<?php
/**
 * ThemesGenerator functions and definitions
 */

/**
 * ThemesGenerator only works in WordPress 4.7 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function themesgenerator_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed at WordPress.org. See: https://translate.wordpress.org/projects/wp-themes/themesgenerator
	 * If you're building a theme based on ThemesGenerator, use a find and replace
	 * to change 'themesgenerator' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'themesgenerator' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'themesgenerator-featured-image', 2000, 1200, true );

	add_image_size( 'themesgenerator-thumbnail-avatar', 100, 100, true );

	// Set the default content width.
	$GLOBALS['content_width'] = 525;



	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'audio',
	) );

	// Add theme support for Custom Logo.
/*
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );
*/
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', themesgenerator_fonts_url() ) );

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(
		'widgets' => array(
			// Place three core-defined widgets in the sidebar area.
			'sidebar-1' => array(
				'text_business_info',
				'search',
				'text_about',
			),

			// Add the core-defined business info widget to the footer 1 area.
			'sidebar-2' => array(
				'text_business_info',
			),

			// Put two core-defined widgets in the footer 2 area.
			'sidebar-3' => array(
				'text_about',
				'search',
			),
		),

		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts' => array(
			'home',
			'about' => array(
				'thumbnail' => '{{image-sandwich}}',
			),
			'contact' => array(
				'thumbnail' => '{{image-espresso}}',
			),
			'blog' => array(
				'thumbnail' => '{{image-coffee}}',
			),
			'homepage-section' => array(
				'thumbnail' => '{{image-espresso}}',
			),
		),

		// Create the custom image attachments used as post thumbnails for pages.
		'attachments' => array(
			'image-espresso' => array(
				'post_title' => _x( 'Espresso', 'Theme starter content', 'themesgenerator' ),
				'file' => 'assets/images/espresso.jpg', // URL relative to the template directory.
			),
			'image-sandwich' => array(
				'post_title' => _x( 'Sandwich', 'Theme starter content', 'themesgenerator' ),
				'file' => 'assets/images/sandwich.jpg',
			),
			'image-coffee' => array(
				'post_title' => _x( 'Coffee', 'Theme starter content', 'themesgenerator' ),
				'file' => 'assets/images/coffee.jpg',
			),
		),

		// Default to a static front page and assign the front and posts pages.
		'options' => array(
			'show_on_front' => 'page',
			'page_on_front' => '{{home}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set the front page section theme mods to the IDs of the core-registered pages.
		'theme_mods' => array(
			'panel_1' => '{{homepage-section}}',
			'panel_2' => '{{about}}',
			'panel_3' => '{{blog}}',
			'panel_4' => '{{contact}}',
		),

		// Set up nav menus for each of the two areas registered in the theme.
		'nav_menus' => array(
			// Assign a menu to the "top" location.
			'top' => array(
				'name' => __( 'Top Menu', 'themesgenerator' ),
				'items' => array(
					'link_home', // Note that the core "home" page is actually a link in case a static front page is not used.
					'page_about',
					'page_blog',
					'page_contact',
				),
			),
		),
	);

	/**
	 * Filters ThemesGenerator array of starter content.
	 *
	 * @since ThemesGenerator 1.1
	 *
	 * @param array $starter_content Array of starter content.
	 */
	$starter_content = apply_filters( 'themesgenerator_starter_content', $starter_content );

	add_theme_support( 'starter-content', $starter_content );
}
add_action( 'after_setup_theme', 'themesgenerator_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function themesgenerator_content_width() {

	$content_width = $GLOBALS['content_width'];

	// Get layout.
	$page_layout = get_theme_mod( 'page_layout' );

	// Check if layout is one column.
	if ( 'one-column' === $page_layout ) {
		if ( themesgenerator_is_frontpage() ) {
			$content_width = 644;
		} elseif ( is_page() ) {
			$content_width = 740;
		}
	}

	// Check if is single post and there is no sidebar.
	if ( is_single() && ! is_active_sidebar( 'sidebar-1' ) ) {
		$content_width = 740;
	}

	/**
	 * Filter ThemesGenerator content width of the theme.
	 *
	 * @since ThemesGenerator 1.0
	 *
	 * @param int $content_width Content width in pixels.
	 */
	$GLOBALS['content_width'] = apply_filters( 'themesgenerator_content_width', $content_width );
}
add_action( 'template_redirect', 'themesgenerator_content_width', 0 );

/**
 * Register custom fonts.
 */
function themesgenerator_fonts_url() {
	$fonts_url = '';

	/*
	 * Translators: If there are characters in your language that are not
	 * supported by Libre Franklin, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$libre_franklin = _x( 'on', 'Libre Franklin font: on or off', 'themesgenerator' );

	if ( 'off' !== $libre_franklin ) {
		$font_families = array();

		$font_families[] = 'Libre Franklin:300,300i,400,400i,600,600i,800,800i';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Add preconnect for Google Fonts.
 *
 * @since ThemesGenerator 1.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function themesgenerator_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'themesgenerator-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'themesgenerator_resource_hints', 10, 2 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function themesgenerator_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'themesgenerator' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'themesgenerator' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'themesgenerator' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'themesgenerator' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'themesgenerator' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'themesgenerator' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'themesgenerator_widgets_init' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since ThemesGenerator 1.0
 *
 * @param string $link Link to single post/page.
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function themesgenerator_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'themesgenerator' ), get_the_title( get_the_ID() ) )
	);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'themesgenerator_excerpt_more' );

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since ThemesGenerator 1.0
 */
function themesgenerator_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'themesgenerator_javascript_detection', 0 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function themesgenerator_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'themesgenerator_pingback_header' );

/**
 * Display custom color CSS.
 */
function themesgenerator_colors_css_wrap() {
	if ( 'custom' !== get_theme_mod( 'colorscheme' ) && ! is_customize_preview() ) {
		return;
	}

	require_once( get_parent_theme_file_path( '/inc/color-patterns.php' ) );
	$hue = absint( get_theme_mod( 'colorscheme_hue', 250 ) );
?>
	<style type="text/css" id="custom-theme-colors" <?php if ( is_customize_preview() ) { echo 'data-hue="' . $hue . '"'; } ?>>
		<?php echo themesgenerator_custom_colors_css(); ?>
	</style>
<?php }
add_action( 'wp_head', 'themesgenerator_colors_css_wrap' );

/**
 * Enqueue scripts and styles.
 */
function themesgenerator_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'themesgenerator-fonts', themesgenerator_fonts_url(), array(), null );

	// Theme stylesheet.
	wp_enqueue_style( 'themesgenerator-style', get_stylesheet_uri() );

	// Load the dark colorscheme.
	if ( 'dark' === get_theme_mod( 'colorscheme', 'light' ) || is_customize_preview() ) {
		wp_enqueue_style( 'themesgenerator-colors-dark', get_theme_file_uri( '/assets/css/colors-dark.css' ), array( 'themesgenerator-style' ), '1.0' );
	}

	// Load the Internet Explorer 9 specific stylesheet, to fix display issues in the Customizer.
	if ( is_customize_preview() ) {
		wp_enqueue_style( 'themesgenerator-ie9', get_theme_file_uri( '/assets/css/ie9.css' ), array( 'themesgenerator-style' ), '1.0' );
		wp_style_add_data( 'themesgenerator-ie9', 'conditional', 'IE 9' );
	}

	// Load the Internet Explorer 8 specific stylesheet.
	wp_enqueue_style( 'themesgenerator-ie8', get_theme_file_uri( '/assets/css/ie8.css' ), array( 'themesgenerator-style' ), '1.0' );
	wp_style_add_data( 'themesgenerator-ie8', 'conditional', 'lt IE 9' );

	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'themesgenerator-skip-link-focus-fix', get_theme_file_uri( '/assets/js/skip-link-focus-fix.js' ), array(), '1.0', true );

	$themesgenerator_l10n = array(
//		'quote'          => themesgenerator_get_svg( array( 'icon' => 'quote-right' ) ),
	);

	if ( has_nav_menu( 'top' ) ) {
		wp_enqueue_script( 'themesgenerator-navigation', get_theme_file_uri( '/assets/js/navigation.js' ), array( 'jquery' ), '1.0', true );
		$themesgenerator_l10n['expand']         = __( 'Expand child menu', 'themesgenerator' );
		$themesgenerator_l10n['collapse']       = __( 'Collapse child menu', 'themesgenerator' );
//		$themesgenerator_l10n['icon']           = themesgenerator_get_svg( array( 'icon' => 'angle-down', 'fallback' => true ) );
	}

	wp_enqueue_script( 'themesgenerator-global', get_theme_file_uri( '/assets/js/global.js' ), array( 'jquery' ), '1.0', true );

	wp_enqueue_script( 'jquery-scrollto', get_theme_file_uri( '/assets/js/jquery.scrollTo.js' ), array( 'jquery' ), '2.1.2', true );

	wp_localize_script( 'themesgenerator-skip-link-focus-fix', 'themesgeneratorScreenReaderText', $themesgenerator_l10n );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'themesgenerator_scripts' );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images.
 *
 * @since ThemesGenerator 1.0
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
function themesgenerator_content_image_sizes_attr( $sizes, $size ) {
	$width = $size[0];

	if ( 740 <= $width ) {
		$sizes = '(max-width: 706px) 89vw, (max-width: 767px) 82vw, 740px';
	}

	if ( is_active_sidebar( 'sidebar-1' ) || is_archive() || is_search() || is_home() || is_page() ) {
		if ( ! ( is_page() && 'one-column' === get_theme_mod( 'page_options' ) ) && 767 <= $width ) {
			 $sizes = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
		}
	}

	return $sizes;
}
add_filter( 'wp_calculate_image_sizes', 'themesgenerator_content_image_sizes_attr', 10, 2 );

/**
 * Filter the `sizes` value in the header image markup.
 *
 * @since ThemesGenerator 1.0
 *
 * @param string $html   The HTML image tag markup being filtered.
 * @param object $header The custom header object returned by 'get_custom_header()'.
 * @param array  $attr   Array of the attributes for the image tag.
 * @return string The filtered header image HTML.
 */
function themesgenerator_header_image_tag( $html, $header, $attr ) {
	if ( isset( $attr['sizes'] ) ) {
		$html = str_replace( $attr['sizes'], '100vw', $html );
	}
	return $html;
}
add_filter( 'get_header_image_tag', 'themesgenerator_header_image_tag', 10, 3 );

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails.
 *
 * @since ThemesGenerator 1.0
 *
 * @param array $attr       Attributes for the image markup.
 * @param int   $attachment Image attachment ID.
 * @param array $size       Registered image size or flat array of height and width dimensions.
 * @return array The filtered attributes for the image markup.
 */
function themesgenerator_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( is_archive() || is_search() || is_home() ) {
		$attr['sizes'] = '(max-width: 767px) 89vw, (max-width: 1000px) 54vw, (max-width: 1071px) 543px, 580px';
	} else {
		$attr['sizes'] = '100vw';
	}

	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'themesgenerator_post_thumbnail_sizes_attr', 10, 3 );

/**
 * Use front-page.php when Front page displays is set to a static page.
 *
 * @since ThemesGenerator 1.0
 *
 * @param string $template front-page.php.
 *
 * @return string The template to be used: blank if is_home() is true (defaults to index.php), else $template.
 */
function themesgenerator_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'themesgenerator_front_page_template' );

/**
 * Modifies tag cloud widget arguments to display all tags in the same font size
 * and use list format for better accessibility.
 *
 * @since ThemesGenerator 1.4
 *
 * @param array $args Arguments for tag cloud widget.
 * @return array The filtered arguments for tag cloud widget.
 */
function themesgenerator_widget_tag_cloud_args( $args ) {
	$args['largest']  = 1;
	$args['smallest'] = 1;
	$args['unit']     = 'em';
	$args['format']   = 'list';

	return $args;
}
add_filter( 'widget_tag_cloud_args', 'themesgenerator_widget_tag_cloud_args' );

/**
 * Implement the Custom Header feature.
 */
//require get_parent_theme_file_path( '/inc/custom-header.php' );

/**
 * Custom template tags for this theme.
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Additional features to allow styling of the templates.
 */
//require get_parent_theme_file_path( '/inc/template-functions.php' );

/**
 * Checks to see if we're on the homepage or not.
 */
function themesgenerator_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}


/**
 * Customizer additions.
 */
//require get_parent_theme_file_path( '/inc/customizer.php' );

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

class Excerpt_Walker extends Walker_Nav_Menu
{
    //function start_el(&$output, $item, $depth, $args)
	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 )
    {
        global $wp_query;
        $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

        $class_names = $value = '';

        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $classes[] = 'menu-item-' . $item->ID;
	$classes[] = 'item';

        $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
        $class_names = ' class="' . esc_attr( $class_names ) . '"';

        $id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
        $id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';

        $output .= $indent . '<li' . $id . $value . $class_names .'>';

        $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
        $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
        $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
        $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';
		
		


        $item_output = $args->before;
        $item_output .= '<a class="navbar-menu-link" '. $attributes .'>';

        $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;

        /*GET THE EXCERPT*/
        /*$q = new WP_Query(array('post__in'=>$item->object_id));
        if($q->have_posts()) : while($q->have_posts()) : $q->the_post();
            $item_output .= '<span class="menu-excerpt">'.get_the_excerpt().'</span>';
        endwhile;endif;*/
        /*****************/

        $item_output .= '</a>';
        $item_output .= $args->after;

        $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
    }
}


/*Edit in TG*/
add_action('admin_bar_menu', 'add_toolbar_items', 100);
function add_toolbar_items($admin_bar){
	$external_link=get_template_directory_uri()."/themes-generator-theme.txt";
	$complete_link="https://themesgenerator.com/?editmode=ok&dedit=$external_link";
    $admin_bar->add_menu( array(
        'id'    => 'edit-theme',
        'title' => 'Edit Theme',
        'href'  => $complete_link,
        'meta'  => array(
            'title' => __('Edit theme in Themes Generator', 'themesgenerator'),   
			'target' => __('_blank', 'themesgenerator'),
        ),
    ));
}



/**
 * Ensure cart contents update when products are added to the cart via AJAX
 */
function my_header_add_to_cart_fragment( $fragments ) {
 
    ob_start();
    $count = WC()->cart->cart_contents_count;
    ?><a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e( 'View your shopping cart', 'themesgenerator'  ); ?>"><?php
    if ( $count > 0 ) {
        ?>
        <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
        <?php            
    }
        ?></a><?php
 
    $fragments['a.cart-contents'] = ob_get_clean();
     
    return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'my_header_add_to_cart_fragment' );


/**
 * Add Cart icon and count to header if WC is active
 */
function my_wc_cart_count() {
 
    if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
 
        $count = WC()->cart->cart_contents_count;
        ?><a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e( 'View your shopping cart', 'themesgenerator' ); ?>"><?php
        if ( $count > 0 ) {
            ?>
            <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
            <?php
        }
                ?></a><?php
    }
 
}
add_action( 'your_theme_header_top', 'my_wc_cart_count' );








/***********************/
/*Woocommerce ratings */
/*********************/

//Enqueue the plugin's styles.
add_action( 'wp_enqueue_scripts', 'tg_woo_ra_rating_styles' );
function tg_woo_ra_rating_styles() {
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'ci-comment-rating-styles' );
}

//Create the rating interface.
add_action( 'comment_form_logged_in_after', 'tg_woo_ra_rating_rating_field' );
add_action( 'comment_form_after_fields', 'tg_woo_ra_rating_rating_field' );
function tg_woo_ra_rating_rating_field () {
	?>
	<label for="rating">Rating</label>
	<fieldset class="comments-rating">
		<span class="rating-container">
			<?php for ( $i = 5; $i >= 1; $i-- ) : ?>
				<input type="radio" id="rating-<?php echo esc_attr( $i ); ?>" name="rating" value="<?php echo esc_attr( $i ); ?>" /><label for="rating-<?php echo esc_attr( $i ); ?>"><?php echo esc_html( $i ); ?></label>
			<?php endfor; ?>
			<input type="radio" id="rating-0" class="star-cb-clear" name="rating" value="0" /><label for="rating-0">0</label>
		</span>
	</fieldset>
	<?php
}

//Save the rating submitted by the user.
add_action( 'comment_post', 'tg_woo_ra_rating_save_comment_rating' );
function tg_woo_ra_rating_save_comment_rating( $comment_id ) {
	if ( ( isset( $_POST['rating'] ) ) && ( '' !== $_POST['rating'] ) )
	$rating = intval( $_POST['rating'] );
	add_comment_meta( $comment_id, 'rating', $rating );
}

//Make the rating required -> is_product() is not working as expected, so validation is disabled
add_filter( 'preprocess_comment', 'tg_woo_ra_rating_require_rating' );
function tg_woo_ra_rating_require_rating( $commentdata ) {
	if (function_exists( 'is_product' ) ) {
		if ( ! is_admin() && is_product() &&( ! isset( $_POST['rating'] ) || 0 === intval( $_POST['rating'] ) ) )
		wp_die( __( 'Error: You did not add a rating. Hit the Back button on your Web browser and resubmit your comment with a rating.' , 'themesgenerator') );
		return $commentdata;
	} else return $commentdata;
}

//Display the rating on a submitted comment.
add_filter( 'comment_text', 'tg_woo_ra_rating_display_rating');
function tg_woo_ra_rating_display_rating( $comment_text ){

	if ( $rating = get_comment_meta( get_comment_ID(), 'rating', true ) ) {
		$stars = '<p class="stars">';
		for ( $i = 1; $i <= $rating; $i++ ) {
			$stars .= '<span class="dashicons dashicons-star-filled"></span>';
		}
		$stars .= '</p>';
		$comment_text = $comment_text . $stars;
		return $comment_text;
	} else {
		return $comment_text;
	}
}

//Get the average rating of a post.
function tg_woo_ra_rating_get_average_ratings( $id ) {
	$comments = get_approved_comments( $id );

	if ( $comments ) {
		$i = 0;
		$total = 0;
		foreach( $comments as $comment ){
			$rate = get_comment_meta( $comment->comment_ID, 'rating', true );
			if( isset( $rate ) && '' !== $rate ) {
				$i++;
				$total += $rate;
			}
		}

		if ( 0 === $i ) {
			return false;
		} else {
			return round( $total / $i, 1 );
		}
	} else {
		return false;
	}
}



/*****************************/
/*Disable comments URL field*/
/***************************/

function crunchify_disable_comment_url($fields) { 
    unset($fields['url']);
    return $fields;
}
add_filter('comment_form_default_fields','crunchify_disable_comment_url');





/**************************/
/*Woocommerce customizer */
/************************/

/*Add shop styles if WC is active*/
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
add_action( "customize_register", "themesgenchild_register_theme_customizer_woo"); 
}

function themesgenchild_register_theme_customizer_woo( $wp_customize ) {


$wp_customize->add_section( 'tg_woo__theme_colors', array(
	'title' => __( 'Shop Styles', 'themesgenerator' ),
	'priority' => 100,
) );


/*cart_color*/
$wp_customize->add_setting( 'cart_color', array(
	'default' => '#444444',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cart_color', array(
	'label' => 'Cart Color',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'cart_color',
) ) );

/*cart_count_background*/
$wp_customize->add_setting( 'cart_count_background', array(
	'default' => '#2ecc71',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cart_count_background', array(
	'label' => 'Cart Count Background',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'cart_count_background',
) ) );

/*cart_count_text*/
$wp_customize->add_setting( 'cart_count_text', array(
	'default' => '#ffffff',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cart_count_text', array(
	'label' => 'Cart Count Text',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'cart_count_text',
) ) );

/*price_color*/
$wp_customize->add_setting( 'price_color', array(
	'default' => '#77a464',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'price_color', array(
	'label' => 'Price Color',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'price_color',
) ) );

/*buttons_text*/
$wp_customize->add_setting( 'buttons_text', array(
	'default' => '#ffffff',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_text', array(
	'label' => 'Buttons Text',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'buttons_text',
) ) );

/*buttons_background*/
$wp_customize->add_setting( 'buttons_background', array(
	'default' => '#a46497',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_background', array(
	'label' => 'Buttons Background',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'buttons_background',
) ) );

/*buttons_text_hover*/
$wp_customize->add_setting( 'buttons_text_hover', array(
	'default' => '#e6e6e6',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_text_hover', array(
	'label' => 'Buttons Text Hover',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'buttons_text_hover',
) ) );

/*buttons_background_hover*/
$wp_customize->add_setting( 'buttons_background_hover', array(
	'default' => '#935386',"sanitize_callback" => "esc_attr"
) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_background_hover', array(
	'label' => 'Buttons Background Hover',
	'section' => 'tg_woo__theme_colors',
	'settings' => 'buttons_background_hover',
) ) );



function theme_slug_sanitize_checkbox( $input ){    
	if (isset( $input )) return $input;
	else return "false";
}


/*show_cart_in_menu*/
$wp_customize->add_setting( 'show_cart_in_menu', array(
'default'        => true,
'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox"
 ) );
$wp_customize->add_control('show_cart_in_menu',
array(
    'section'   => 'tg_woo__theme_colors',
    'label'     => 'Show cart in menu',
    'type'      => 'checkbox'
     )
 );

/*show_cart_count*/
$wp_customize->add_setting( 'show_cart_count', array(
'default'        => true,
'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox"
 ) );
$wp_customize->add_control('show_cart_count',
array(
    'section'   => 'tg_woo__theme_colors',
    'label'     => 'Show cart counter',
    'type'      => 'checkbox'
     )
 ); 
 
 
/*cart menu location*/
$wp_customize->add_setting(
	'cart_menu_location',
	array(
		'default' => '1',
		'sanitize_callback' => 'sanitize_float',
	)
);
$wp_customize->add_control(
	'cart_menu_location',
	array(
		'label' => 'Cart location (menu number)',
		'section' => 'tg_woo__theme_colors',
		'type' => 'number',
		'input_attrs' => array(
			'min' => '1', 'step' => '1', 'max' => '999',
		  ),
	)
); 
 
 
 
 
}


function tg_customizer_head_styles() {
	$cart_color = get_theme_mod( 'cart_color' ); 	
	if ( $cart_color != '#444444' ) :
	?>
		<style type="text/css">
			.cart-contents:before {
				color: <?php echo $cart_color; ?>;
			}
		</style>
	<?php
	endif;
	
	$cart_count_background = get_theme_mod( 'cart_count_background' );
	if ( $cart_count_background != '#2ecc71' ) :
	?>
		<style type="text/css">
			.cart-contents-count {
				background-color: <?php echo $cart_count_background; ?>;
			}
		</style>
	<?php
	endif;	

	$cart_count_text = get_theme_mod( 'cart_count_text' );
	if ( $cart_count_text != '#ffffff' ) :
	?>
		<style type="text/css">
			.cart-contents-count {
				color: <?php echo $cart_count_text; ?>;
			}
		</style>
	<?php
	endif;	

	$price_color = get_theme_mod( 'price_color' );
	if ( $price_color != '#77a464' ) :
	?>
		<style type="text/css">
			.woocommerce div.product p.price, .woocommerce div.product span.price {
				color: <?php echo $price_color; ?>;
			}
		</style>
	<?php
	endif;

	$buttons_text = get_theme_mod( 'buttons_text' );
	if ( $buttons_text != '#ffffff' ) :
	?>
		<style type="text/css">
			.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt {
				color: <?php echo $buttons_text; ?>!important;
			}
			.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button {
				color: <?php echo $buttons_text; ?>!important;
			}
		</style>
	<?php
	endif;

	$buttons_background = get_theme_mod( 'buttons_background' );
	if ( $buttons_background != '#a46497' ) :
	?>
		<style type="text/css">
			.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt {
				background-color: <?php echo $buttons_background; ?>!important;
			}						
			.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button {
				background-color: <?php echo $buttons_background; ?>!important;
			}			
		</style>
	<?php
	endif;
	
	$buttons_text_hover = get_theme_mod( 'buttons_text_hover' );
	if ( $buttons_text_hover != '#e6e6e6' ) :
	?>
		<style type="text/css">
			.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover {
				color: <?php echo $buttons_text_hover; ?>!important;
			}
			.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover{
				color: <?php echo $buttons_text_hover; ?>!important;
			}
		</style>
	<?php
	endif;	
	

	$buttons_background_hover = get_theme_mod( 'buttons_background_hover' );
	if ( $buttons_background_hover != '#935386' ) :
	?>
		<style type="text/css">
			.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover {
				background-color: <?php echo $buttons_background_hover; ?>!important;
			}
			.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover {
				background-color: <?php echo $buttons_background_hover; ?>!important;
			}
		</style>
	<?php
	endif;
		
	
	$show_cart_in_menu = get_theme_mod( 'show_cart_in_menu', 'true' ); 	
	if ( $show_cart_in_menu === true ) :
	?>
		<style type="text/css">
			.cart-contents {
				display: block;
			}
		</style>
	<?php
	endif;
	if ( $show_cart_in_menu === false ) :
	?>
		<style type="text/css">
			.cart-contents {
				display: none!important;
			}
		</style>
	<?php
	endif;


	$show_cart_count = get_theme_mod( 'show_cart_count', 'true' ); 	
	if ( $show_cart_count === true ) :
	?>
		<style type="text/css">
			.cart-contents-count {
				display: inline;
			}
		</style>
	<?php
	endif;
	if ( $show_cart_count === false ) :
	?>
		<style type="text/css">
			.cart-contents-count {
				display: none!important;
			}
		</style>
	<?php
	endif;
	
	$cart_menu_location = get_theme_mod( 'cart_menu_location', 'true' ); 	
	if ( $cart_menu_location == "true" ) $cart_menu_location=1;
	if ( $cart_menu_location != "true" ) :
	?>
		<script>
		jQuery( document ).ready(function() {
			/*Ubico cart en menu location asignada*/
			/*Si el menu asignado a carrito no se encuentra en la current page, no lo muestro*/			
			if (jQuery(".mymenu<?php echo $cart_menu_location;?>").length){
				jQuery(".cart-contents").insertAfter( ".mymenu<?php echo $cart_menu_location;?>" );	
			} else jQuery(".cart-contents").remove();						
		});		
		</script>
	<?php
	endif;	
}
add_action( 'wp_head', 'tg_customizer_head_styles' );


/**************************/
/*Site Layout customizer */
/************************/
add_action( "customize_register", "themesgenchild_register_theme_customizer_sitelayout"); 
function themesgenchild_register_theme_customizer_sitelayout( $wp_customize ) {
	$wp_customize->add_section( 'tg_layout', array(
		'title' => __( 'Main Options', 'themesgenerator' ),
		'priority' => 100,
	) );
	function sanitize_float( $input ) {
		return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
	}
	/*content_min_height*/
	$wp_customize->add_setting(
		'content_min_height',
		array(
			'default' => '588',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'content_min_height',
		array(
			'label' => 'Content minimum height (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);
	/*content_max_width*/
	$wp_customize->add_setting(
		'content_max_width',
		array(
			'default' => '1400',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'content_max_width',
		array(
			'label' => 'Content maximum width (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);
	/*footer_widgets_sect_max_width*/
	$wp_customize->add_setting(
		'footer_widgets_sect_max_width',
		array(
			'default' => '1280',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'footer_widgets_sect_max_width',
		array(
			'label' => 'Footer widgets area max width (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
	/*footer_widgets_padding_leftright*/
	$wp_customize->add_setting(
		'footer_widgets_padding_leftright',
		array(
			'default' => '30',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'footer_widgets_padding_leftright',
		array(
			'label' => 'Footer widgets left/right padding (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
	/*footer_widgets_padding_topbottom*/
	$wp_customize->add_setting(
		'footer_widgets_padding_topbottom',
		array(
			'default' => '35',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'footer_widgets_padding_topbottom',
		array(
			'label' => 'Footer widgets top/bott padding (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	


	
	
	
	
	/*post_excerpt_length*/
	$wp_customize->add_setting(
		'post_excerpt_length',
		array(
			'default' => '55',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'post_excerpt_length',
		array(
			'label' => 'Post excerpt length (words)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);
	
	
	
	
	
	
	
	function theme_slug_sanitize_checkbox2( $input ){    
		if (isset( $input )) return $input;
		else return "false";
	}


	/*show_full_width_footer_widgets*/
	$wp_customize->add_setting( 'show_full_width_footer_widgets', array(
	'default'        => false,
	'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox2"
	 ) );
	$wp_customize->add_control('show_full_width_footer_widgets',
	array(
		'section'   => 'tg_layout',
		'label'     => 'Full width footer widgets',
		'type'      => 'checkbox'
		 )
	 );


	




	 
	/*menu_footer_widgets_background*/
	require_once( dirname( __FILE__ ) . '/inc/alpha-color-picker.php' );
	$wp_customize->add_setting(
		'footer_widgets_background',
		array(
			'default'     => 'rgba(238,238,238,1)',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',"sanitize_callback" => "esc_attr"
		)
	);
	$wp_customize->add_control(
		new Customize_Alpha_Color_Control(
			$wp_customize,
			'footer_widgets_background',
			array(
				'label'         => 'Footer widgets area background',
				'section'       => 'tg_layout',
				'settings'      => 'footer_widgets_background',
				'show_opacity'  => true, // Optional.
				'palette'	=> array(
					'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
					'rgba(50,50,50,0.8)',
					'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
					'#00CC99' // Mix of color types = no problem
				)
			)
		)
	);



	
	
	
	
	
	
	
	
	
	/*page_title_color*/ 
	$wp_customize->add_setting( 'page_title_color', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_title_color', array(
		'label' => 'Page title color',
		'section' => 'tg_layout',
		'settings' => 'page_title_color',
	) ) );	
	/*post_title_color*/ 
	$wp_customize->add_setting( 'post_title_color', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'post_title_color', array(
		'label' => 'Post title color',
		'section' => 'tg_layout',
		'settings' => 'post_title_color',
	) ) );	
	/*page_title_size*/
	$wp_customize->add_setting(
		'page_title_size',
		array(
			'default' => '26',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'page_title_size',
		array(
			'label' => 'Page title size (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
	/*post_title_size*/
	$wp_customize->add_setting(
		'post_title_size',
		array(
			'default' => '26',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'post_title_size',
		array(
			'label' => 'Post title size (px)',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
	
	
	
			function tg_sanitize_fontweight_pagetitle( $input ) {
			$valid = array(
			'100' => 'Thin',
			'200' => 'Extra-Light',
			'300' => 'Light',
			'400' => 'Normal',
			'500' => 'Medium',
			'600' => 'Semi-Bold',
			'700' => 'Bold',
			'800' => 'Extra-Bold',
			'900' => 'Ultra-Bold',			
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
			}	
			$bold_choices = array(
				'100' => 'Thin',
				'200' => 'Extra-Light',
				'300' => 'Light',
				'400' => 'Normal',
				'500' => 'Medium',
				'600' => 'Semi-Bold',
				'700' => 'Bold',
				'800' => 'Extra-Bold',
				'900' => 'Ultra-Bold',				
			);
			$wp_customize->add_setting( 'fontweight_pagetitle', array(
					'sanitize_callback' => 'tg_sanitize_fontweight_pagetitle',
					'default' => '400'
				)
			);
			$wp_customize->add_control( 'fontweight_pagetitle', array(
					'type' => 'select',
					"label"    => __( "Page title font weight", "themesgenerator" ),
					/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
					'section' => 'tg_layout',
					'choices' => $bold_choices,
					"settings" => "fontweight_pagetitle"
				)
			);
	
	
	
	
			function tg_sanitize_fontweight_posttitle( $input ) {
			$valid = array(
			'100' => 'Thin',
			'200' => 'Extra-Light',
			'300' => 'Light',
			'400' => 'Normal',
			'500' => 'Medium',
			'600' => 'Semi-Bold',
			'700' => 'Bold',
			'800' => 'Extra-Bold',
			'900' => 'Ultra-Bold',			
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
			}	
			$bold_choices = array(
				'100' => 'Thin',
				'200' => 'Extra-Light',
				'300' => 'Light',
				'400' => 'Normal',
				'500' => 'Medium',
				'600' => 'Semi-Bold',
				'700' => 'Bold',
				'800' => 'Extra-Bold',
				'900' => 'Ultra-Bold',				
			);
			$wp_customize->add_setting( 'fontweight_posttitle', array(
					'sanitize_callback' => 'tg_sanitize_fontweight_posttitle',
					'default' => '400'
				)
			);
			$wp_customize->add_control( 'fontweight_posttitle', array(
					'type' => 'select',
					"label"    => __( "Post title font weight", "themesgenerator" ),
					/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
					'section' => 'tg_layout',
					'choices' => $bold_choices,
					"settings" => "fontweight_posttitle"
				)
			);	
	
	
	
	
	
	
				/*page_title_font*/
				 function tgnav_sanitize_fonts_pagetitle( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "inherit" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "page_title_font_pagetitle", array("sanitize_callback" => "tgnav_sanitize_fonts_pagetitle","default" => "inherit"));
				$wp_customize->add_control( "page_title_font_pagetitle", array("type" => "select","label" => __( "Page title font", "themesgenerator" ),"section" => "tg_layout","choices" => $font_choices,"settings" => "page_title_font_pagetitle"));	
				

				/*post_title_font*/
				 function tgnav_sanitize_fonts_posttitle( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "inherit" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "post_title_font_posttitle", array("sanitize_callback" => "tgnav_sanitize_fonts_posttitle","default" => "inherit"));
				$wp_customize->add_control( "post_title_font_posttitle", array("type" => "select","label" => __( "Post title font", "themesgenerator" ),"section" => "tg_layout","choices" => $font_choices,"settings" => "post_title_font_posttitle"));	
		

	

	/*show_posts_sidebar*/
	$wp_customize->add_setting( 'show_posts_sidebar', array(
	'default'        => false,
	'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox2"
	 ) );
	$wp_customize->add_control('show_posts_sidebar',
	array(
		'section'   => 'tg_layout',
		'label'     => 'Sidebar in blog & WooCommerce',
		'type'      => 'checkbox'
		 )
	 );	
	 
	 
	 
	/*show_back_to_top_button*/
	$wp_customize->add_setting( 'show_back_to_top_button', array(
	'default'        => false,
	'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox2"
	 ) );
	$wp_customize->add_control('show_back_to_top_button',
	array(
		'section'   => 'tg_layout',
		'label'     => 'Show back to top button',
		'type'      => 'checkbox'
		 )
	 );


	/*back_to_top_button_arrow_color*/ 
	$wp_customize->add_setting( 'back_to_top_button_arrow_color', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_to_top_button_arrow_color', array(
		'label' => 'Back to top arrow',
		'section' => 'tg_layout',
		'settings' => 'back_to_top_button_arrow_color',
	) ) );

	
	/*back_to_top_button_arrow_background*/ 
	$wp_customize->add_setting( 'back_to_top_button_arrow_background', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_to_top_button_arrow_background', array(
		'label' => 'Back to top background',
		'section' => 'tg_layout',
		'settings' => 'back_to_top_button_arrow_background',
	) ) );


	/*back_to_top_button_arrow_hover*/ 
	$wp_customize->add_setting( 'back_to_top_button_arrow_hover', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'back_to_top_button_arrow_hover', array(
		'label' => 'Back to top hover',
		'section' => 'tg_layout',
		'settings' => 'back_to_top_button_arrow_hover',
	) ) );	




	/*back_to_top_button_align_left*/
	$wp_customize->add_setting( 'back_to_top_button_align_left', array(
	'default'        => false,
	'capability'     => 'edit_theme_options',"sanitize_callback" => "theme_slug_sanitize_checkbox2"
	 ) );
	$wp_customize->add_control('back_to_top_button_align_left',
	array(
		'section'   => 'tg_layout',
		'label'     => 'Back to top button align left',
		'type'      => 'checkbox'
		 )
	 );
	 
	 
	 
	 
	 
	/*back_to_top_button_opacity*/
	$wp_customize->add_setting(
		'back_to_top_button_opacity',
		array(
			'default' => '1',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'back_to_top_button_opacity',
		array(
			'label' => 'Back to top button opacity',
			'section' => 'tg_layout',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '0.1', 'max' => '1',
			  ),
		)
	);
	
}
/*Page title font, outside the main customizer function*/
function tgnav_scripts_pagetitle() { $page_title_font_pagetitle = esc_html(get_theme_mod("page_title_font_pagetitle")); if( $page_title_font_pagetitle ) { $not_google_fonts_pagetitle = array("inherit", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts_pagetitle as $url) { if (strpos($page_title_font_pagetitle, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts_pagetitle", "//fonts.googleapis.com/css?family=". $page_title_font_pagetitle ); } else { wp_enqueue_style( "themesgenerator-source-body_pagetitle", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts_pagetitle" );
function tg_sitelayout_latest_posts_2_pagetitle() { $page_title_font_pagetitle = esc_html(get_theme_mod("page_title_font_pagetitle")); if ( $page_title_font_pagetitle ) {	$font_pieces = explode(":", $page_title_font_pagetitle); $custom = "body.page:not(.themesgenerator-front-page) .entry-title { font-family: ".$font_pieces[0]."!important; }"."\n";} if ( $page_title_font_pagetitle ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_2_pagetitle" );

/*Post title font, outside the main customizer function*/
function tgnav_scripts_posttitle() { $post_title_font_posttitle = esc_html(get_theme_mod("post_title_font_posttitle")); if( $post_title_font_posttitle ) { $not_google_fonts_posttitle = array("inherit", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts_posttitle as $url) { if (strpos($post_title_font_posttitle, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts_posttitle", "//fonts.googleapis.com/css?family=". $post_title_font_posttitle ); } else { wp_enqueue_style( "themesgenerator-source-body_posttitle", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts_posttitle" );
function tg_sitelayout_latest_posts_2_posttitle() { $post_title_font_posttitle = esc_html(get_theme_mod("post_title_font_posttitle")); if ( $post_title_font_posttitle ) {	$font_pieces = explode(":", $post_title_font_posttitle); $custom = "body.single:not(.themesgenerator-front-page) .entry-title { font-family: ".$font_pieces[0]."!important; }"."\n";} if ( $post_title_font_posttitle ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_2_posttitle" );
	



function tg_sitelayout_head_styles() {
	$content_min_height = get_theme_mod( 'content_min_height' ); 	
	if ( $content_min_height != '588' ) :
	?>
		<style type="text/css">
			body:not(.home) .site-content {
				min-height: <?php echo $content_min_height; ?>px;
			}
		</style>
	<?php
	endif;
	$content_max_width = get_theme_mod( 'content_max_width' ); 	
	if ( $content_max_width != '1400' ) :
	?>
		<style type="text/css">
			body:not(.home) .wrap{
				max-width: <?php echo $content_max_width; ?>px;
				margin: 0 auto;
			}
		</style>
	<?php
	endif;
	$footer_widgets_sect_max_width = get_theme_mod( 'footer_widgets_sect_max_width' ); 	
	if ( $footer_widgets_sect_max_width != '1280' ) :
	?>
		<style type="text/css">
			.home .site-footer .widget-area{
				max-width: <?php echo $footer_widgets_sect_max_width; ?>px!important;
			}
		</style>
	<?php
	endif;
	$footer_widgets_padding_leftright = get_theme_mod( 'footer_widgets_padding_leftright' ); 	
	if ( $footer_widgets_padding_leftright != '30' ) :
	?>
		<style type="text/css">
			.site-footer .widget-column{
				padding-left: <?php echo $footer_widgets_padding_leftright; ?>px!important;
				padding-right: <?php echo $footer_widgets_padding_leftright; ?>px!important;
			}
		</style>
	<?php
	endif;
	$footer_widgets_padding_topbottom = get_theme_mod( 'footer_widgets_padding_topbottom' ); 	
	if ( $footer_widgets_padding_topbottom != '35' ) :
	?>
		<style type="text/css">
			.site-footer .widget-column{
				padding-top: <?php echo $footer_widgets_padding_topbottom; ?>px!important;
				padding-bottom: <?php echo $footer_widgets_padding_topbottom; ?>px!important;
			}
		</style>
	<?php
	endif;
	
	

	$post_excerpt_length = get_theme_mod( 'post_excerpt_length' ); 	
	if ( $post_excerpt_length != '55' ) :
		function wpdocs_custom_excerpt_length( $length ) {
			$post_excerpt_length = get_theme_mod( 'post_excerpt_length' ); 
			if (empty($post_excerpt_length)) $post_excerpt_length='55';
			return $post_excerpt_length;
		}
		add_filter( 'excerpt_length', 'wpdocs_custom_excerpt_length', 999 );	
	endif;




	
	





	$back_to_top_button_opacity = get_theme_mod( 'back_to_top_button_opacity' ); 	
	if ( $back_to_top_button_opacity != '1' ) :
	?>
		<style type="text/css">
			#backtotopbutton.show {
				opacity: <?php echo $back_to_top_button_opacity; ?>!important;
			}
		</style>
	<?php
	endif;	
	
		

	
	
	

	
	$show_full_width_footer_widgets = get_theme_mod( 'show_full_width_footer_widgets', 'true' );
	if ( $show_full_width_footer_widgets === true ) :
	?>
		<style type="text/css">
			.site-footer .widget-column{
				width: 100%!important;
			}
		</style>
	<?php
	endif;
	if ( $show_full_width_footer_widgets === false ) :
	?>
		<style type="text/css">
			.site-footer .widget-column{
				width: 36%;
			}
		</style>
	<?php
	endif;
	
	
	
	
	
	
	

	
	
	
	
	
	$show_back_to_top_button = get_theme_mod( 'show_back_to_top_button', 'true' );
	if ( $show_back_to_top_button === true ) :
	?>
		<style type="text/css">
		#backtotopbutton.show {
				  opacity: 1;
				  visibility: visible;
				}
		</style>
	<?php
	endif;
	if ( $show_back_to_top_button === false ) :
	?>
		<style type="text/css">
			#backtotopbutton.show {
			  opacity: 0;
			  visibility: hidden;
			}
		</style>
	<?php
	endif;	
	



	
	
	$back_to_top_button_align_left = get_theme_mod( 'back_to_top_button_align_left', 'true' );
	if ( $back_to_top_button_align_left === true ) :
	?>
		<style type="text/css">
			#backtotopbutton {
			  left: 30px;
			  right: auto;
			}
		</style>
	<?php
	endif;
	if ( $back_to_top_button_align_left === false ) :
	?>
		<style type="text/css">
			#backtotopbutton {
			  right: 30px;
			}
		</style>
	<?php
	endif;	





	
	
/*Begin page & post title*/		
	$page_title_color = get_theme_mod( 'page_title_color' ); 	
	if (( $page_title_color != 'inherit' )&&( $page_title_color != '' )) :
	?>
		<style type="text/css">
			body.page:not(.themesgenerator-front-page) .entry-title{
				color: <?php echo $page_title_color; ?>!important;
			}
		</style>
	<?php
	endif;	
	$page_title_size = get_theme_mod( 'page_title_size' ); 	
	if ( $page_title_size != '26.5' ) :
	?>
		<style type="text/css">
			body.page:not(.themesgenerator-front-page) .entry-title{
				font-size: <?php echo $page_title_size; ?>px!important;
			}
		</style>
	<?php
	endif;
	
	
	
	
	$page_title_fontweight = esc_html(get_theme_mod('fontweight_pagetitle'));
	if ( $page_title_fontweight ) {
			?>
				<style type="text/css">					
					body.page:not(.themesgenerator-front-page) .entry-title { font-weight: <?php echo $page_title_fontweight;?>!important; }
				</style>
			<?php
	}
		
	$post_title_fontweight = esc_html(get_theme_mod('fontweight_posttitle'));
	if ( $post_title_fontweight ) {
			?>
				<style type="text/css">					
					body.single:not(.themesgenerator-front-page) .entry-title { font-weight: <?php echo $post_title_fontweight;?>!important; }
				</style>
			<?php
	}	




	
		
		
	$post_title_color = get_theme_mod( 'post_title_color' ); 	
	if (( $post_title_color != 'inherit' )&&( $post_title_color != '' )) :
	?>
		<style type="text/css">
			body.single:not(.themesgenerator-front-page) .entry-title{
				color: <?php echo $post_title_color; ?>!important;
			}
		</style>
	<?php
	endif;	
	$post_title_size = get_theme_mod( 'post_title_size' ); 	
	if ( $post_title_size != '26.5' ) :
	?>
		<style type="text/css">
			body.single:not(.themesgenerator-front-page) .entry-title{
				font-size: <?php echo $post_title_size; ?>px!important;
			}
		</style>
	<?php
	endif;	
/*End page & post title*/		


	
	
	
	
	
	
	$back_to_top_button_arrow_color = get_theme_mod( 'back_to_top_button_arrow_color' ); 	
	if (( $back_to_top_button_arrow_color != 'inherit' )&&( $back_to_top_button_arrow_color != '' )) :
	?>
		<style type="text/css">
			#backtotopbutton::after {
				color: <?php echo $back_to_top_button_arrow_color; ?>!important;
			}
		</style>
	<?php
	endif;
	
	
	$back_to_top_button_arrow_background = get_theme_mod( 'back_to_top_button_arrow_background' ); 	
	if (( $back_to_top_button_arrow_background != 'inherit' )&&( $back_to_top_button_arrow_background != '' )) :
	?>
		<style type="text/css">
			#backtotopbutton {
				background-color: <?php echo $back_to_top_button_arrow_background; ?>;
			}
		</style>
	<?php
	endif;	
	
	$back_to_top_button_arrow_hover = get_theme_mod( 'back_to_top_button_arrow_hover' ); 	
	if (( $back_to_top_button_arrow_hover != 'inherit' )&&( $back_to_top_button_arrow_hover != '' )) :
	?>
		<style type="text/css">
			#backtotopbutton:hover {
				background-color: <?php echo $back_to_top_button_arrow_hover; ?>;
			}
		</style>
	<?php
	endif;		
	
	
	
	
	
	$footer_widgets_background = get_theme_mod( 'footer_widgets_background' ); 	
	if ( $footer_widgets_background != 'rgba(238,238,238,1)' ) :
	?>
		<style type="text/css">
			.site-footer {
				background-color: <?php echo $footer_widgets_background; ?>!important;
			}
		</style>
	<?php
	endif;



	
	$show_posts_sidebar = get_theme_mod( 'show_posts_sidebar', 'true' ); 
	/*Sidebar function*/ function init_add_sidebar_classes_to_body2($classes = ""){		$classes[] = "has-sidebar";    return $classes;}	
	if ( $show_posts_sidebar === true ) {
		add_filter("body_class", "init_add_sidebar_classes_to_body2");		
	}
	if ( $show_posts_sidebar === false ) {
		remove_filter("body_class", "init_add_sidebar_classes_to_body2");
		remove_filter("body_class", "init_add_sidebar_classes_to_body");
	}

	
}	
add_action( 'wp_head', 'tg_sitelayout_head_styles' );

function shop_cat_sidebar() {
	get_sidebar();
}
add_action( 'woocommerce_after_shop_loop', 'shop_cat_sidebar', 2);




/*******************************/
/*Translate customizer strings*/
/*****************************/
function youruniqueprefix_filter_gettext( $translated, $original, $domain ) {
 
    // This is an array of original strings
    // and what they should be replaced with
    $strings = array(
        'Your latest posts' => 'Themes Generator',
        'Howdy, %1$s' => 'Greetings, %1$s!',
        // Add some more strings here
    );
 
    // See if the current string is in the $strings array
    // If so, replace it's translation
    if ( isset( $strings[$original] ) ) {
        // This accomplishes the same thing as __()
        // but without running it through the filter again
        $translations = get_translations_for_domain( $domain );
        $translated = $translations->translate( $strings[$original] );
    }
 
    return $translated;
}
 
add_filter( 'gettext', 'youruniqueprefix_filter_gettext', 10, 3 );






// Wrap all categories in a function
function wcat2() {
    $out = array();
    $categories = get_categories();
	$out['showallcategories'] = 'all';
    foreach( $categories as $category ) {
		/*
        $out[$category->term_id] = array(
            'label' => $category->slug,
            'value' => $category->term_id
        );
		*/
		
		 $out[$category->slug] = $category->slug;
    }
    //return array('options'=>$out);
    return $out;
}


function wpse55748_filter_post_thumbnail_html( $html ) {
    // If there is no post thumbnail,
    // Return a default image
    if ( '' == $html ) {
        /*return '<img src="' . get_template_directory_uri() . '/images/no-photo-available.svg" class="image-size-name" />';*/
		return '<img src="https://gist.githubusercontent.com/xamdam777/451b47c2f450ff13a21e9930f7ba65ff/raw/cd28ec1bd6647f4fca3177fb35c076f40f151440/no-image.svg?sanitize=true" class="image-size-name" />';
		
    }
    // Else, return the post thumbnail
    return $html;
}
add_filter( 'post_thumbnail_html', 'wpse55748_filter_post_thumbnail_html' );


/*Custom js (tracking code)*/
add_action( 'customize_register', 'tg_tracking_code' );
function tg_tracking_code( $wp_customize ) {	 
		$wp_customize->add_section( 'custom_js', array(
			'title'    => __( 'Additional Code', 'textdomain' ),
			'priority' => 190,
		) );
	 
		$wp_customize->add_setting( 'custom_js', array(
			'type' => 'option',
		) );	 
		$wp_customize->add_control( new WP_Customize_Code_Editor_Control( $wp_customize, 'custom_html', array(
			'label'     => 'Tracking Code',
			'code_type' => 'javascript',
			'settings'  => 'custom_js',
			'section'   => 'custom_js',
		) ) );	 
	}	 
add_action( 'wp_footer', 'prefix_customize_output' );
function prefix_customize_output() {	 
		$js = get_option( 'custom_js', '' );	 
		if ( '' === $js ) {	 
			return;	 
		} 
		echo $js . "\n";
	}
	
/*Activate TG front page after install*/	
function themename_after_setup_theme() {
 $site_type = get_option('show_on_front');
 if($site_type == 'page') {
  update_option( 'show_on_front', 'posts' );
 }
}
add_action( 'after_switch_theme', 'themename_after_setup_theme' );	























/* Page & post settings (title, todo...) */
function themesgenerator_metabox_get_meta( $value ) {
	global $post;
	$field = get_post_meta( $post->ID, $value, true );
	if ( ! empty( $field ) ) {
		return is_array( $field ) ? stripslashes_deep( $field ) : stripslashes( wp_kses_decode_entities( $field ) );
	} else {
		return false;
	}
}

function themesgenerator_metabox_add_meta_box() {
	add_meta_box(
		'themesgenerator_metabox-custom-metabox',
		__( 'Page extra options', 'themesgenerator' ),
		'themesgenerator_metabox_html',
		'page',
		'normal',
		'default'
	);
}
add_action( 'add_meta_boxes', 'themesgenerator_metabox_add_meta_box' );
function themesgenerator_metabox_html( $post) {
	wp_nonce_field( '_themesgenerator_metabox_nonce', 'themesgenerator_metabox_nonce' ); ?>
	<p> <label style="display: block;" for="custom_metabox_show_title"><?php _e( 'Show the page title in the frontend', 'themesgenerator' ); ?></label><br>
		<select name="custom_metabox_show_title" id="custom_metabox_show_title">
			<option value="block" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_title' ) === 'block' ) ? 'selected' : '' ?>>Yes</option>
			<option value="none" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_title' ) === 'none' ) ? 'selected' : '' ?>>No</option>
		</select>
	</p>	
<?php
}
function themesgenerator_metabox_showpostmeta_html() {
	add_meta_box(
		'themesgenerator_metabox-custom-metabox-postmeta',
		__( 'Post extra options', 'themesgenerator' ),
		'themesgenerator_postmetabox_html',
		'post',
		'normal',
		'default'
	);
}
add_action( 'add_meta_boxes', 'themesgenerator_metabox_showpostmeta_html' );
function themesgenerator_postmetabox_html($post) {
	wp_nonce_field( '_themesgenerator_metabox_noncepost', 'themesgenerator_metabox_noncepost' ); ?>
	<p> 
	<label style="display: block;" for="custom_metabox_show_titlepost"><?php _e( 'Show the post title in the frontend', 'themesgenerator' ); ?></label><br>
		<select name="custom_metabox_show_titlepost" id="custom_metabox_show_titlepost">
			<option value="block" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_titlepost' ) === 'block' ) ? 'selected' : '' ?>>Yes</option>
			<option value="none" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_titlepost' ) === 'none' ) ? 'selected' : '' ?>>No</option>
		</select>
	</p>
	<p> <label style="display: block;" for="custom_metabox_show_metapost"><?php _e( 'Show the post meta data (date & author) in the frontend', 'themesgenerator' ); ?></label><br>
		<select name="custom_metabox_show_metapost" id="custom_metabox_show_metapost">
			<option value="block" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_metapost' ) === 'block' ) ? 'selected' : '' ?>>Yes</option>
			<option value="none" <?php echo (themesgenerator_metabox_get_meta( 'custom_metabox_show_metapost' ) === 'none' ) ? 'selected' : '' ?>>No</option>
		</select>
	</p>	
<?php
}
function themesgenerator_metabox_save( $post_id ) {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;		
	if (( ! isset( $_POST['themesgenerator_metabox_nonce'] ) || ! wp_verify_nonce( $_POST['themesgenerator_metabox_nonce'], '_themesgenerator_metabox_nonce' ) )&&( ! isset( $_POST['themesgenerator_metabox_noncepost'] ) || ! wp_verify_nonce( $_POST['themesgenerator_metabox_noncepost'], '_themesgenerator_metabox_noncepost' ) )) return;		
	if ( ! current_user_can( 'edit_post', $post_id ) ) return;	
	if ( isset( $_POST['custom_metabox_show_title'] ) )	update_post_meta( $post_id, 'custom_metabox_show_title', esc_attr( $_POST['custom_metabox_show_title'] ) );
	if ( isset( $_POST['custom_metabox_show_titlepost'] ) )	update_post_meta( $post_id, 'custom_metabox_show_titlepost', esc_attr( $_POST['custom_metabox_show_titlepost'] ) );	
	if ( isset( $_POST['custom_metabox_show_metapost'] ) )	update_post_meta( $post_id, 'custom_metabox_show_metapost', esc_attr( $_POST['custom_metabox_show_metapost'] ) );
}
add_action( 'save_post', 'themesgenerator_metabox_save' );






/**
 * Include the TGM_Plugin_Activation class for Easy Theme and Plugin Upgrades
 */
require_once dirname( __FILE__ ) . '/inc/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'my_theme_register_required_pluginsEasyUpgrades' );
function my_theme_register_required_pluginsEasyUpgrades() {
	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		/** This is an example of how to include a plugin pre-packaged with a theme */
		/*
		array(
			'name'     => 'TGM Example Plugin', // The plugin name
			'slug'     => 'tgm-example-plugin', // The plugin slug (typically the folder name)
			'source'   => get_stylesheet_directory() . '/lib/plugins/tgm-example-plugin.zip', // The plugin source
			'required' => false,
		),
		*/
		/** This is an example of how to include a plugin from the WordPress Plugin Repository */
		array(
			'name' => 'Easy Theme and Plugin Upgrades',
			'slug' => 'easy-theme-and-plugin-upgrades',
		)
	);
	/** Change this to your theme text domain, used for internationalising strings */
	$theme_text_domain = 'themesgenerator';
	/**
	 * Array of configuration settings. Uncomment and amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * uncomment the strings and domain.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		/*'domain'       => $theme_text_domain,         // Text domain - likely want to be the same as your theme. */
		/*'default_path' => '',                         // Default absolute path to pre-packaged plugins */
		/*'menu'         => 'install-my-theme-plugins', // Menu slug */
		'strings'      	 => array(
			/*'page_title'             => __( 'Install Required Plugins', $theme_text_domain ), // */
			/*'menu_title'             => __( 'Install Plugins', $theme_text_domain ), // */
			/*'instructions_install'   => __( 'The %1$s plugin is required for this theme. Click on the big blue button below to install and activate %1$s.', $theme_text_domain ), // %1$s = plugin name */
			/*'instructions_activate'  => __( 'The %1$s is installed but currently inactive. Please go to the <a href="%2$s">plugin administration page</a> page to activate it.', $theme_text_domain ), // %1$s = plugin name, %2$s = plugins page URL */
			/*'button'                 => __( 'Install %s Now', $theme_text_domain ), // %1$s = plugin name */
			/*'installing'             => __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name */
			/*'oops'                   => __( 'Something went wrong with the plugin API.', $theme_text_domain ), // */
			/*'notice_can_install'     => __( 'This theme requires the %1$s plugin. <a href="%2$s"><strong>Click here to begin the installation process</strong></a>. You may be asked for FTP credentials based on your server setup.', $theme_text_domain ), // %1$s = plugin name, %2$s = TGMPA page URL */
			/*'notice_cannot_install'  => __( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', $theme_text_domain ), // %1$s = plugin name */
			/*'notice_can_activate'    => __( 'This theme requires the %1$s plugin. That plugin is currently inactive, so please go to the <a href="%2$s">plugin administration page</a> to activate it.', $theme_text_domain ), // %1$s = plugin name, %2$s = plugins page URL */
			/*'notice_cannot_activate' => __( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', $theme_text_domain ), // %1$s = plugin name */
			/*'return'                 => __( 'Return to Required Plugins Installer', $theme_text_domain ), // */
		),
	);
	tgmpa( $plugins, $config );
}
add_action( "customize_register", "themesgenchild_register_theme_customizer"); function themesgenchild_register_theme_customizer( $wp_customize ) {	$wp_customize->add_panel( "text_blocks", array(	"priority" => 69, "theme_supports" => "", "title" => __( "Text Blocks", "themesgenerator" ), "description" => __( "Set editable text for certain content.", "themesgenerator" ),)); function sanitize_text( $text ) { $allowed_html = array("a" => array( "href" => array(), "title" => array(), "target" => array(),"class" => array(), "id" => array() ), "span" => array( "class" => array(), "id" => array() ), "br" => array(), "em" => array(), "strong" => array(),); return wp_kses( $text, $allowed_html ); } 
$wp_customize->add_section( "customtgtext-1" , array("title" => __("Change Text 1","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-1", array( "default" => __( "Lawyers with passion", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-1", array( "label"    => __( "Text 1", "themesgenerator" ), "section"  => "customtgtext-1", "settings" => "tgtext-1", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-1", array("selector" => "#tgtext-1",));

$wp_customize->add_section( "customtgtext-2" , array("title" => __("Change Text 2","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-2", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-2", array( "label"    => __( "Text 2", "themesgenerator" ), "section"  => "customtgtext-2", "settings" => "tgtext-2", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-2", array("selector" => "#tgtext-2",));

$wp_customize->add_section( "customtgtext-3" , array("title" => __("Change Text 3","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-3", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-3", array( "label"    => __( "Text 3", "themesgenerator" ), "section"  => "customtgtext-3", "settings" => "tgtext-3", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-3", array("selector" => "#tgtext-3",));

$wp_customize->add_section( "customtgtext-4" , array("title" => __("Change Text 4","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-4", array( "default" => __( "AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-4", array( "label"    => __( "Text 4", "themesgenerator" ), "section"  => "customtgtext-4", "settings" => "tgtext-4", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-4", array("selector" => "#tgtext-4",));

$wp_customize->add_section( "customtgtext-5" , array("title" => __("Change Text 5","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-5", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-5", array( "label"    => __( "Text 5", "themesgenerator" ), "section"  => "customtgtext-5", "settings" => "tgtext-5", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-5", array("selector" => "#tgtext-5",));

$wp_customize->add_section( "customtgtext-6" , array("title" => __("Change Text 6","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-6", array( "default" => __( "SEE MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-6", array( "label"    => __( "Text 6", "themesgenerator" ), "section"  => "customtgtext-6", "settings" => "tgtext-6", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-6", array("selector" => "#tgtext-6",));

$wp_customize->add_section( "customtgtext-7" , array("title" => __("Change Text 7","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-7", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-7", array( "label"    => __( "Text 7", "themesgenerator" ), "section"  => "customtgtext-7", "settings" => "tgtext-7", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-7", array("selector" => "#tgtext-7",));

$wp_customize->add_section( "customtgtext-8" , array("title" => __("Change Text 8","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-8", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-8", array( "label"    => __( "Text 8", "themesgenerator" ), "section"  => "customtgtext-8", "settings" => "tgtext-8", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-8", array("selector" => "#tgtext-8",));

$wp_customize->add_section( "customtgtext-9" , array("title" => __("Change Text 9","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-9", array( "default" => __( "LAWYERS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-9", array( "label"    => __( "Text 9", "themesgenerator" ), "section"  => "customtgtext-9", "settings" => "tgtext-9", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-9", array("selector" => "#tgtext-9",));

$wp_customize->add_section( "customtgtext-10" , array("title" => __("Change Text 10","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-10", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-10", array( "label"    => __( "Text 10", "themesgenerator" ), "section"  => "customtgtext-10", "settings" => "tgtext-10", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-10", array("selector" => "#tgtext-10",));

$wp_customize->add_section( "customtgtext-11" , array("title" => __("Change Text 11","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-11", array( "default" => __( "MAGHREB", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-11", array( "label"    => __( "Text 11", "themesgenerator" ), "section"  => "customtgtext-11", "settings" => "tgtext-11", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-11", array("selector" => "#tgtext-11",));

$wp_customize->add_section( "customtgtext-12" , array("title" => __("Change Text 12","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-12", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-12", array( "label"    => __( "Text 12", "themesgenerator" ), "section"  => "customtgtext-12", "settings" => "tgtext-12", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-12", array("selector" => "#tgtext-12",));

$wp_customize->add_section( "customtgtext-13" , array("title" => __("Change Text 13","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-13", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-13", array( "label"    => __( "Text 13", "themesgenerator" ), "section"  => "customtgtext-13", "settings" => "tgtext-13", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-13", array("selector" => "#tgtext-13",));

$wp_customize->add_section( "customtgtext-14" , array("title" => __("Change Text 14","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-14", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-14", array( "label"    => __( "Text 14", "themesgenerator" ), "section"  => "customtgtext-14", "settings" => "tgtext-14", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-14", array("selector" => "#tgtext-14",));

$wp_customize->add_section( "customtgtext-15" , array("title" => __("Change Text 15","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-15", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-15", array( "label"    => __( "Text 15", "themesgenerator" ), "section"  => "customtgtext-15", "settings" => "tgtext-15", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-15", array("selector" => "#tgtext-15",));

$wp_customize->add_section( "customtgtext-16" , array("title" => __("Change Text 16","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-16", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-16", array( "label"    => __( "Text 16", "themesgenerator" ), "section"  => "customtgtext-16", "settings" => "tgtext-16", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-16", array("selector" => "#tgtext-16",));

$wp_customize->add_section( "customtgtext-17" , array("title" => __("Change Text 17","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-17", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-17", array( "label"    => __( "Text 17", "themesgenerator" ), "section"  => "customtgtext-17", "settings" => "tgtext-17", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-17", array("selector" => "#tgtext-17",));

$wp_customize->add_section( "customtgtext-18" , array("title" => __("Change Text 18","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-18", array( "default" => __( "MASHREK", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-18", array( "label"    => __( "Text 18", "themesgenerator" ), "section"  => "customtgtext-18", "settings" => "tgtext-18", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-18", array("selector" => "#tgtext-18",));

$wp_customize->add_section( "customtgtext-19" , array("title" => __("Change Text 19","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-19", array( "default" => __( "Avocate - Rechtsanwälte ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-19", array( "label"    => __( "Text 19", "themesgenerator" ), "section"  => "customtgtext-19", "settings" => "tgtext-19", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-19", array("selector" => "#tgtext-19",));

$wp_customize->add_section( "customtgtext-20" , array("title" => __("Change Text 20","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-20", array( "default" => __( "Eschenheimer Landstrasse 1", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-20", array( "label"    => __( "Text 20", "themesgenerator" ), "section"  => "customtgtext-20", "settings" => "tgtext-20", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-20", array("selector" => "#tgtext-20",));

$wp_customize->add_section( "customtgtext-21" , array("title" => __("Change Text 21","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-21", array( "default" => __( "D-69316  Frankfurt am Main | GERMANY", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-21", array( "label"    => __( "Text 21", "themesgenerator" ), "section"  => "customtgtext-21", "settings" => "tgtext-21", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-21", array("selector" => "#tgtext-21",));

$wp_customize->add_section( "customtgtext-22" , array("title" => __("Change Text 22","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-22", array( "default" => __( "+20 2 23 91 43 44", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-22", array( "label"    => __( "Text 22", "themesgenerator" ), "section"  => "customtgtext-22", "settings" => "tgtext-22", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-22", array("selector" => "#tgtext-22",));

$wp_customize->add_section( "customtgtext-23" , array("title" => __("Change Text 23","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-23", array( "default" => __( "+49 69 66 42 89 64 ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-23", array( "label"    => __( "Text 23", "themesgenerator" ), "section"  => "customtgtext-23", "settings" => "tgtext-23", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-23", array("selector" => "#tgtext-23",));

$wp_customize->add_section( "customtgtext-24" , array("title" => __("Change Text 24","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-24", array( "default" => __( "ule@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-24", array( "label"    => __( "Text 24", "themesgenerator" ), "section"  => "customtgtext-24", "settings" => "tgtext-24", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-24", array("selector" => "#tgtext-24",));

$wp_customize->add_section( "customtgtext-25" , array("title" => __("Change Text 25","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-25", array( "default" => __( "SEE LOCATIONS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-25", array( "label"    => __( "Text 25", "themesgenerator" ), "section"  => "customtgtext-25", "settings" => "tgtext-25", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-25", array("selector" => "#tgtext-25",));

$wp_customize->add_section( "customtgtext-26" , array("title" => __("Change Text 26","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-26", array( "default" => __( "International Legal Practice", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-26", array( "label"    => __( "Text 26", "themesgenerator" ), "section"  => "customtgtext-26", "settings" => "tgtext-26", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-26", array("selector" => "#tgtext-26",));

$wp_customize->add_section( "customtgtext-27" , array("title" => __("Change Text 27","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-27", array( "default" => __( "INTERNATIONAL LEGAL PRACTICE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-27", array( "label"    => __( "Text 27", "themesgenerator" ), "section"  => "customtgtext-27", "settings" => "tgtext-27", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-27", array("selector" => "#tgtext-27",));

$wp_customize->add_section( "customtgtext-28" , array("title" => __("Change Text 28","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-28", array( "default" => __( "Practice Areas", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-28", array( "label"    => __( "Text 28", "themesgenerator" ), "section"  => "customtgtext-28", "settings" => "tgtext-28", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-28", array("selector" => "#tgtext-28",));

$wp_customize->add_section( "customtgtext-29" , array("title" => __("Change Text 29","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-29", array( "default" => __( "PRACTICE AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-29", array( "label"    => __( "Text 29", "themesgenerator" ), "section"  => "customtgtext-29", "settings" => "tgtext-29", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-29", array("selector" => "#tgtext-29",));

$wp_customize->add_section( "customtgtext-30" , array("title" => __("Change Text 30","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-30", array( "default" => __( "Mergers & Acquisitions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-30", array( "label"    => __( "Text 30", "themesgenerator" ), "section"  => "customtgtext-30", "settings" => "tgtext-30", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-30", array("selector" => "#tgtext-30",));

$wp_customize->add_section( "customtgtext-31" , array("title" => __("Change Text 31","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-31", array( "default" => __( "International Joint Ventures, Cross Border Transactions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-31", array( "label"    => __( "Text 31", "themesgenerator" ), "section"  => "customtgtext-31", "settings" => "tgtext-31", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-31", array("selector" => "#tgtext-31",));

$wp_customize->add_section( "customtgtext-32" , array("title" => __("Change Text 32","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-32", array( "default" => __( "Corporate", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-32", array( "label"    => __( "Text 32", "themesgenerator" ), "section"  => "customtgtext-32", "settings" => "tgtext-32", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-32", array("selector" => "#tgtext-32",));

$wp_customize->add_section( "customtgtext-33" , array("title" => __("Change Text 33","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-33", array( "default" => __( "Business set-up, both onshore and offshore (UAE-Bubai-Free Zones)", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-33", array( "label"    => __( "Text 33", "themesgenerator" ), "section"  => "customtgtext-33", "settings" => "tgtext-33", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-33", array("selector" => "#tgtext-33",));

$wp_customize->add_section( "customtgtext-34" , array("title" => __("Change Text 34","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-34", array( "default" => __( "Foreign Direct Investments", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-34", array( "label"    => __( "Text 34", "themesgenerator" ), "section"  => "customtgtext-34", "settings" => "tgtext-34", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-34", array("selector" => "#tgtext-34",));

$wp_customize->add_section( "customtgtext-35" , array("title" => __("Change Text 35","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-35", array( "default" => __( "Contract law, drafting und reviewing contracts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-35", array( "label"    => __( "Text 35", "themesgenerator" ), "section"  => "customtgtext-35", "settings" => "tgtext-35", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-35", array("selector" => "#tgtext-35",));

$wp_customize->add_section( "customtgtext-36" , array("title" => __("Change Text 36","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-36", array( "default" => __( "Engineering, Construction und Trunkey Projects, in connection with energy and natural resources", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-36", array( "label"    => __( "Text 36", "themesgenerator" ), "section"  => "customtgtext-36", "settings" => "tgtext-36", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-36", array("selector" => "#tgtext-36",));

$wp_customize->add_section( "customtgtext-37" , array("title" => __("Change Text 37","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-37", array( "default" => __( "Energy & Utilities (O&M), Oil & Gas, Renewable Energy, Solar, E&P contracts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-37", array( "label"    => __( "Text 37", "themesgenerator" ), "section"  => "customtgtext-37", "settings" => "tgtext-37", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-37", array("selector" => "#tgtext-37",));

$wp_customize->add_section( "customtgtext-38" , array("title" => __("Change Text 38","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-38", array( "default" => __( "Technology Transfer (trademarks, Know-how, technical assistance), License Agreements", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-38", array( "label"    => __( "Text 38", "themesgenerator" ), "section"  => "customtgtext-38", "settings" => "tgtext-38", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-38", array("selector" => "#tgtext-38",));

$wp_customize->add_section( "customtgtext-39" , array("title" => __("Change Text 39","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-39", array( "default" => __( "Project Finance, Structured Trade & Export Finance", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-39", array( "label"    => __( "Text 39", "themesgenerator" ), "section"  => "customtgtext-39", "settings" => "tgtext-39", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-39", array("selector" => "#tgtext-39",));

$wp_customize->add_section( "customtgtext-40" , array("title" => __("Change Text 40","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-40", array( "default" => __( "International trade law", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-40", array( "label"    => __( "Text 40", "themesgenerator" ), "section"  => "customtgtext-40", "settings" => "tgtext-40", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-40", array("selector" => "#tgtext-40",));

$wp_customize->add_section( "customtgtext-41" , array("title" => __("Change Text 41","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-41", array( "default" => __( "Commercial Agencies & Distributorships", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-41", array( "label"    => __( "Text 41", "themesgenerator" ), "section"  => "customtgtext-41", "settings" => "tgtext-41", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-41", array("selector" => "#tgtext-41",));

$wp_customize->add_section( "customtgtext-42" , array("title" => __("Change Text 42","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-42", array( "default" => __( "Employment", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-42", array( "label"    => __( "Text 42", "themesgenerator" ), "section"  => "customtgtext-42", "settings" => "tgtext-42", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-42", array("selector" => "#tgtext-42",));

$wp_customize->add_section( "customtgtext-43" , array("title" => __("Change Text 43","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-43", array( "default" => __( "Export control & international sanctions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-43", array( "label"    => __( "Text 43", "themesgenerator" ), "section"  => "customtgtext-43", "settings" => "tgtext-43", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-43", array("selector" => "#tgtext-43",));

$wp_customize->add_section( "customtgtext-44" , array("title" => __("Change Text 44","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-44", array( "default" => __( "Public Tenders", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-44", array( "label"    => __( "Text 44", "themesgenerator" ), "section"  => "customtgtext-44", "settings" => "tgtext-44", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-44", array("selector" => "#tgtext-44",));

$wp_customize->add_section( "customtgtext-45" , array("title" => __("Change Text 45","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-45", array( "default" => __( "Corporate, Compliance, Internal Investigations, White Collar Crime", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-45", array( "label"    => __( "Text 45", "themesgenerator" ), "section"  => "customtgtext-45", "settings" => "tgtext-45", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-45", array("selector" => "#tgtext-45",));

$wp_customize->add_section( "customtgtext-46" , array("title" => __("Change Text 46","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-46", array( "default" => __( "Corporate Structuring & Insolvency", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-46", array( "label"    => __( "Text 46", "themesgenerator" ), "section"  => "customtgtext-46", "settings" => "tgtext-46", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-46", array("selector" => "#tgtext-46",));

$wp_customize->add_section( "customtgtext-47" , array("title" => __("Change Text 47","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-47", array( "default" => __( "International Tax Law (Double Taxation Treaties) and Custums", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-47", array( "label"    => __( "Text 47", "themesgenerator" ), "section"  => "customtgtext-47", "settings" => "tgtext-47", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-47", array("selector" => "#tgtext-47",));

$wp_customize->add_section( "customtgtext-48" , array("title" => __("Change Text 48","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-48", array( "default" => __( "Multi-jurisdictional dispute resolution, mediation", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-48", array( "label"    => __( "Text 48", "themesgenerator" ), "section"  => "customtgtext-48", "settings" => "tgtext-48", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-48", array("selector" => "#tgtext-48",));

$wp_customize->add_section( "customtgtext-49" , array("title" => __("Change Text 49","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-49", array( "default" => __( "International arbitation, transnational ligation and DIFC Courts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-49", array( "label"    => __( "Text 49", "themesgenerator" ), "section"  => "customtgtext-49", "settings" => "tgtext-49", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-49", array("selector" => "#tgtext-49",));

$wp_customize->add_section( "customtgtext-50" , array("title" => __("Change Text 50","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-50", array( "default" => __( "EXPERIENCE BY COUNTRY", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-50", array( "label"    => __( "Text 50", "themesgenerator" ), "section"  => "customtgtext-50", "settings" => "tgtext-50", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-50", array("selector" => "#tgtext-50",));

$wp_customize->add_section( "customtgtext-51" , array("title" => __("Change Text 51","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-51", array( "default" => __( "EGYPT", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-51", array( "label"    => __( "Text 51", "themesgenerator" ), "section"  => "customtgtext-51", "settings" => "tgtext-51", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-51", array("selector" => "#tgtext-51",));

$wp_customize->add_section( "customtgtext-52" , array("title" => __("Change Text 52","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-52", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-52", array( "label"    => __( "Text 52", "themesgenerator" ), "section"  => "customtgtext-52", "settings" => "tgtext-52", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-52", array("selector" => "#tgtext-52",));

$wp_customize->add_section( "customtgtext-53" , array("title" => __("Change Text 53","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-53", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-53", array( "label"    => __( "Text 53", "themesgenerator" ), "section"  => "customtgtext-53", "settings" => "tgtext-53", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-53", array("selector" => "#tgtext-53",));

$wp_customize->add_section( "customtgtext-54" , array("title" => __("Change Text 54","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-54", array( "default" => __( "TANGER", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-54", array( "label"    => __( "Text 54", "themesgenerator" ), "section"  => "customtgtext-54", "settings" => "tgtext-54", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-54", array("selector" => "#tgtext-54",));

$wp_customize->add_section( "customtgtext-55" , array("title" => __("Change Text 55","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-55", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-55", array( "label"    => __( "Text 55", "themesgenerator" ), "section"  => "customtgtext-55", "settings" => "tgtext-55", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-55", array("selector" => "#tgtext-55",));

$wp_customize->add_section( "customtgtext-56" , array("title" => __("Change Text 56","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-56", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-56", array( "label"    => __( "Text 56", "themesgenerator" ), "section"  => "customtgtext-56", "settings" => "tgtext-56", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-56", array("selector" => "#tgtext-56",));

$wp_customize->add_section( "customtgtext-57" , array("title" => __("Change Text 57","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-57", array( "default" => __( "DUBAI", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-57", array( "label"    => __( "Text 57", "themesgenerator" ), "section"  => "customtgtext-57", "settings" => "tgtext-57", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-57", array("selector" => "#tgtext-57",));

$wp_customize->add_section( "customtgtext-58" , array("title" => __("Change Text 58","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-58", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-58", array( "label"    => __( "Text 58", "themesgenerator" ), "section"  => "customtgtext-58", "settings" => "tgtext-58", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-58", array("selector" => "#tgtext-58",));

$wp_customize->add_section( "customtgtext-59" , array("title" => __("Change Text 59","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-59", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-59", array( "label"    => __( "Text 59", "themesgenerator" ), "section"  => "customtgtext-59", "settings" => "tgtext-59", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-59", array("selector" => "#tgtext-59",));

$wp_customize->add_section( "customtgtext-60" , array("title" => __("Change Text 60","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-60", array( "default" => __( "EGYPT", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-60", array( "label"    => __( "Text 60", "themesgenerator" ), "section"  => "customtgtext-60", "settings" => "tgtext-60", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-60", array("selector" => "#tgtext-60",));

$wp_customize->add_section( "customtgtext-61" , array("title" => __("Change Text 61","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-61", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-61", array( "label"    => __( "Text 61", "themesgenerator" ), "section"  => "customtgtext-61", "settings" => "tgtext-61", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-61", array("selector" => "#tgtext-61",));

$wp_customize->add_section( "customtgtext-62" , array("title" => __("Change Text 62","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-62", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-62", array( "label"    => __( "Text 62", "themesgenerator" ), "section"  => "customtgtext-62", "settings" => "tgtext-62", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-62", array("selector" => "#tgtext-62",));

$wp_customize->add_section( "customtgtext-63" , array("title" => __("Change Text 63","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-63", array( "default" => __( "TANGER", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-63", array( "label"    => __( "Text 63", "themesgenerator" ), "section"  => "customtgtext-63", "settings" => "tgtext-63", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-63", array("selector" => "#tgtext-63",));

$wp_customize->add_section( "customtgtext-64" , array("title" => __("Change Text 64","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-64", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-64", array( "label"    => __( "Text 64", "themesgenerator" ), "section"  => "customtgtext-64", "settings" => "tgtext-64", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-64", array("selector" => "#tgtext-64",));

$wp_customize->add_section( "customtgtext-65" , array("title" => __("Change Text 65","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-65", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-65", array( "label"    => __( "Text 65", "themesgenerator" ), "section"  => "customtgtext-65", "settings" => "tgtext-65", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-65", array("selector" => "#tgtext-65",));

$wp_customize->add_section( "customtgtext-66" , array("title" => __("Change Text 66","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-66", array( "default" => __( "DUBAI", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-66", array( "label"    => __( "Text 66", "themesgenerator" ), "section"  => "customtgtext-66", "settings" => "tgtext-66", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-66", array("selector" => "#tgtext-66",));

$wp_customize->add_section( "customtgtext-67" , array("title" => __("Change Text 67","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-67", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-67", array( "label"    => __( "Text 67", "themesgenerator" ), "section"  => "customtgtext-67", "settings" => "tgtext-67", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-67", array("selector" => "#tgtext-67",));

$wp_customize->add_section( "customtgtext-68" , array("title" => __("Change Text 68","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-68", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-68", array( "label"    => __( "Text 68", "themesgenerator" ), "section"  => "customtgtext-68", "settings" => "tgtext-68", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-68", array("selector" => "#tgtext-68",));

$wp_customize->add_section( "customtgtext-69" , array("title" => __("Change Text 69","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-69", array( "default" => __( "Team", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-69", array( "label"    => __( "Text 69", "themesgenerator" ), "section"  => "customtgtext-69", "settings" => "tgtext-69", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-69", array("selector" => "#tgtext-69",));

$wp_customize->add_section( "customtgtext-70" , array("title" => __("Change Text 70","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-70", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-70", array( "label"    => __( "Text 70", "themesgenerator" ), "section"  => "customtgtext-70", "settings" => "tgtext-70", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-70", array("selector" => "#tgtext-70",));

$wp_customize->add_section( "customtgtext-71" , array("title" => __("Change Text 71","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-71", array( "default" => __( "Offices", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-71", array( "label"    => __( "Text 71", "themesgenerator" ), "section"  => "customtgtext-71", "settings" => "tgtext-71", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-71", array("selector" => "#tgtext-71",));

$wp_customize->add_section( "customtgtext-72" , array("title" => __("Change Text 72","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-72", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-72", array( "label"    => __( "Text 72", "themesgenerator" ), "section"  => "customtgtext-72", "settings" => "tgtext-72", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-72", array("selector" => "#tgtext-72",));

$wp_customize->add_section( "customtgtext-73" , array("title" => __("Change Text 73","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-73", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-73", array( "label"    => __( "Text 73", "themesgenerator" ), "section"  => "customtgtext-73", "settings" => "tgtext-73", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-73", array("selector" => "#tgtext-73",));

$wp_customize->add_section( "customtgtext-74" , array("title" => __("Change Text 74","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-74", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-74", array( "label"    => __( "Text 74", "themesgenerator" ), "section"  => "customtgtext-74", "settings" => "tgtext-74", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-74", array("selector" => "#tgtext-74",));

$wp_customize->add_section( "customtgtext-75" , array("title" => __("Change Text 75","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-75", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-75", array( "label"    => __( "Text 75", "themesgenerator" ), "section"  => "customtgtext-75", "settings" => "tgtext-75", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-75", array("selector" => "#tgtext-75",));

$wp_customize->add_section( "customtgtext-76" , array("title" => __("Change Text 76","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-76", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-76", array( "label"    => __( "Text 76", "themesgenerator" ), "section"  => "customtgtext-76", "settings" => "tgtext-76", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-76", array("selector" => "#tgtext-76",));

$wp_customize->add_section( "customtgtext-77" , array("title" => __("Change Text 77","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-77", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-77", array( "label"    => __( "Text 77", "themesgenerator" ), "section"  => "customtgtext-77", "settings" => "tgtext-77", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-77", array("selector" => "#tgtext-77",));

$wp_customize->add_section( "customtgtext-78" , array("title" => __("Change Text 78","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-78", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-78", array( "label"    => __( "Text 78", "themesgenerator" ), "section"  => "customtgtext-78", "settings" => "tgtext-78", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-78", array("selector" => "#tgtext-78",));

$wp_customize->add_section( "customtgtext-79" , array("title" => __("Change Text 79","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-79", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-79", array( "label"    => __( "Text 79", "themesgenerator" ), "section"  => "customtgtext-79", "settings" => "tgtext-79", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-79", array("selector" => "#tgtext-79",));

$wp_customize->add_section( "customtgtext-80" , array("title" => __("Change Text 80","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-80", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-80", array( "label"    => __( "Text 80", "themesgenerator" ), "section"  => "customtgtext-80", "settings" => "tgtext-80", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-80", array("selector" => "#tgtext-80",));

$wp_customize->add_section( "customtgtext-81" , array("title" => __("Change Text 81","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-81", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-81", array( "label"    => __( "Text 81", "themesgenerator" ), "section"  => "customtgtext-81", "settings" => "tgtext-81", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-81", array("selector" => "#tgtext-81",));

$wp_customize->add_section( "customtgtext-82" , array("title" => __("Change Text 82","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-82", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-82", array( "label"    => __( "Text 82", "themesgenerator" ), "section"  => "customtgtext-82", "settings" => "tgtext-82", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-82", array("selector" => "#tgtext-82",));

$wp_customize->add_section( "customtgtext-83" , array("title" => __("Change Text 83","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-83", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-83", array( "label"    => __( "Text 83", "themesgenerator" ), "section"  => "customtgtext-83", "settings" => "tgtext-83", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-83", array("selector" => "#tgtext-83",));

$wp_customize->add_section( "customtgtext-84" , array("title" => __("Change Text 84","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-84", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-84", array( "label"    => __( "Text 84", "themesgenerator" ), "section"  => "customtgtext-84", "settings" => "tgtext-84", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-84", array("selector" => "#tgtext-84",));

$wp_customize->add_section( "customtgtext-85" , array("title" => __("Change Text 85","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-85", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-85", array( "label"    => __( "Text 85", "themesgenerator" ), "section"  => "customtgtext-85", "settings" => "tgtext-85", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-85", array("selector" => "#tgtext-85",));

$wp_customize->add_section( "customtgtext-86" , array("title" => __("Change Text 86","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-86", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-86", array( "label"    => __( "Text 86", "themesgenerator" ), "section"  => "customtgtext-86", "settings" => "tgtext-86", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-86", array("selector" => "#tgtext-86",));

$wp_customize->add_section( "customtgtext-87" , array("title" => __("Change Text 87","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-87", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-87", array( "label"    => __( "Text 87", "themesgenerator" ), "section"  => "customtgtext-87", "settings" => "tgtext-87", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-87", array("selector" => "#tgtext-87",));

$wp_customize->add_section( "customtgtext-88" , array("title" => __("Change Text 88","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-88", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-88", array( "label"    => __( "Text 88", "themesgenerator" ), "section"  => "customtgtext-88", "settings" => "tgtext-88", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-88", array("selector" => "#tgtext-88",));

$wp_customize->add_section( "customtgtext-89" , array("title" => __("Change Text 89","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-89", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-89", array( "label"    => __( "Text 89", "themesgenerator" ), "section"  => "customtgtext-89", "settings" => "tgtext-89", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-89", array("selector" => "#tgtext-89",));

$wp_customize->add_section( "customtgtext-90" , array("title" => __("Change Text 90","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-90", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-90", array( "label"    => __( "Text 90", "themesgenerator" ), "section"  => "customtgtext-90", "settings" => "tgtext-90", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-90", array("selector" => "#tgtext-90",));

$wp_customize->add_section( "customtgtext-91" , array("title" => __("Change Text 91","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-91", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-91", array( "label"    => __( "Text 91", "themesgenerator" ), "section"  => "customtgtext-91", "settings" => "tgtext-91", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-91", array("selector" => "#tgtext-91",));

$wp_customize->add_section( "customtgtext-92" , array("title" => __("Change Text 92","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-92", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-92", array( "label"    => __( "Text 92", "themesgenerator" ), "section"  => "customtgtext-92", "settings" => "tgtext-92", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-92", array("selector" => "#tgtext-92",));

$wp_customize->add_section( "customtgtext-93" , array("title" => __("Change Text 93","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-93", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-93", array( "label"    => __( "Text 93", "themesgenerator" ), "section"  => "customtgtext-93", "settings" => "tgtext-93", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-93", array("selector" => "#tgtext-93",));

$wp_customize->add_section( "customtgtext-94" , array("title" => __("Change Text 94","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-94", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-94", array( "label"    => __( "Text 94", "themesgenerator" ), "section"  => "customtgtext-94", "settings" => "tgtext-94", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-94", array("selector" => "#tgtext-94",));

$wp_customize->add_section( "customtgtext-95" , array("title" => __("Change Text 95","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-95", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-95", array( "label"    => __( "Text 95", "themesgenerator" ), "section"  => "customtgtext-95", "settings" => "tgtext-95", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-95", array("selector" => "#tgtext-95",));

$wp_customize->add_section( "customtgtext-96" , array("title" => __("Change Text 96","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-96", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-96", array( "label"    => __( "Text 96", "themesgenerator" ), "section"  => "customtgtext-96", "settings" => "tgtext-96", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-96", array("selector" => "#tgtext-96",));

$wp_customize->add_section( "customtgtext-97" , array("title" => __("Change Text 97","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-97", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-97", array( "label"    => __( "Text 97", "themesgenerator" ), "section"  => "customtgtext-97", "settings" => "tgtext-97", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-97", array("selector" => "#tgtext-97",));

$wp_customize->add_section( "customtgtext-98" , array("title" => __("Change Text 98","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-98", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-98", array( "label"    => __( "Text 98", "themesgenerator" ), "section"  => "customtgtext-98", "settings" => "tgtext-98", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-98", array("selector" => "#tgtext-98",));

$wp_customize->add_section( "customtgtext-99" , array("title" => __("Change Text 99","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-99", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-99", array( "label"    => __( "Text 99", "themesgenerator" ), "section"  => "customtgtext-99", "settings" => "tgtext-99", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-99", array("selector" => "#tgtext-99",));

$wp_customize->add_section( "customtgtext-100" , array("title" => __("Change Text 100","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-100", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-100", array( "label"    => __( "Text 100", "themesgenerator" ), "section"  => "customtgtext-100", "settings" => "tgtext-100", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-100", array("selector" => "#tgtext-100",));

$wp_customize->add_section( "customtgtext-101" , array("title" => __("Change Text 101","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-101", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-101", array( "label"    => __( "Text 101", "themesgenerator" ), "section"  => "customtgtext-101", "settings" => "tgtext-101", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-101", array("selector" => "#tgtext-101",));

$wp_customize->add_section( "customtgtext-102" , array("title" => __("Change Text 102","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-102", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-102", array( "label"    => __( "Text 102", "themesgenerator" ), "section"  => "customtgtext-102", "settings" => "tgtext-102", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-102", array("selector" => "#tgtext-102",));

$wp_customize->add_section( "customtgtext-103" , array("title" => __("Change Text 103","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-103", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-103", array( "label"    => __( "Text 103", "themesgenerator" ), "section"  => "customtgtext-103", "settings" => "tgtext-103", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-103", array("selector" => "#tgtext-103",));

$wp_customize->add_section( "customtgtext-104" , array("title" => __("Change Text 104","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-104", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-104", array( "label"    => __( "Text 104", "themesgenerator" ), "section"  => "customtgtext-104", "settings" => "tgtext-104", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-104", array("selector" => "#tgtext-104",));

$wp_customize->add_section( "customtgtext-105" , array("title" => __("Change Text 105","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-105", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-105", array( "label"    => __( "Text 105", "themesgenerator" ), "section"  => "customtgtext-105", "settings" => "tgtext-105", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-105", array("selector" => "#tgtext-105",));

$wp_customize->add_section( "customtgtext-106" , array("title" => __("Change Text 106","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-106", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-106", array( "label"    => __( "Text 106", "themesgenerator" ), "section"  => "customtgtext-106", "settings" => "tgtext-106", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-106", array("selector" => "#tgtext-106",));

$wp_customize->add_section( "customtgtext-107" , array("title" => __("Change Text 107","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-107", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-107", array( "label"    => __( "Text 107", "themesgenerator" ), "section"  => "customtgtext-107", "settings" => "tgtext-107", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-107", array("selector" => "#tgtext-107",));

$wp_customize->add_section( "customtgtext-108" , array("title" => __("Change Text 108","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-108", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-108", array( "label"    => __( "Text 108", "themesgenerator" ), "section"  => "customtgtext-108", "settings" => "tgtext-108", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-108", array("selector" => "#tgtext-108",));

$wp_customize->add_section( "customtgtext-109" , array("title" => __("Change Text 109","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-109", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-109", array( "label"    => __( "Text 109", "themesgenerator" ), "section"  => "customtgtext-109", "settings" => "tgtext-109", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-109", array("selector" => "#tgtext-109",));

$wp_customize->add_section( "customtgtext-110" , array("title" => __("Change Text 110","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-110", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-110", array( "label"    => __( "Text 110", "themesgenerator" ), "section"  => "customtgtext-110", "settings" => "tgtext-110", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-110", array("selector" => "#tgtext-110",));

$wp_customize->add_section( "customtgtext-111" , array("title" => __("Change Text 111","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-111", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-111", array( "label"    => __( "Text 111", "themesgenerator" ), "section"  => "customtgtext-111", "settings" => "tgtext-111", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-111", array("selector" => "#tgtext-111",));

$wp_customize->add_section( "customtgtext-112" , array("title" => __("Change Text 112","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-112", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-112", array( "label"    => __( "Text 112", "themesgenerator" ), "section"  => "customtgtext-112", "settings" => "tgtext-112", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-112", array("selector" => "#tgtext-112",));

$wp_customize->add_section( "customtgtext-113" , array("title" => __("Change Text 113","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-113", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-113", array( "label"    => __( "Text 113", "themesgenerator" ), "section"  => "customtgtext-113", "settings" => "tgtext-113", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-113", array("selector" => "#tgtext-113",));

$wp_customize->add_section( "customtgtext-114" , array("title" => __("Change Text 114","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-114", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-114", array( "label"    => __( "Text 114", "themesgenerator" ), "section"  => "customtgtext-114", "settings" => "tgtext-114", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-114", array("selector" => "#tgtext-114",));

$wp_customize->add_section( "customtgtext-115" , array("title" => __("Change Text 115","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-115", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-115", array( "label"    => __( "Text 115", "themesgenerator" ), "section"  => "customtgtext-115", "settings" => "tgtext-115", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-115", array("selector" => "#tgtext-115",));

$wp_customize->add_section( "customtgtext-116" , array("title" => __("Change Text 116","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-116", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-116", array( "label"    => __( "Text 116", "themesgenerator" ), "section"  => "customtgtext-116", "settings" => "tgtext-116", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-116", array("selector" => "#tgtext-116",));

$wp_customize->add_section( "customtgtext-117" , array("title" => __("Change Text 117","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-117", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-117", array( "label"    => __( "Text 117", "themesgenerator" ), "section"  => "customtgtext-117", "settings" => "tgtext-117", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-117", array("selector" => "#tgtext-117",));

$wp_customize->add_section( "customtgtext-118" , array("title" => __("Change Text 118","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-118", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-118", array( "label"    => __( "Text 118", "themesgenerator" ), "section"  => "customtgtext-118", "settings" => "tgtext-118", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-118", array("selector" => "#tgtext-118",));

$wp_customize->add_section( "customtgtext-119" , array("title" => __("Change Text 119","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-119", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-119", array( "label"    => __( "Text 119", "themesgenerator" ), "section"  => "customtgtext-119", "settings" => "tgtext-119", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-119", array("selector" => "#tgtext-119",));

$wp_customize->add_section( "customtgtext-120" , array("title" => __("Change Text 120","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-120", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-120", array( "label"    => __( "Text 120", "themesgenerator" ), "section"  => "customtgtext-120", "settings" => "tgtext-120", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-120", array("selector" => "#tgtext-120",));

$wp_customize->add_section( "customtgtext-121" , array("title" => __("Change Text 121","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-121", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-121", array( "label"    => __( "Text 121", "themesgenerator" ), "section"  => "customtgtext-121", "settings" => "tgtext-121", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-121", array("selector" => "#tgtext-121",));

$wp_customize->add_section( "customtgtext-122" , array("title" => __("Change Text 122","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-122", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-122", array( "label"    => __( "Text 122", "themesgenerator" ), "section"  => "customtgtext-122", "settings" => "tgtext-122", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-122", array("selector" => "#tgtext-122",));

$wp_customize->add_section( "customtgtext-123" , array("title" => __("Change Text 123","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-123", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-123", array( "label"    => __( "Text 123", "themesgenerator" ), "section"  => "customtgtext-123", "settings" => "tgtext-123", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-123", array("selector" => "#tgtext-123",));

$wp_customize->add_section( "customtgtext-124" , array("title" => __("Change Text 124","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-124", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-124", array( "label"    => __( "Text 124", "themesgenerator" ), "section"  => "customtgtext-124", "settings" => "tgtext-124", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-124", array("selector" => "#tgtext-124",));

$wp_customize->add_section( "customtgtext-125" , array("title" => __("Change Text 125","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-125", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-125", array( "label"    => __( "Text 125", "themesgenerator" ), "section"  => "customtgtext-125", "settings" => "tgtext-125", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-125", array("selector" => "#tgtext-125",));

$wp_customize->add_section( "customtgtext-126" , array("title" => __("Change Text 126","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-126", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-126", array( "label"    => __( "Text 126", "themesgenerator" ), "section"  => "customtgtext-126", "settings" => "tgtext-126", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-126", array("selector" => "#tgtext-126",));

$wp_customize->add_section( "customtgtext-127" , array("title" => __("Change Text 127","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-127", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-127", array( "label"    => __( "Text 127", "themesgenerator" ), "section"  => "customtgtext-127", "settings" => "tgtext-127", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-127", array("selector" => "#tgtext-127",));

$wp_customize->add_section( "customtgtext-128" , array("title" => __("Change Text 128","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-128", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-128", array( "label"    => __( "Text 128", "themesgenerator" ), "section"  => "customtgtext-128", "settings" => "tgtext-128", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-128", array("selector" => "#tgtext-128",));

$wp_customize->add_section( "customtgtext-129" , array("title" => __("Change Text 129","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-129", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-129", array( "label"    => __( "Text 129", "themesgenerator" ), "section"  => "customtgtext-129", "settings" => "tgtext-129", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-129", array("selector" => "#tgtext-129",));

$wp_customize->add_section( "customtgtext-130" , array("title" => __("Change Text 130","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-130", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-130", array( "label"    => __( "Text 130", "themesgenerator" ), "section"  => "customtgtext-130", "settings" => "tgtext-130", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-130", array("selector" => "#tgtext-130",));

$wp_customize->add_section( "customtgtext-131" , array("title" => __("Change Text 131","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-131", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-131", array( "label"    => __( "Text 131", "themesgenerator" ), "section"  => "customtgtext-131", "settings" => "tgtext-131", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-131", array("selector" => "#tgtext-131",));

$wp_customize->add_section( "customtgtext-132" , array("title" => __("Change Text 132","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-132", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-132", array( "label"    => __( "Text 132", "themesgenerator" ), "section"  => "customtgtext-132", "settings" => "tgtext-132", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-132", array("selector" => "#tgtext-132",));

$wp_customize->add_section( "customtgtext-133" , array("title" => __("Change Text 133","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-133", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-133", array( "label"    => __( "Text 133", "themesgenerator" ), "section"  => "customtgtext-133", "settings" => "tgtext-133", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-133", array("selector" => "#tgtext-133",));

$wp_customize->add_section( "customtgtext-134" , array("title" => __("Change Text 134","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-134", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-134", array( "label"    => __( "Text 134", "themesgenerator" ), "section"  => "customtgtext-134", "settings" => "tgtext-134", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-134", array("selector" => "#tgtext-134",));

$wp_customize->add_section( "customtgtext-135" , array("title" => __("Change Text 135","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-135", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-135", array( "label"    => __( "Text 135", "themesgenerator" ), "section"  => "customtgtext-135", "settings" => "tgtext-135", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-135", array("selector" => "#tgtext-135",));

$wp_customize->add_section( "customtgtext-136" , array("title" => __("Change Text 136","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-136", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-136", array( "label"    => __( "Text 136", "themesgenerator" ), "section"  => "customtgtext-136", "settings" => "tgtext-136", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-136", array("selector" => "#tgtext-136",));

$wp_customize->add_section( "customtgtext-137" , array("title" => __("Change Text 137","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-137", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-137", array( "label"    => __( "Text 137", "themesgenerator" ), "section"  => "customtgtext-137", "settings" => "tgtext-137", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-137", array("selector" => "#tgtext-137",));

$wp_customize->add_section( "customtgtext-138" , array("title" => __("Change Text 138","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-138", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-138", array( "label"    => __( "Text 138", "themesgenerator" ), "section"  => "customtgtext-138", "settings" => "tgtext-138", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-138", array("selector" => "#tgtext-138",));

$wp_customize->add_section( "customtgtext-139" , array("title" => __("Change Text 139","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-139", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-139", array( "label"    => __( "Text 139", "themesgenerator" ), "section"  => "customtgtext-139", "settings" => "tgtext-139", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-139", array("selector" => "#tgtext-139",));

$wp_customize->add_section( "customtgtext-140" , array("title" => __("Change Text 140","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-140", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-140", array( "label"    => __( "Text 140", "themesgenerator" ), "section"  => "customtgtext-140", "settings" => "tgtext-140", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-140", array("selector" => "#tgtext-140",));

$wp_customize->add_section( "customtgtext-141" , array("title" => __("Change Text 141","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-141", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-141", array( "label"    => __( "Text 141", "themesgenerator" ), "section"  => "customtgtext-141", "settings" => "tgtext-141", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-141", array("selector" => "#tgtext-141",));

$wp_customize->add_section( "customtgtext-142" , array("title" => __("Change Text 142","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-142", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-142", array( "label"    => __( "Text 142", "themesgenerator" ), "section"  => "customtgtext-142", "settings" => "tgtext-142", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-142", array("selector" => "#tgtext-142",));

$wp_customize->add_section( "customtgtext-143" , array("title" => __("Change Text 143","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-143", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-143", array( "label"    => __( "Text 143", "themesgenerator" ), "section"  => "customtgtext-143", "settings" => "tgtext-143", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-143", array("selector" => "#tgtext-143",));

$wp_customize->add_section( "customtgtext-144" , array("title" => __("Change Text 144","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-144", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-144", array( "label"    => __( "Text 144", "themesgenerator" ), "section"  => "customtgtext-144", "settings" => "tgtext-144", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-144", array("selector" => "#tgtext-144",));

$wp_customize->add_section( "customtgtext-145" , array("title" => __("Change Text 145","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-145", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-145", array( "label"    => __( "Text 145", "themesgenerator" ), "section"  => "customtgtext-145", "settings" => "tgtext-145", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-145", array("selector" => "#tgtext-145",));

$wp_customize->add_section( "customtgtext-146" , array("title" => __("Change Text 146","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-146", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-146", array( "label"    => __( "Text 146", "themesgenerator" ), "section"  => "customtgtext-146", "settings" => "tgtext-146", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-146", array("selector" => "#tgtext-146",));

$wp_customize->add_section( "customtgtext-147" , array("title" => __("Change Text 147","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-147", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-147", array( "label"    => __( "Text 147", "themesgenerator" ), "section"  => "customtgtext-147", "settings" => "tgtext-147", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-147", array("selector" => "#tgtext-147",));

$wp_customize->add_section( "customtgtext-148" , array("title" => __("Change Text 148","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-148", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-148", array( "label"    => __( "Text 148", "themesgenerator" ), "section"  => "customtgtext-148", "settings" => "tgtext-148", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-148", array("selector" => "#tgtext-148",));

$wp_customize->add_section( "customtgtext-149" , array("title" => __("Change Text 149","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-149", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-149", array( "label"    => __( "Text 149", "themesgenerator" ), "section"  => "customtgtext-149", "settings" => "tgtext-149", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-149", array("selector" => "#tgtext-149",));

$wp_customize->add_section( "customtgtext-150" , array("title" => __("Change Text 150","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-150", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-150", array( "label"    => __( "Text 150", "themesgenerator" ), "section"  => "customtgtext-150", "settings" => "tgtext-150", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-150", array("selector" => "#tgtext-150",));

$wp_customize->add_section( "customtgtext-151" , array("title" => __("Change Text 151","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-151", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-151", array( "label"    => __( "Text 151", "themesgenerator" ), "section"  => "customtgtext-151", "settings" => "tgtext-151", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-151", array("selector" => "#tgtext-151",));

$wp_customize->add_section( "customtgtext-152" , array("title" => __("Change Text 152","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-152", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-152", array( "label"    => __( "Text 152", "themesgenerator" ), "section"  => "customtgtext-152", "settings" => "tgtext-152", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-152", array("selector" => "#tgtext-152",));

$wp_customize->add_section( "customtgtext-153" , array("title" => __("Change Text 153","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-153", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-153", array( "label"    => __( "Text 153", "themesgenerator" ), "section"  => "customtgtext-153", "settings" => "tgtext-153", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-153", array("selector" => "#tgtext-153",));

$wp_customize->add_section( "customtgtext-154" , array("title" => __("Change Text 154","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-154", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-154", array( "label"    => __( "Text 154", "themesgenerator" ), "section"  => "customtgtext-154", "settings" => "tgtext-154", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-154", array("selector" => "#tgtext-154",));

$wp_customize->add_section( "customtgtext-155" , array("title" => __("Change Text 155","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-155", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-155", array( "label"    => __( "Text 155", "themesgenerator" ), "section"  => "customtgtext-155", "settings" => "tgtext-155", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-155", array("selector" => "#tgtext-155",));

$wp_customize->add_section( "customtgtext-156" , array("title" => __("Change Text 156","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-156", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-156", array( "label"    => __( "Text 156", "themesgenerator" ), "section"  => "customtgtext-156", "settings" => "tgtext-156", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-156", array("selector" => "#tgtext-156",));

$wp_customize->add_section( "customtgtext-157" , array("title" => __("Change Text 157","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-157", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-157", array( "label"    => __( "Text 157", "themesgenerator" ), "section"  => "customtgtext-157", "settings" => "tgtext-157", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-157", array("selector" => "#tgtext-157",));

$wp_customize->add_section( "customtgtext-158" , array("title" => __("Change Text 158","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-158", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-158", array( "label"    => __( "Text 158", "themesgenerator" ), "section"  => "customtgtext-158", "settings" => "tgtext-158", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-158", array("selector" => "#tgtext-158",));

$wp_customize->add_section( "customtgtext-159" , array("title" => __("Change Text 159","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-159", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-159", array( "label"    => __( "Text 159", "themesgenerator" ), "section"  => "customtgtext-159", "settings" => "tgtext-159", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-159", array("selector" => "#tgtext-159",));

$wp_customize->add_section( "customtgtext-160" , array("title" => __("Change Text 160","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-160", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-160", array( "label"    => __( "Text 160", "themesgenerator" ), "section"  => "customtgtext-160", "settings" => "tgtext-160", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-160", array("selector" => "#tgtext-160",));

$wp_customize->add_section( "customtgtext-161" , array("title" => __("Change Text 161","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-161", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-161", array( "label"    => __( "Text 161", "themesgenerator" ), "section"  => "customtgtext-161", "settings" => "tgtext-161", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-161", array("selector" => "#tgtext-161",));

$wp_customize->add_section( "customtgtext-162" , array("title" => __("Change Text 162","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-162", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-162", array( "label"    => __( "Text 162", "themesgenerator" ), "section"  => "customtgtext-162", "settings" => "tgtext-162", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-162", array("selector" => "#tgtext-162",));

$wp_customize->add_section( "customtgtext-163" , array("title" => __("Change Text 163","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-163", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-163", array( "label"    => __( "Text 163", "themesgenerator" ), "section"  => "customtgtext-163", "settings" => "tgtext-163", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-163", array("selector" => "#tgtext-163",));

$wp_customize->add_section( "customtgtext-164" , array("title" => __("Change Text 164","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-164", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-164", array( "label"    => __( "Text 164", "themesgenerator" ), "section"  => "customtgtext-164", "settings" => "tgtext-164", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-164", array("selector" => "#tgtext-164",));

$wp_customize->add_section( "customtgtext-165" , array("title" => __("Change Text 165","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-165", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-165", array( "label"    => __( "Text 165", "themesgenerator" ), "section"  => "customtgtext-165", "settings" => "tgtext-165", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-165", array("selector" => "#tgtext-165",));

$wp_customize->add_section( "customtgtext-166" , array("title" => __("Change Text 166","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-166", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-166", array( "label"    => __( "Text 166", "themesgenerator" ), "section"  => "customtgtext-166", "settings" => "tgtext-166", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-166", array("selector" => "#tgtext-166",));

$wp_customize->add_section( "customtgtext-167" , array("title" => __("Change Text 167","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-167", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-167", array( "label"    => __( "Text 167", "themesgenerator" ), "section"  => "customtgtext-167", "settings" => "tgtext-167", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-167", array("selector" => "#tgtext-167",));

$wp_customize->add_section( "customtgtext-168" , array("title" => __("Change Text 168","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-168", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-168", array( "label"    => __( "Text 168", "themesgenerator" ), "section"  => "customtgtext-168", "settings" => "tgtext-168", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-168", array("selector" => "#tgtext-168",));

$wp_customize->add_section( "customtgtext-169" , array("title" => __("Change Text 169","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-169", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-169", array( "label"    => __( "Text 169", "themesgenerator" ), "section"  => "customtgtext-169", "settings" => "tgtext-169", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-169", array("selector" => "#tgtext-169",));

$wp_customize->add_section( "customtgtext-170" , array("title" => __("Change Text 170","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-170", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-170", array( "label"    => __( "Text 170", "themesgenerator" ), "section"  => "customtgtext-170", "settings" => "tgtext-170", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-170", array("selector" => "#tgtext-170",));

$wp_customize->add_section( "customtgtext-171" , array("title" => __("Change Text 171","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-171", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-171", array( "label"    => __( "Text 171", "themesgenerator" ), "section"  => "customtgtext-171", "settings" => "tgtext-171", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-171", array("selector" => "#tgtext-171",));

$wp_customize->add_section( "customtgtext-172" , array("title" => __("Change Text 172","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-172", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-172", array( "label"    => __( "Text 172", "themesgenerator" ), "section"  => "customtgtext-172", "settings" => "tgtext-172", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-172", array("selector" => "#tgtext-172",));

$wp_customize->add_section( "customtgtext-173" , array("title" => __("Change Text 173","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-173", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-173", array( "label"    => __( "Text 173", "themesgenerator" ), "section"  => "customtgtext-173", "settings" => "tgtext-173", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-173", array("selector" => "#tgtext-173",));

$wp_customize->add_section( "customtgtext-174" , array("title" => __("Change Text 174","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-174", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-174", array( "label"    => __( "Text 174", "themesgenerator" ), "section"  => "customtgtext-174", "settings" => "tgtext-174", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-174", array("selector" => "#tgtext-174",));

$wp_customize->add_section( "customtgtext-175" , array("title" => __("Change Text 175","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-175", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-175", array( "label"    => __( "Text 175", "themesgenerator" ), "section"  => "customtgtext-175", "settings" => "tgtext-175", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-175", array("selector" => "#tgtext-175",));

$wp_customize->add_section( "customtgtext-176" , array("title" => __("Change Text 176","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-176", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-176", array( "label"    => __( "Text 176", "themesgenerator" ), "section"  => "customtgtext-176", "settings" => "tgtext-176", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-176", array("selector" => "#tgtext-176",));

$wp_customize->add_section( "customtgtext-177" , array("title" => __("Change Text 177","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-177", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-177", array( "label"    => __( "Text 177", "themesgenerator" ), "section"  => "customtgtext-177", "settings" => "tgtext-177", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-177", array("selector" => "#tgtext-177",));

$wp_customize->add_section( "customtgtext-178" , array("title" => __("Change Text 178","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-178", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-178", array( "label"    => __( "Text 178", "themesgenerator" ), "section"  => "customtgtext-178", "settings" => "tgtext-178", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-178", array("selector" => "#tgtext-178",));

$wp_customize->add_section( "customtgtext-179" , array("title" => __("Change Text 179","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-179", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-179", array( "label"    => __( "Text 179", "themesgenerator" ), "section"  => "customtgtext-179", "settings" => "tgtext-179", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-179", array("selector" => "#tgtext-179",));

$wp_customize->add_section( "customtgtext-180" , array("title" => __("Change Text 180","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-180", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-180", array( "label"    => __( "Text 180", "themesgenerator" ), "section"  => "customtgtext-180", "settings" => "tgtext-180", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-180", array("selector" => "#tgtext-180",));

$wp_customize->add_section( "customtgtext-181" , array("title" => __("Change Text 181","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-181", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-181", array( "label"    => __( "Text 181", "themesgenerator" ), "section"  => "customtgtext-181", "settings" => "tgtext-181", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-181", array("selector" => "#tgtext-181",));

$wp_customize->add_section( "customtgtext-182" , array("title" => __("Change Text 182","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-182", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-182", array( "label"    => __( "Text 182", "themesgenerator" ), "section"  => "customtgtext-182", "settings" => "tgtext-182", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-182", array("selector" => "#tgtext-182",));

$wp_customize->add_section( "customtgtext-183" , array("title" => __("Change Text 183","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-183", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-183", array( "label"    => __( "Text 183", "themesgenerator" ), "section"  => "customtgtext-183", "settings" => "tgtext-183", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-183", array("selector" => "#tgtext-183",));

$wp_customize->add_section( "customtgtext-184" , array("title" => __("Change Text 184","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-184", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-184", array( "label"    => __( "Text 184", "themesgenerator" ), "section"  => "customtgtext-184", "settings" => "tgtext-184", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-184", array("selector" => "#tgtext-184",));

$wp_customize->add_section( "customtgtext-185" , array("title" => __("Change Text 185","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-185", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-185", array( "label"    => __( "Text 185", "themesgenerator" ), "section"  => "customtgtext-185", "settings" => "tgtext-185", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-185", array("selector" => "#tgtext-185",));

$wp_customize->add_section( "customtgtext-186" , array("title" => __("Change Text 186","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-186", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-186", array( "label"    => __( "Text 186", "themesgenerator" ), "section"  => "customtgtext-186", "settings" => "tgtext-186", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-186", array("selector" => "#tgtext-186",));

$wp_customize->add_section( "customtgtext-187" , array("title" => __("Change Text 187","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-187", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-187", array( "label"    => __( "Text 187", "themesgenerator" ), "section"  => "customtgtext-187", "settings" => "tgtext-187", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-187", array("selector" => "#tgtext-187",));

$wp_customize->add_section( "customtgtext-188" , array("title" => __("Change Text 188","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-188", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-188", array( "label"    => __( "Text 188", "themesgenerator" ), "section"  => "customtgtext-188", "settings" => "tgtext-188", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-188", array("selector" => "#tgtext-188",));

$wp_customize->add_section( "customtgtext-189" , array("title" => __("Change Text 189","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-189", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-189", array( "label"    => __( "Text 189", "themesgenerator" ), "section"  => "customtgtext-189", "settings" => "tgtext-189", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-189", array("selector" => "#tgtext-189",));

$wp_customize->add_section( "customtgtext-190" , array("title" => __("Change Text 190","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-190", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-190", array( "label"    => __( "Text 190", "themesgenerator" ), "section"  => "customtgtext-190", "settings" => "tgtext-190", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-190", array("selector" => "#tgtext-190",));

$wp_customize->add_section( "customtgtext-191" , array("title" => __("Change Text 191","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-191", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-191", array( "label"    => __( "Text 191", "themesgenerator" ), "section"  => "customtgtext-191", "settings" => "tgtext-191", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-191", array("selector" => "#tgtext-191",));

$wp_customize->add_section( "customtgtext-192" , array("title" => __("Change Text 192","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-192", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-192", array( "label"    => __( "Text 192", "themesgenerator" ), "section"  => "customtgtext-192", "settings" => "tgtext-192", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-192", array("selector" => "#tgtext-192",));

$wp_customize->add_section( "customtgtext-193" , array("title" => __("Change Text 193","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-193", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-193", array( "label"    => __( "Text 193", "themesgenerator" ), "section"  => "customtgtext-193", "settings" => "tgtext-193", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-193", array("selector" => "#tgtext-193",));

$wp_customize->add_section( "customtgtext-194" , array("title" => __("Change Text 194","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-194", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-194", array( "label"    => __( "Text 194", "themesgenerator" ), "section"  => "customtgtext-194", "settings" => "tgtext-194", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-194", array("selector" => "#tgtext-194",));

$wp_customize->add_section( "customtgtext-195" , array("title" => __("Change Text 195","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-195", array( "default" => __( "PUBLICATIONS & NEWS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-195", array( "label"    => __( "Text 195", "themesgenerator" ), "section"  => "customtgtext-195", "settings" => "tgtext-195", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-195", array("selector" => "#tgtext-195",));

$wp_customize->add_section( "customtgtext-196" , array("title" => __("Change Text 196","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-196", array( "default" => __( "SEE ALL", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-196", array( "label"    => __( "Text 196", "themesgenerator" ), "section"  => "customtgtext-196", "settings" => "tgtext-196", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-196", array("selector" => "#tgtext-196",));

$wp_customize->add_section( "customtgtext-197" , array("title" => __("Change Text 197","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-197", array( "default" => __( "Lawyers with passion", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-197", array( "label"    => __( "Text 197", "themesgenerator" ), "section"  => "customtgtext-197", "settings" => "tgtext-197", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-197", array("selector" => "#tgtext-197",));

$wp_customize->add_section( "customtgtext-198" , array("title" => __("Change Text 198","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-198", array( "default" => __( "Tanger", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-198", array( "label"    => __( "Text 198", "themesgenerator" ), "section"  => "customtgtext-198", "settings" => "tgtext-198", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-198", array("selector" => "#tgtext-198",));

$wp_customize->add_section( "customtgtext-199" , array("title" => __("Change Text 199","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-199", array( "default" => __( "Marrakesh", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-199", array( "label"    => __( "Text 199", "themesgenerator" ), "section"  => "customtgtext-199", "settings" => "tgtext-199", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-199", array("selector" => "#tgtext-199",));

$wp_customize->add_section( "customtgtext-200" , array("title" => __("Change Text 200","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-200", array( "default" => __( "Dubai", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-200", array( "label"    => __( "Text 200", "themesgenerator" ), "section"  => "customtgtext-200", "settings" => "tgtext-200", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-200", array("selector" => "#tgtext-200",));

$wp_customize->add_section( "customtgtext-201" , array("title" => __("Change Text 201","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-201", array( "default" => __( "Sevilla", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-201", array( "label"    => __( "Text 201", "themesgenerator" ), "section"  => "customtgtext-201", "settings" => "tgtext-201", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-201", array("selector" => "#tgtext-201",));

$wp_customize->add_section( "customtgtext-202" , array("title" => __("Change Text 202","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-202", array( "default" => __( "Frankfurt", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-202", array( "label"    => __( "Text 202", "themesgenerator" ), "section"  => "customtgtext-202", "settings" => "tgtext-202", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-202", array("selector" => "#tgtext-202",));

$wp_customize->add_section( "customtgtext-203" , array("title" => __("Change Text 203","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-203", array( "default" => __( "Amman", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-203", array( "label"    => __( "Text 203", "themesgenerator" ), "section"  => "customtgtext-203", "settings" => "tgtext-203", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-203", array("selector" => "#tgtext-203",));

$wp_customize->add_section( "customtgtext-204" , array("title" => __("Change Text 204","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-204", array( "default" => __( "Bagdad", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-204", array( "label"    => __( "Text 204", "themesgenerator" ), "section"  => "customtgtext-204", "settings" => "tgtext-204", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-204", array("selector" => "#tgtext-204",));

$wp_customize->add_section( "customtgtext-205" , array("title" => __("Change Text 205","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-205", array( "default" => __( "Algerien", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-205", array( "label"    => __( "Text 205", "themesgenerator" ), "section"  => "customtgtext-205", "settings" => "tgtext-205", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-205", array("selector" => "#tgtext-205",));

$wp_customize->add_section( "customtgtext-206" , array("title" => __("Change Text 206","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-206", array( "default" => __( "Beirut", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-206", array( "label"    => __( "Text 206", "themesgenerator" ), "section"  => "customtgtext-206", "settings" => "tgtext-206", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-206", array("selector" => "#tgtext-206",));

$wp_customize->add_section( "customtgtext-207" , array("title" => __("Change Text 207","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-207", array( "default" => __( "Casablanca", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-207", array( "label"    => __( "Text 207", "themesgenerator" ), "section"  => "customtgtext-207", "settings" => "tgtext-207", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-207", array("selector" => "#tgtext-207",));

$wp_customize->add_section( "customtgtext-208" , array("title" => __("Change Text 208","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-208", array( "default" => __( "Kairo", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-208", array( "label"    => __( "Text 208", "themesgenerator" ), "section"  => "customtgtext-208", "settings" => "tgtext-208", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-208", array("selector" => "#tgtext-208",));

$wp_customize->add_section( "customtgtext-209" , array("title" => __("Change Text 209","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-209", array( "default" => __( "Manama", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-209", array( "label"    => __( "Text 209", "themesgenerator" ), "section"  => "customtgtext-209", "settings" => "tgtext-209", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-209", array("selector" => "#tgtext-209",));

$wp_customize->add_section( "customtgtext-210" , array("title" => __("Change Text 210","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-210", array( "default" => __( "Riad", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-210", array( "label"    => __( "Text 210", "themesgenerator" ), "section"  => "customtgtext-210", "settings" => "tgtext-210", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-210", array("selector" => "#tgtext-210",));

$wp_customize->add_section( "customtgtext-211" , array("title" => __("Change Text 211","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-211", array( "default" => __( "Tunis", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-211", array( "label"    => __( "Text 211", "themesgenerator" ), "section"  => "customtgtext-211", "settings" => "tgtext-211", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-211", array("selector" => "#tgtext-211",));

$wp_customize->add_section( "customtgtext-212" , array("title" => __("Change Text 212","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-212", array( "default" => __( "Ras al Khaimah", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-212", array( "label"    => __( "Text 212", "themesgenerator" ), "section"  => "customtgtext-212", "settings" => "tgtext-212", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-212", array("selector" => "#tgtext-212",));

$wp_customize->add_section( "customtgtext-213" , array("title" => __("Change Text 213","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-213", array( "default" => __( "HOME", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-213", array( "label"    => __( "Text 213", "themesgenerator" ), "section"  => "customtgtext-213", "settings" => "tgtext-213", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-213", array("selector" => "#tgtext-213",));

$wp_customize->add_section( "customtgtext-214" , array("title" => __("Change Text 214","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-214", array( "default" => __( "THE PRACTICE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-214", array( "label"    => __( "Text 214", "themesgenerator" ), "section"  => "customtgtext-214", "settings" => "tgtext-214", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-214", array("selector" => "#tgtext-214",));

$wp_customize->add_section( "customtgtext-215" , array("title" => __("Change Text 215","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-215", array( "default" => __( "AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-215", array( "label"    => __( "Text 215", "themesgenerator" ), "section"  => "customtgtext-215", "settings" => "tgtext-215", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-215", array("selector" => "#tgtext-215",));

$wp_customize->add_section( "customtgtext-216" , array("title" => __("Change Text 216","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-216", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-216", array( "label"    => __( "Text 216", "themesgenerator" ), "section"  => "customtgtext-216", "settings" => "tgtext-216", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-216", array("selector" => "#tgtext-216",));

$wp_customize->add_section( "customtgtext-217" , array("title" => __("Change Text 217","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-217", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-217", array( "label"    => __( "Text 217", "themesgenerator" ), "section"  => "customtgtext-217", "settings" => "tgtext-217", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-217", array("selector" => "#tgtext-217",));

$wp_customize->add_section( "customtgtext-218" , array("title" => __("Change Text 218","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-218", array( "default" => __( "NEWS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-218", array( "label"    => __( "Text 218", "themesgenerator" ), "section"  => "customtgtext-218", "settings" => "tgtext-218", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-218", array("selector" => "#tgtext-218",));

$wp_customize->add_section( "customtgtext-219" , array("title" => __("Change Text 219","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-219", array( "default" => __( "Contact", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-219", array( "label"    => __( "Text 219", "themesgenerator" ), "section"  => "customtgtext-219", "settings" => "tgtext-219", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-219", array("selector" => "#tgtext-219",));

$wp_customize->add_section( "customtgtext-220" , array("title" => __("Change Text 220","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-220", array( "default" => __( "© Copyright - MIDEAST | Law 2020", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-220", array( "label"    => __( "Text 220", "themesgenerator" ), "section"  => "customtgtext-220", "settings" => "tgtext-220", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-220", array("selector" => "#tgtext-220",));

$wp_customize->add_section( "customtgtext-221" , array("title" => __("Change Text 221","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-221", array( "default" => __( "Legal", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-221", array( "label"    => __( "Text 221", "themesgenerator" ), "section"  => "customtgtext-221", "settings" => "tgtext-221", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-221", array("selector" => "#tgtext-221",));

$wp_customize->add_section( "customtgtext-222" , array("title" => __("Change Text 222","themesgenerator"),	"panel"    => "text_blocks","priority" => 19) );
$wp_customize->add_setting( "tgtext-222", array( "default" => __( "Data Protection Policy", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtext-222", array( "label"    => __( "Text 222", "themesgenerator" ), "section"  => "customtgtext-222", "settings" => "tgtext-222", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tgtext-222", array("selector" => "#tgtext-222",));

$wp_customize->add_section( "customtgtext-9999" , array("title" => __("See all","themesgenerator"),	"panel"    => "text_blocks","priority" => 1) );
$wp_customize->add_setting( "tgtext-1", array( "default" => __( "Lawyers with passion", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-2", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-3", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-4", array( "default" => __( "AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-5", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-6", array( "default" => __( "SEE MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-7", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-8", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet. ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-9", array( "default" => __( "LAWYERS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-10", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-11", array( "default" => __( "MAGHREB", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-12", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-13", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-14", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-15", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-16", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-17", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-18", array( "default" => __( "MASHREK", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-19", array( "default" => __( "Avocate - Rechtsanwälte ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-20", array( "default" => __( "Eschenheimer Landstrasse 1", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-21", array( "default" => __( "D-69316  Frankfurt am Main | GERMANY", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-22", array( "default" => __( "+20 2 23 91 43 44", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-23", array( "default" => __( "+49 69 66 42 89 64 ", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-24", array( "default" => __( "ule@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-25", array( "default" => __( "SEE LOCATIONS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-26", array( "default" => __( "International Legal Practice", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-27", array( "default" => __( "INTERNATIONAL LEGAL PRACTICE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-28", array( "default" => __( "Practice Areas", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-29", array( "default" => __( "PRACTICE AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-30", array( "default" => __( "Mergers & Acquisitions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-31", array( "default" => __( "International Joint Ventures, Cross Border Transactions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-32", array( "default" => __( "Corporate", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-33", array( "default" => __( "Business set-up, both onshore and offshore (UAE-Bubai-Free Zones)", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-34", array( "default" => __( "Foreign Direct Investments", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-35", array( "default" => __( "Contract law, drafting und reviewing contracts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-36", array( "default" => __( "Engineering, Construction und Trunkey Projects, in connection with energy and natural resources", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-37", array( "default" => __( "Energy & Utilities (O&M), Oil & Gas, Renewable Energy, Solar, E&P contracts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-38", array( "default" => __( "Technology Transfer (trademarks, Know-how, technical assistance), License Agreements", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-39", array( "default" => __( "Project Finance, Structured Trade & Export Finance", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-40", array( "default" => __( "International trade law", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-41", array( "default" => __( "Commercial Agencies & Distributorships", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-42", array( "default" => __( "Employment", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-43", array( "default" => __( "Export control & international sanctions", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-44", array( "default" => __( "Public Tenders", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-45", array( "default" => __( "Corporate, Compliance, Internal Investigations, White Collar Crime", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-46", array( "default" => __( "Corporate Structuring & Insolvency", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-47", array( "default" => __( "International Tax Law (Double Taxation Treaties) and Custums", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-48", array( "default" => __( "Multi-jurisdictional dispute resolution, mediation", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-49", array( "default" => __( "International arbitation, transnational ligation and DIFC Courts", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-50", array( "default" => __( "EXPERIENCE BY COUNTRY", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-51", array( "default" => __( "EGYPT", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-52", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-53", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-54", array( "default" => __( "TANGER", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-55", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-56", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-57", array( "default" => __( "DUBAI", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-58", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-59", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-60", array( "default" => __( "EGYPT", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-61", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-62", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-63", array( "default" => __( "TANGER", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-64", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-65", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-66", array( "default" => __( "DUBAI", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-67", array( "default" => __( "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod temp ut labore et dolore...", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-68", array( "default" => __( "READ MORE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-69", array( "default" => __( "Team", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-70", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-71", array( "default" => __( "Offices", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-72", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-73", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-74", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-75", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-76", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-77", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-78", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-79", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-80", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-81", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-82", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-83", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-84", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-85", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-86", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-87", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-88", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-89", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-90", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-91", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-92", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-93", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-94", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-95", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-96", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-97", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-98", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-99", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-100", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-101", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-102", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-103", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-104", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-105", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-106", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-107", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-108", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-109", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-110", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-111", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-112", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-113", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-114", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-115", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-116", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-117", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-118", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-119", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-120", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-121", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-122", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-123", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-124", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-125", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-126", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-127", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-128", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-129", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-130", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-131", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-132", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-133", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-134", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-135", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-136", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-137", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-138", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-139", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-140", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-141", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-142", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-143", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-144", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-145", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-146", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-147", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-148", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-149", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-150", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-151", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-152", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-153", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-154", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-155", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-156", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-157", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-158", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-159", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-160", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-161", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-162", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-163", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-164", array( "default" => __( "Marrocco", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-165", array( "default" => __( "Abogados – Rechtsanwälte", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-166", array( "default" => __( "c/ Manuel Bermudo Barrera 3B, 2C", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-167", array( "default" => __( "41004 Sevilla | SPAIN", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-168", array( "default" => __( "+34 684 083 156", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-169", array( "default" => __( "+34 955 314 614", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-170", array( "default" => __( "steiner@mideastlaw.de", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-171", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-172", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-173", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-174", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-175", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-176", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-177", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-178", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-179", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-180", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-181", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-182", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-183", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-184", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-185", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-186", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-187", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-188", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-189", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-190", array( "default" => __( "News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-191", array( "default" => __( "All News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-192", array( "default" => __( "Legal News", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-193", array( "default" => __( "Media", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-194", array( "default" => __( "Other", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-195", array( "default" => __( "PUBLICATIONS & NEWS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-196", array( "default" => __( "SEE ALL", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-197", array( "default" => __( "Lawyers with passion", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-198", array( "default" => __( "Tanger", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-199", array( "default" => __( "Marrakesh", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-200", array( "default" => __( "Dubai", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-201", array( "default" => __( "Sevilla", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-202", array( "default" => __( "Frankfurt", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-203", array( "default" => __( "Amman", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-204", array( "default" => __( "Bagdad", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-205", array( "default" => __( "Algerien", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-206", array( "default" => __( "Beirut", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-207", array( "default" => __( "Casablanca", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-208", array( "default" => __( "Kairo", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-209", array( "default" => __( "Manama", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-210", array( "default" => __( "Riad", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-211", array( "default" => __( "Tunis", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-212", array( "default" => __( "Ras al Khaimah", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-213", array( "default" => __( "HOME", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-214", array( "default" => __( "THE PRACTICE", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-215", array( "default" => __( "AREAS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-216", array( "default" => __( "TEAM", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-217", array( "default" => __( "OFFICES", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-218", array( "default" => __( "NEWS", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-219", array( "default" => __( "Contact", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-220", array( "default" => __( "© Copyright - MIDEAST | Law 2020", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-221", array( "default" => __( "Legal", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );$wp_customize->add_setting( "tgtext-222", array( "default" => __( "Data Protection Policy", "themesgenerator" ), "sanitize_callback" => "sanitize_text"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-1", array( "label"    => __( "Text 1", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-1", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-2", array( "label"    => __( "Text 2", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-2", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-3", array( "label"    => __( "Text 3", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-3", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-4", array( "label"    => __( "Text 4", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-4", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-5", array( "label"    => __( "Text 5", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-5", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-6", array( "label"    => __( "Text 6", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-6", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-7", array( "label"    => __( "Text 7", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-7", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-8", array( "label"    => __( "Text 8", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-8", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-9", array( "label"    => __( "Text 9", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-9", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-10", array( "label"    => __( "Text 10", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-10", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-11", array( "label"    => __( "Text 11", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-11", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-12", array( "label"    => __( "Text 12", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-12", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-13", array( "label"    => __( "Text 13", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-13", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-14", array( "label"    => __( "Text 14", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-14", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-15", array( "label"    => __( "Text 15", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-15", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-16", array( "label"    => __( "Text 16", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-16", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-17", array( "label"    => __( "Text 17", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-17", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-18", array( "label"    => __( "Text 18", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-18", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-19", array( "label"    => __( "Text 19", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-19", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-20", array( "label"    => __( "Text 20", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-20", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-21", array( "label"    => __( "Text 21", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-21", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-22", array( "label"    => __( "Text 22", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-22", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-23", array( "label"    => __( "Text 23", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-23", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-24", array( "label"    => __( "Text 24", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-24", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-25", array( "label"    => __( "Text 25", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-25", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-26", array( "label"    => __( "Text 26", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-26", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-27", array( "label"    => __( "Text 27", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-27", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-28", array( "label"    => __( "Text 28", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-28", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-29", array( "label"    => __( "Text 29", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-29", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-30", array( "label"    => __( "Text 30", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-30", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-31", array( "label"    => __( "Text 31", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-31", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-32", array( "label"    => __( "Text 32", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-32", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-33", array( "label"    => __( "Text 33", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-33", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-34", array( "label"    => __( "Text 34", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-34", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-35", array( "label"    => __( "Text 35", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-35", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-36", array( "label"    => __( "Text 36", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-36", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-37", array( "label"    => __( "Text 37", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-37", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-38", array( "label"    => __( "Text 38", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-38", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-39", array( "label"    => __( "Text 39", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-39", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-40", array( "label"    => __( "Text 40", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-40", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-41", array( "label"    => __( "Text 41", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-41", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-42", array( "label"    => __( "Text 42", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-42", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-43", array( "label"    => __( "Text 43", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-43", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-44", array( "label"    => __( "Text 44", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-44", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-45", array( "label"    => __( "Text 45", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-45", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-46", array( "label"    => __( "Text 46", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-46", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-47", array( "label"    => __( "Text 47", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-47", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-48", array( "label"    => __( "Text 48", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-48", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-49", array( "label"    => __( "Text 49", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-49", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-50", array( "label"    => __( "Text 50", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-50", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-51", array( "label"    => __( "Text 51", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-51", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-52", array( "label"    => __( "Text 52", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-52", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-53", array( "label"    => __( "Text 53", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-53", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-54", array( "label"    => __( "Text 54", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-54", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-55", array( "label"    => __( "Text 55", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-55", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-56", array( "label"    => __( "Text 56", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-56", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-57", array( "label"    => __( "Text 57", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-57", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-58", array( "label"    => __( "Text 58", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-58", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-59", array( "label"    => __( "Text 59", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-59", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-60", array( "label"    => __( "Text 60", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-60", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-61", array( "label"    => __( "Text 61", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-61", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-62", array( "label"    => __( "Text 62", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-62", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-63", array( "label"    => __( "Text 63", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-63", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-64", array( "label"    => __( "Text 64", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-64", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-65", array( "label"    => __( "Text 65", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-65", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-66", array( "label"    => __( "Text 66", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-66", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-67", array( "label"    => __( "Text 67", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-67", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-68", array( "label"    => __( "Text 68", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-68", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-69", array( "label"    => __( "Text 69", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-69", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-70", array( "label"    => __( "Text 70", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-70", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-71", array( "label"    => __( "Text 71", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-71", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-72", array( "label"    => __( "Text 72", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-72", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-73", array( "label"    => __( "Text 73", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-73", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-74", array( "label"    => __( "Text 74", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-74", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-75", array( "label"    => __( "Text 75", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-75", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-76", array( "label"    => __( "Text 76", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-76", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-77", array( "label"    => __( "Text 77", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-77", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-78", array( "label"    => __( "Text 78", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-78", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-79", array( "label"    => __( "Text 79", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-79", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-80", array( "label"    => __( "Text 80", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-80", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-81", array( "label"    => __( "Text 81", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-81", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-82", array( "label"    => __( "Text 82", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-82", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-83", array( "label"    => __( "Text 83", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-83", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-84", array( "label"    => __( "Text 84", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-84", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-85", array( "label"    => __( "Text 85", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-85", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-86", array( "label"    => __( "Text 86", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-86", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-87", array( "label"    => __( "Text 87", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-87", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-88", array( "label"    => __( "Text 88", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-88", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-89", array( "label"    => __( "Text 89", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-89", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-90", array( "label"    => __( "Text 90", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-90", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-91", array( "label"    => __( "Text 91", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-91", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-92", array( "label"    => __( "Text 92", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-92", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-93", array( "label"    => __( "Text 93", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-93", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-94", array( "label"    => __( "Text 94", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-94", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-95", array( "label"    => __( "Text 95", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-95", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-96", array( "label"    => __( "Text 96", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-96", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-97", array( "label"    => __( "Text 97", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-97", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-98", array( "label"    => __( "Text 98", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-98", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-99", array( "label"    => __( "Text 99", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-99", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-100", array( "label"    => __( "Text 100", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-100", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-101", array( "label"    => __( "Text 101", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-101", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-102", array( "label"    => __( "Text 102", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-102", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-103", array( "label"    => __( "Text 103", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-103", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-104", array( "label"    => __( "Text 104", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-104", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-105", array( "label"    => __( "Text 105", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-105", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-106", array( "label"    => __( "Text 106", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-106", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-107", array( "label"    => __( "Text 107", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-107", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-108", array( "label"    => __( "Text 108", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-108", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-109", array( "label"    => __( "Text 109", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-109", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-110", array( "label"    => __( "Text 110", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-110", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-111", array( "label"    => __( "Text 111", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-111", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-112", array( "label"    => __( "Text 112", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-112", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-113", array( "label"    => __( "Text 113", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-113", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-114", array( "label"    => __( "Text 114", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-114", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-115", array( "label"    => __( "Text 115", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-115", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-116", array( "label"    => __( "Text 116", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-116", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-117", array( "label"    => __( "Text 117", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-117", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-118", array( "label"    => __( "Text 118", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-118", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-119", array( "label"    => __( "Text 119", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-119", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-120", array( "label"    => __( "Text 120", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-120", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-121", array( "label"    => __( "Text 121", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-121", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-122", array( "label"    => __( "Text 122", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-122", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-123", array( "label"    => __( "Text 123", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-123", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-124", array( "label"    => __( "Text 124", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-124", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-125", array( "label"    => __( "Text 125", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-125", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-126", array( "label"    => __( "Text 126", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-126", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-127", array( "label"    => __( "Text 127", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-127", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-128", array( "label"    => __( "Text 128", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-128", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-129", array( "label"    => __( "Text 129", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-129", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-130", array( "label"    => __( "Text 130", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-130", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-131", array( "label"    => __( "Text 131", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-131", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-132", array( "label"    => __( "Text 132", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-132", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-133", array( "label"    => __( "Text 133", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-133", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-134", array( "label"    => __( "Text 134", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-134", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-135", array( "label"    => __( "Text 135", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-135", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-136", array( "label"    => __( "Text 136", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-136", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-137", array( "label"    => __( "Text 137", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-137", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-138", array( "label"    => __( "Text 138", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-138", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-139", array( "label"    => __( "Text 139", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-139", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-140", array( "label"    => __( "Text 140", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-140", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-141", array( "label"    => __( "Text 141", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-141", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-142", array( "label"    => __( "Text 142", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-142", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-143", array( "label"    => __( "Text 143", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-143", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-144", array( "label"    => __( "Text 144", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-144", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-145", array( "label"    => __( "Text 145", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-145", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-146", array( "label"    => __( "Text 146", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-146", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-147", array( "label"    => __( "Text 147", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-147", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-148", array( "label"    => __( "Text 148", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-148", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-149", array( "label"    => __( "Text 149", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-149", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-150", array( "label"    => __( "Text 150", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-150", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-151", array( "label"    => __( "Text 151", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-151", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-152", array( "label"    => __( "Text 152", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-152", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-153", array( "label"    => __( "Text 153", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-153", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-154", array( "label"    => __( "Text 154", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-154", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-155", array( "label"    => __( "Text 155", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-155", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-156", array( "label"    => __( "Text 156", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-156", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-157", array( "label"    => __( "Text 157", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-157", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-158", array( "label"    => __( "Text 158", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-158", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-159", array( "label"    => __( "Text 159", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-159", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-160", array( "label"    => __( "Text 160", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-160", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-161", array( "label"    => __( "Text 161", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-161", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-162", array( "label"    => __( "Text 162", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-162", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-163", array( "label"    => __( "Text 163", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-163", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-164", array( "label"    => __( "Text 164", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-164", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-165", array( "label"    => __( "Text 165", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-165", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-166", array( "label"    => __( "Text 166", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-166", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-167", array( "label"    => __( "Text 167", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-167", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-168", array( "label"    => __( "Text 168", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-168", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-169", array( "label"    => __( "Text 169", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-169", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-170", array( "label"    => __( "Text 170", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-170", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-171", array( "label"    => __( "Text 171", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-171", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-172", array( "label"    => __( "Text 172", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-172", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-173", array( "label"    => __( "Text 173", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-173", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-174", array( "label"    => __( "Text 174", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-174", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-175", array( "label"    => __( "Text 175", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-175", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-176", array( "label"    => __( "Text 176", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-176", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-177", array( "label"    => __( "Text 177", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-177", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-178", array( "label"    => __( "Text 178", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-178", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-179", array( "label"    => __( "Text 179", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-179", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-180", array( "label"    => __( "Text 180", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-180", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-181", array( "label"    => __( "Text 181", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-181", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-182", array( "label"    => __( "Text 182", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-182", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-183", array( "label"    => __( "Text 183", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-183", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-184", array( "label"    => __( "Text 184", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-184", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-185", array( "label"    => __( "Text 185", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-185", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-186", array( "label"    => __( "Text 186", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-186", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-187", array( "label"    => __( "Text 187", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-187", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-188", array( "label"    => __( "Text 188", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-188", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-189", array( "label"    => __( "Text 189", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-189", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-190", array( "label"    => __( "Text 190", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-190", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-191", array( "label"    => __( "Text 191", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-191", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-192", array( "label"    => __( "Text 192", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-192", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-193", array( "label"    => __( "Text 193", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-193", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-194", array( "label"    => __( "Text 194", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-194", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-195", array( "label"    => __( "Text 195", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-195", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-196", array( "label"    => __( "Text 196", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-196", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-197", array( "label"    => __( "Text 197", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-197", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-198", array( "label"    => __( "Text 198", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-198", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-199", array( "label"    => __( "Text 199", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-199", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-200", array( "label"    => __( "Text 200", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-200", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-201", array( "label"    => __( "Text 201", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-201", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-202", array( "label"    => __( "Text 202", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-202", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-203", array( "label"    => __( "Text 203", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-203", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-204", array( "label"    => __( "Text 204", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-204", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-205", array( "label"    => __( "Text 205", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-205", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-206", array( "label"    => __( "Text 206", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-206", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-207", array( "label"    => __( "Text 207", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-207", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-208", array( "label"    => __( "Text 208", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-208", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-209", array( "label"    => __( "Text 209", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-209", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-210", array( "label"    => __( "Text 210", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-210", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-211", array( "label"    => __( "Text 211", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-211", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-212", array( "label"    => __( "Text 212", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-212", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-213", array( "label"    => __( "Text 213", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-213", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-214", array( "label"    => __( "Text 214", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-214", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-215", array( "label"    => __( "Text 215", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-215", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-216", array( "label"    => __( "Text 216", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-216", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-217", array( "label"    => __( "Text 217", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-217", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-218", array( "label"    => __( "Text 218", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-218", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-219", array( "label"    => __( "Text 219", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-219", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-220", array( "label"    => __( "Text 220", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-220", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-221", array( "label"    => __( "Text 221", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-221", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtgtextAll-222", array( "label"    => __( "Text 222", "themesgenerator" ), "section"  => "customtgtext-9999", "settings" => "tgtext-222", "type"     => "text" ) ));
}
add_action( "customize_register", "themegenchild_register_theme_customizer2" ); function themegenchild_register_theme_customizer2( $wp_customize ) { $wp_customize->add_panel( "featured_images", array("priority" => 70, "theme_supports" => "","title" => __( "Images", "themesgenerator" ), "description" => __( "Set images", "themesgenerator" ), ) );
$wp_customize->add_section( "customtgimg-1" , array("title" => __("Change Image 1","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-1", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLawgif-fc7.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-1", array( "label"    => __( "Image 1", "themesgenerator" ), "section"  => "customtgimg-1", "settings" => "tgimg-1" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-1", array("selector" => "#tgimg-1",));

$wp_customize->add_section( "customtgimg-2" , array("title" => __("Change Image 2","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-2", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLawgif-fc7.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-2", array( "label"    => __( "Image 2", "themesgenerator" ), "section"  => "customtgimg-2", "settings" => "tgimg-2" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-2", array("selector" => "#tgimg-2",));

$wp_customize->add_section( "customtgimg-3" , array("title" => __("Change Image 3","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-3", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLawgif-fc7.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-3", array( "label"    => __( "Image 3", "themesgenerator" ), "section"  => "customtgimg-3", "settings" => "tgimg-3" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-3", array("selector" => "#tgimg-3",));

$wp_customize->add_section( "customtgimg-4" , array("title" => __("Change Image 4","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-4", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLawgif-fc7.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-4", array( "label"    => __( "Image 4", "themesgenerator" ), "section"  => "customtgimg-4", "settings" => "tgimg-4" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-4", array("selector" => "#tgimg-4",));

$wp_customize->add_section( "customtgimg-5" , array("title" => __("Change Image 5","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-5", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLawgif-fc7.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-5", array( "label"    => __( "Image 5", "themesgenerator" ), "section"  => "customtgimg-5", "settings" => "tgimg-5" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-5", array("selector" => "#tgimg-5",));

$wp_customize->add_section( "customtgimg-6" , array("title" => __("Change Image 6","themesgenerator"),	"panel"    => "featured_images","priority" => 20) );
$wp_customize->add_setting( "tgimg-6", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/LogoMidEastLaw-6be-d6b.jpg"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgimg-6", array( "label"    => __( "Image 6", "themesgenerator" ), "section"  => "customtgimg-6", "settings" => "tgimg-6" ) ));
$wp_customize->selective_refresh->add_partial("tgimg-6", array("selector" => "#tgimg-6",));
}
add_action( "customize_register", "themegenchild_register_theme_customizerLinks" ); function themegenchild_register_theme_customizerLinks( $wp_customize ) { $wp_customize->add_panel( "featured_links", array("priority" => 70, "theme_supports" => "","title" => __( "Links", "themesgenerator" ), "description" => __( "Set links", "themesgenerator" ), ) );
$wp_customize->add_section( "customtglink-1" , array("title" => __("Change Link 1","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-1", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/the-practice"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-1", array( "label"    => __( "Link 1", "themesgenerator" ), "section"  => "customtglink-1", "settings" => "tglink-1", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-1", array("selector" => "#tglink-1",));

$wp_customize->add_section( "customtglink-2" , array("title" => __("Change Link 2","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-2", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/areas"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-2", array( "label"    => __( "Link 2", "themesgenerator" ), "section"  => "customtglink-2", "settings" => "tglink-2", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-2", array("selector" => "#tglink-2",));

$wp_customize->add_section( "customtglink-3" , array("title" => __("Change Link 3","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-3", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/team"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-3", array( "label"    => __( "Link 3", "themesgenerator" ), "section"  => "customtglink-3", "settings" => "tglink-3", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-3", array("selector" => "#tglink-3",));

$wp_customize->add_section( "customtglink-4" , array("title" => __("Change Link 4","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-4", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/offices/"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-4", array( "label"    => __( "Link 4", "themesgenerator" ), "section"  => "customtglink-4", "settings" => "tglink-4", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-4", array("selector" => "#tglink-4",));

$wp_customize->add_section( "customtglink-5" , array("title" => __("Change Link 5","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-5", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/egypt"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-5", array( "label"    => __( "Link 5", "themesgenerator" ), "section"  => "customtglink-5", "settings" => "tglink-5", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-5", array("selector" => "#tglink-5",));

$wp_customize->add_section( "customtglink-6" , array("title" => __("Change Link 6","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-6", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/news/all"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-6", array( "label"    => __( "Link 6", "themesgenerator" ), "section"  => "customtglink-6", "settings" => "tglink-6", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-6", array("selector" => "#tglink-6",));

$wp_customize->add_section( "customtglink-7" , array("title" => __("Change Link 7","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-7", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/legal"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-7", array( "label"    => __( "Link 7", "themesgenerator" ), "section"  => "customtglink-7", "settings" => "tglink-7", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-7", array("selector" => "#tglink-7",));

$wp_customize->add_section( "customtglink-8" , array("title" => __("Change Link 8","themesgenerator"),	"panel"    => "featured_links","priority" => 20) );
$wp_customize->add_setting( "tglink-8", array( "sanitize_callback" => "esc_attr", "default" => "https://mideastlaw.code-sn.com/en/policy"));
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglink-8", array( "label"    => __( "Link 8", "themesgenerator" ), "section"  => "customtglink-8", "settings" => "tglink-8", "type"     => "text" ) ));
$wp_customize->selective_refresh->add_partial("tglink-8", array("selector" => "#tglink-8",));

$wp_customize->add_section( "customtglink-9999" , array("title" => __("See all","themesgenerator"),	"panel"    => "featured_links","priority" => 1) );
$wp_customize->add_setting( "tglink-1", array( "default" => __( "https://mideastlaw.code-sn.com/en/the-practice", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-2", array( "default" => __( "https://mideastlaw.code-sn.com/en/areas", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-3", array( "default" => __( "https://mideastlaw.code-sn.com/en/team", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-4", array( "default" => __( "https://mideastlaw.code-sn.com/en/offices/", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-5", array( "default" => __( "https://mideastlaw.code-sn.com/en/egypt", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-6", array( "default" => __( "https://mideastlaw.code-sn.com/news/all", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-7", array( "default" => __( "https://mideastlaw.code-sn.com/en/legal", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );$wp_customize->add_setting( "tglink-8", array( "default" => __( "https://mideastlaw.code-sn.com/en/policy", "themesgenerator" ), "sanitize_callback" => "esc_attr"	) );
$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-1", array( "label"    => __( "Link 1", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-1", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-2", array( "label"    => __( "Link 2", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-2", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-3", array( "label"    => __( "Link 3", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-3", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-4", array( "label"    => __( "Link 4", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-4", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-5", array( "label"    => __( "Link 5", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-5", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-6", array( "label"    => __( "Link 6", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-6", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-7", array( "label"    => __( "Link 7", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-7", "type"     => "text" ) ));$wp_customize->add_control( new WP_Customize_Control( $wp_customize, "customtglinkAll-8", array( "label"    => __( "Link 8", "themesgenerator" ), "section"  => "customtglink-9999", "settings" => "tglink-8", "type"     => "text" ) ));
}
 add_action( "customize_register", "themegenchild_register_theme_customizer_pc1" ); 
			function themegenchild_register_theme_customizer_pc1( $wp_customize ) { 
				$wp_customize->add_panel( "tgpage_contents1_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents1", "themesgenerator" ), "description" => __( "Set page content block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tgpage_contents1_options", array("title" => __( "Page Content Block 1", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the page content block 1", "tgpage_contents1"),) );
				$wp_customize->add_setting( "page_contentz_name1", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tgpage_contents1_theme_name",array("label" => __( "Page to show", "themesgenerator" ),"settings" => "page_contentz_name1","priority" => 10,"section" => "tgpage_contents1_options","type" => "dropdown-pages")));
				
				$wp_customize->add_setting("tgpage_contents_padding1",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding1", array("label" => "Top & Bottom Padding (px)", "section" => "tgpage_contents1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tgpage_contents_padding_leftright1", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding_leftright1", array("label" => "Left & Right Padding (px)", "section" => "tgpage_contents1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tgpage_contents_paragraph_margin1", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_paragraph_margin1", array("label" => "Paragraph Margin (px)", "section" => "tgpage_contents1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->selective_refresh->add_partial("tgpage_contents_paragraph_margin1", array( "selector" => "#page_contentz_name1") );
			}			
			function tg_sitelayout_head_styles1() { $content_padding1 = get_theme_mod("tgpage_contents_padding1"); $content_padding_leftright1 = get_theme_mod("tgpage_contents_padding_leftright1"); $content_paragraph_margin1 = get_theme_mod("tgpage_contents_paragraph_margin1"); if ( $content_padding1 != "5" ) : ?> <style type="text/css"> .pagecontz-1 { padding-top: <?php echo $content_padding1;?>px!important; padding-bottom: <?php echo $content_padding1; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright1 != "20" ) : ?> <style type="text/css"> .pagecontz-1 { padding-left: <?php echo $content_padding_leftright1; ?>px!important; padding-right: <?php echo $content_padding_leftright1; ?>px!important; } </style> <?php endif; if ( $content_paragraph_margin1 != "10" ) : ?> <style type="text/css"> .pagecontz-1 p{ margin: <?php echo $content_paragraph_margin1; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles1" );			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_pc2" ); 
			function themegenchild_register_theme_customizer_pc2( $wp_customize ) { 
				$wp_customize->add_panel( "tgpage_contents2_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents2", "themesgenerator" ), "description" => __( "Set page content block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tgpage_contents2_options", array("title" => __( "Page Content Block 2", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the page content block 2", "tgpage_contents2"),) );
				$wp_customize->add_setting( "page_contentz_name2", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tgpage_contents2_theme_name",array("label" => __( "Page to show", "themesgenerator" ),"settings" => "page_contentz_name2","priority" => 10,"section" => "tgpage_contents2_options","type" => "dropdown-pages")));
				
				$wp_customize->add_setting("tgpage_contents_padding2",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding2", array("label" => "Top & Bottom Padding (px)", "section" => "tgpage_contents2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tgpage_contents_padding_leftright2", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding_leftright2", array("label" => "Left & Right Padding (px)", "section" => "tgpage_contents2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tgpage_contents_paragraph_margin2", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_paragraph_margin2", array("label" => "Paragraph Margin (px)", "section" => "tgpage_contents2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->selective_refresh->add_partial("tgpage_contents_paragraph_margin2", array( "selector" => "#page_contentz_name2") );
			}			
			function tg_sitelayout_head_styles2() { $content_padding2 = get_theme_mod("tgpage_contents_padding2"); $content_padding_leftright2 = get_theme_mod("tgpage_contents_padding_leftright2"); $content_paragraph_margin2 = get_theme_mod("tgpage_contents_paragraph_margin2"); if ( $content_padding2 != "5" ) : ?> <style type="text/css"> .pagecontz-2 { padding-top: <?php echo $content_padding2;?>px!important; padding-bottom: <?php echo $content_padding2; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright2 != "20" ) : ?> <style type="text/css"> .pagecontz-2 { padding-left: <?php echo $content_padding_leftright2; ?>px!important; padding-right: <?php echo $content_padding_leftright2; ?>px!important; } </style> <?php endif; if ( $content_paragraph_margin2 != "10" ) : ?> <style type="text/css"> .pagecontz-2 p{ margin: <?php echo $content_paragraph_margin2; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles2" );			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_pc3" ); 
			function themegenchild_register_theme_customizer_pc3( $wp_customize ) { 
				$wp_customize->add_panel( "tgpage_contents3_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents3", "themesgenerator" ), "description" => __( "Set page content block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tgpage_contents3_options", array("title" => __( "Page Content Block 3", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the page content block 3", "tgpage_contents3"),) );
				$wp_customize->add_setting( "page_contentz_name3", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tgpage_contents3_theme_name",array("label" => __( "Page to show", "themesgenerator" ),"settings" => "page_contentz_name3","priority" => 10,"section" => "tgpage_contents3_options","type" => "dropdown-pages")));
				
				$wp_customize->add_setting("tgpage_contents_padding3",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding3", array("label" => "Top & Bottom Padding (px)", "section" => "tgpage_contents3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tgpage_contents_padding_leftright3", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding_leftright3", array("label" => "Left & Right Padding (px)", "section" => "tgpage_contents3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tgpage_contents_paragraph_margin3", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_paragraph_margin3", array("label" => "Paragraph Margin (px)", "section" => "tgpage_contents3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->selective_refresh->add_partial("tgpage_contents_paragraph_margin3", array( "selector" => "#page_contentz_name3") );
			}			
			function tg_sitelayout_head_styles3() { $content_padding3 = get_theme_mod("tgpage_contents_padding3"); $content_padding_leftright3 = get_theme_mod("tgpage_contents_padding_leftright3"); $content_paragraph_margin3 = get_theme_mod("tgpage_contents_paragraph_margin3"); if ( $content_padding3 != "5" ) : ?> <style type="text/css"> .pagecontz-3 { padding-top: <?php echo $content_padding3;?>px!important; padding-bottom: <?php echo $content_padding3; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright3 != "20" ) : ?> <style type="text/css"> .pagecontz-3 { padding-left: <?php echo $content_padding_leftright3; ?>px!important; padding-right: <?php echo $content_padding_leftright3; ?>px!important; } </style> <?php endif; if ( $content_paragraph_margin3 != "10" ) : ?> <style type="text/css"> .pagecontz-3 p{ margin: <?php echo $content_paragraph_margin3; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles3" );			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_pc4" ); 
			function themegenchild_register_theme_customizer_pc4( $wp_customize ) { 
				$wp_customize->add_panel( "tgpage_contents4_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents4", "themesgenerator" ), "description" => __( "Set page content block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tgpage_contents4_options", array("title" => __( "Page Content Block 4", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the page content block 4", "tgpage_contents4"),) );
				$wp_customize->add_setting( "page_contentz_name4", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tgpage_contents4_theme_name",array("label" => __( "Page to show", "themesgenerator" ),"settings" => "page_contentz_name4","priority" => 10,"section" => "tgpage_contents4_options","type" => "dropdown-pages")));
				
				$wp_customize->add_setting("tgpage_contents_padding4",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding4", array("label" => "Top & Bottom Padding (px)", "section" => "tgpage_contents4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tgpage_contents_padding_leftright4", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_padding_leftright4", array("label" => "Left & Right Padding (px)", "section" => "tgpage_contents4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tgpage_contents_paragraph_margin4", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tgpage_contents_paragraph_margin4", array("label" => "Paragraph Margin (px)", "section" => "tgpage_contents4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->selective_refresh->add_partial("tgpage_contents_paragraph_margin4", array( "selector" => "#page_contentz_name4") );
			}			
			function tg_sitelayout_head_styles4() { $content_padding4 = get_theme_mod("tgpage_contents_padding4"); $content_padding_leftright4 = get_theme_mod("tgpage_contents_padding_leftright4"); $content_paragraph_margin4 = get_theme_mod("tgpage_contents_paragraph_margin4"); if ( $content_padding4 != "5" ) : ?> <style type="text/css"> .pagecontz-4 { padding-top: <?php echo $content_padding4;?>px!important; padding-bottom: <?php echo $content_padding4; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright4 != "20" ) : ?> <style type="text/css"> .pagecontz-4 { padding-left: <?php echo $content_padding_leftright4; ?>px!important; padding-right: <?php echo $content_padding_leftright4; ?>px!important; } </style> <?php endif; if ( $content_paragraph_margin4 != "10" ) : ?> <style type="text/css"> .pagecontz-4 p{ margin: <?php echo $content_paragraph_margin4; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles4" );			
			


 add_action( "customize_register", "themegenchild_register_theme_customizer_lp1" ); 
			function themegenchild_register_theme_customizer_lp1( $wp_customize ) { 
				$wp_customize->add_panel( "tglatest_post1_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents1", "themesgenerator" ), "description" => __( "Set Latest Posts block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tglatest_post1_options", array("title" => __( "Latest Posts Block 1", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the Latest Posts block 1", "tglatest_post1"),) );
				$wp_customize->add_setting( "latest_postz_name1", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tglatest_post1_theme_name",array("label" => __( "Category to show", "themesgenerator" ),"settings" => "latest_postz_name1","priority" => 10,"section" => "tglatest_post1_options","type" => "select","choices" => wcat2())));
				
				$wp_customize->add_setting("tglatest_post_padding1",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding1", array("label" => "Top & bottom padding (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tglatest_post_padding_leftright1", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding_leftright1", array("label" => "Left & right padding (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_paragraph_margin1", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_paragraph_margin1", array("label" => "Description margin (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_count1", array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_count1", array("label" => "Post count", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "99",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_width1", array("sanitize_callback" => "esc_attr", "default" => "150","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_width1", array("label" => "Thumbnail width (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_height1", array("sanitize_callback" => "esc_attr", "default" => "110","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_height1", array("label" => "Thumbnail height (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("tglatest_title_size1", array("sanitize_callback" => "esc_attr", "default" => "26","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_title_size1", array("label" => "Title size (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_description_size1", array("sanitize_callback" => "esc_attr", "default" => "15","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_description_size1", array("label" => "Description size (px)", "section" => "tglatest_post1_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("post_title_color1", array("default" => "#424242","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_title_color1", array("label" => "Post title","section" => "tglatest_post1_options","settings" => "post_title_color1",)));	
	
				$wp_customize->add_setting("post_description_color1", array("default" => "#4c4c4c","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_description_color1", array("label" => "Post description","section" => "tglatest_post1_options","settings" => "post_description_color1",)));
				
			
				function tgnav_sanitize_fonts1( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "tg_latestpost_font1", array("sanitize_callback" => "tgnav_sanitize_fonts1","default" => "auto"));
				$wp_customize->add_control( "tg_latestpost_font1", array("type" => "select","label" => __( "Font family", "themesgenerator" ),"section" => "tglatest_post1_options","choices" => $font_choices,"settings" => "tg_latestpost_font1"));	
				
				
				$wp_customize->selective_refresh->add_partial("tglatest_post_paragraph_margin1", array( "selector" => "#latest_postz_name1") );
			}			
			function tg_sitelayout_head_styles_latestpost21() { $content_padding1 = get_theme_mod("tglatest_post_padding1"); $content_padding_leftright1 = get_theme_mod("tglatest_post_padding_leftright1"); $content_thumbnail_width1 = get_theme_mod("tglatest_thumbnail_width1"); $content_thumbnail_height1 = get_theme_mod("tglatest_thumbnail_height1"); $content_paragraph_margin1 = get_theme_mod("tglatest_post_paragraph_margin1"); $post_title_color1 = get_theme_mod("post_title_color1"); $post_description_color1 = get_theme_mod("post_description_color1"); $tglatest_title_size1 = get_theme_mod("tglatest_title_size1"); $tglatest_description_size1 = get_theme_mod("tglatest_description_size1"); if ( $content_padding1 != "5" ) : ?> <style type="text/css"> .latestpostz-1 { padding-top: <?php echo $content_padding1;?>px!important; padding-bottom: <?php echo $content_padding1; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright1 != "20" ) : ?> <style type="text/css"> .latestpostz-1 { padding-left: <?php echo $content_padding_leftright1; ?>px!important; padding-right: <?php echo $content_padding_leftright1; ?>px!important; } </style> <?php endif; if (( $content_thumbnail_width1 != "150" )&&( $content_thumbnail_width1 != "" )) : ?> <style type="text/css"> .latestpostz-1 img { width: <?php echo $content_thumbnail_width1; ?>px!important; } .latestpostz-1 .latest-post-content { margin-left: calc(<?php echo $content_thumbnail_width1; ?>px + 25px)!important; } </style> <?php endif; if (( $content_thumbnail_height1 != "110" )&&( $content_thumbnail_height1 != "" )) : ?> <style type="text/css"> .latestpostz-1 img { height: <?php echo $content_thumbnail_height1; ?>px!important; } </style> <?php endif; if (( $content_paragraph_margin1 != "10" )&&( $content_paragraph_margin1 != "" )) : ?> <style type="text/css"> .latestpostz-1 p{ margin: <?php echo $content_paragraph_margin1; ?>px!important; } </style> <?php endif; if (( $post_title_color1 != "424242" )&&( $post_title_color1 != "" )) : ?> <style type="text/css"> .latestpostz-1 .latest-post-title{ color: <?php echo $post_title_color1; ?>!important; } </style> <?php endif; if (( $post_description_color1 != "4c4c4c" )&&( $post_description_color1 != "" )) : ?> <style type="text/css"> .latestpostz-1 .latest-post-content p{ color: <?php echo $post_description_color1; ?>!important; } </style> <?php endif; if (( $tglatest_title_size1 != "26" )&&( $tglatest_title_size1 != "" )) : ?> <style type="text/css"> .latestpostz-1 .latest-post-content .latest-post-title{ font-size: <?php echo $tglatest_title_size1; ?>px!important; } </style> <?php endif; if (( $tglatest_description_size1 != "15" )&&( $tglatest_description_size1 != "" )) : ?> <style type="text/css"> .latestpostz-1 .latest-post-content p{ font-size: <?php echo $tglatest_description_size1; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles_latestpost21" );	
			function tgnav_scripts1() { $tg_latestpost_font1 = esc_html(get_theme_mod("tg_latestpost_font1")); if( $tg_latestpost_font1 ) { $not_google_fonts1 = array("auto", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts1 as $url) { if (strpos($tg_latestpost_font1, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts1", "//fonts.googleapis.com/css?family=". $tg_latestpost_font1 ); } else { wp_enqueue_style( "themesgenerator-source-body1", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts1" );
			
			function tg_sitelayout_latest_posts_21() { $tg_latestpost_font1 = esc_html(get_theme_mod("tg_latestpost_font1")); if ( $tg_latestpost_font1 ) {	$font_pieces = explode(":", $tg_latestpost_font1); $custom = ".latestpostz-1 { font-family: {$font_pieces[0]}!important; }"."\n";} if ( $tg_latestpost_font1 ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_21" );
			
			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_lp2" ); 
			function themegenchild_register_theme_customizer_lp2( $wp_customize ) { 
				$wp_customize->add_panel( "tglatest_post2_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents2", "themesgenerator" ), "description" => __( "Set Latest Posts block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tglatest_post2_options", array("title" => __( "Latest Posts Block 2", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the Latest Posts block 2", "tglatest_post2"),) );
				$wp_customize->add_setting( "latest_postz_name2", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tglatest_post2_theme_name",array("label" => __( "Category to show", "themesgenerator" ),"settings" => "latest_postz_name2","priority" => 10,"section" => "tglatest_post2_options","type" => "select","choices" => wcat2())));
				
				$wp_customize->add_setting("tglatest_post_padding2",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding2", array("label" => "Top & bottom padding (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tglatest_post_padding_leftright2", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding_leftright2", array("label" => "Left & right padding (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_paragraph_margin2", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_paragraph_margin2", array("label" => "Description margin (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_count2", array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_count2", array("label" => "Post count", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "99",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_width2", array("sanitize_callback" => "esc_attr", "default" => "150","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_width2", array("label" => "Thumbnail width (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_height2", array("sanitize_callback" => "esc_attr", "default" => "110","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_height2", array("label" => "Thumbnail height (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("tglatest_title_size2", array("sanitize_callback" => "esc_attr", "default" => "26","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_title_size2", array("label" => "Title size (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_description_size2", array("sanitize_callback" => "esc_attr", "default" => "15","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_description_size2", array("label" => "Description size (px)", "section" => "tglatest_post2_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("post_title_color2", array("default" => "#424242","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_title_color2", array("label" => "Post title","section" => "tglatest_post2_options","settings" => "post_title_color2",)));	
	
				$wp_customize->add_setting("post_description_color2", array("default" => "#4c4c4c","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_description_color2", array("label" => "Post description","section" => "tglatest_post2_options","settings" => "post_description_color2",)));
				
			
				function tgnav_sanitize_fonts2( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "tg_latestpost_font2", array("sanitize_callback" => "tgnav_sanitize_fonts2","default" => "auto"));
				$wp_customize->add_control( "tg_latestpost_font2", array("type" => "select","label" => __( "Font family", "themesgenerator" ),"section" => "tglatest_post2_options","choices" => $font_choices,"settings" => "tg_latestpost_font2"));	
				
				
				$wp_customize->selective_refresh->add_partial("tglatest_post_paragraph_margin2", array( "selector" => "#latest_postz_name2") );
			}			
			function tg_sitelayout_head_styles_latestpost22() { $content_padding2 = get_theme_mod("tglatest_post_padding2"); $content_padding_leftright2 = get_theme_mod("tglatest_post_padding_leftright2"); $content_thumbnail_width2 = get_theme_mod("tglatest_thumbnail_width2"); $content_thumbnail_height2 = get_theme_mod("tglatest_thumbnail_height2"); $content_paragraph_margin2 = get_theme_mod("tglatest_post_paragraph_margin2"); $post_title_color2 = get_theme_mod("post_title_color2"); $post_description_color2 = get_theme_mod("post_description_color2"); $tglatest_title_size2 = get_theme_mod("tglatest_title_size2"); $tglatest_description_size2 = get_theme_mod("tglatest_description_size2"); if ( $content_padding2 != "5" ) : ?> <style type="text/css"> .latestpostz-2 { padding-top: <?php echo $content_padding2;?>px!important; padding-bottom: <?php echo $content_padding2; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright2 != "20" ) : ?> <style type="text/css"> .latestpostz-2 { padding-left: <?php echo $content_padding_leftright2; ?>px!important; padding-right: <?php echo $content_padding_leftright2; ?>px!important; } </style> <?php endif; if (( $content_thumbnail_width2 != "150" )&&( $content_thumbnail_width2 != "" )) : ?> <style type="text/css"> .latestpostz-2 img { width: <?php echo $content_thumbnail_width2; ?>px!important; } .latestpostz-2 .latest-post-content { margin-left: calc(<?php echo $content_thumbnail_width2; ?>px + 25px)!important; } </style> <?php endif; if (( $content_thumbnail_height2 != "110" )&&( $content_thumbnail_height2 != "" )) : ?> <style type="text/css"> .latestpostz-2 img { height: <?php echo $content_thumbnail_height2; ?>px!important; } </style> <?php endif; if (( $content_paragraph_margin2 != "10" )&&( $content_paragraph_margin2 != "" )) : ?> <style type="text/css"> .latestpostz-2 p{ margin: <?php echo $content_paragraph_margin2; ?>px!important; } </style> <?php endif; if (( $post_title_color2 != "424242" )&&( $post_title_color2 != "" )) : ?> <style type="text/css"> .latestpostz-2 .latest-post-title{ color: <?php echo $post_title_color2; ?>!important; } </style> <?php endif; if (( $post_description_color2 != "4c4c4c" )&&( $post_description_color2 != "" )) : ?> <style type="text/css"> .latestpostz-2 .latest-post-content p{ color: <?php echo $post_description_color2; ?>!important; } </style> <?php endif; if (( $tglatest_title_size2 != "26" )&&( $tglatest_title_size2 != "" )) : ?> <style type="text/css"> .latestpostz-2 .latest-post-content .latest-post-title{ font-size: <?php echo $tglatest_title_size2; ?>px!important; } </style> <?php endif; if (( $tglatest_description_size2 != "15" )&&( $tglatest_description_size2 != "" )) : ?> <style type="text/css"> .latestpostz-2 .latest-post-content p{ font-size: <?php echo $tglatest_description_size2; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles_latestpost22" );	
			function tgnav_scripts2() { $tg_latestpost_font2 = esc_html(get_theme_mod("tg_latestpost_font2")); if( $tg_latestpost_font2 ) { $not_google_fonts2 = array("auto", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts2 as $url) { if (strpos($tg_latestpost_font2, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts2", "//fonts.googleapis.com/css?family=". $tg_latestpost_font2 ); } else { wp_enqueue_style( "themesgenerator-source-body2", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts2" );
			
			function tg_sitelayout_latest_posts_22() { $tg_latestpost_font2 = esc_html(get_theme_mod("tg_latestpost_font2")); if ( $tg_latestpost_font2 ) {	$font_pieces = explode(":", $tg_latestpost_font2); $custom = ".latestpostz-2 { font-family: {$font_pieces[0]}!important; }"."\n";} if ( $tg_latestpost_font2 ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_22" );
			
			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_lp3" ); 
			function themegenchild_register_theme_customizer_lp3( $wp_customize ) { 
				$wp_customize->add_panel( "tglatest_post3_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents3", "themesgenerator" ), "description" => __( "Set Latest Posts block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tglatest_post3_options", array("title" => __( "Latest Posts Block 3", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the Latest Posts block 3", "tglatest_post3"),) );
				$wp_customize->add_setting( "latest_postz_name3", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tglatest_post3_theme_name",array("label" => __( "Category to show", "themesgenerator" ),"settings" => "latest_postz_name3","priority" => 10,"section" => "tglatest_post3_options","type" => "select","choices" => wcat2())));
				
				$wp_customize->add_setting("tglatest_post_padding3",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding3", array("label" => "Top & bottom padding (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tglatest_post_padding_leftright3", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding_leftright3", array("label" => "Left & right padding (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_paragraph_margin3", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_paragraph_margin3", array("label" => "Description margin (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_count3", array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_count3", array("label" => "Post count", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "99",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_width3", array("sanitize_callback" => "esc_attr", "default" => "150","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_width3", array("label" => "Thumbnail width (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_height3", array("sanitize_callback" => "esc_attr", "default" => "110","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_height3", array("label" => "Thumbnail height (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("tglatest_title_size3", array("sanitize_callback" => "esc_attr", "default" => "26","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_title_size3", array("label" => "Title size (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_description_size3", array("sanitize_callback" => "esc_attr", "default" => "15","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_description_size3", array("label" => "Description size (px)", "section" => "tglatest_post3_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("post_title_color3", array("default" => "#424242","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_title_color3", array("label" => "Post title","section" => "tglatest_post3_options","settings" => "post_title_color3",)));	
	
				$wp_customize->add_setting("post_description_color3", array("default" => "#4c4c4c","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_description_color3", array("label" => "Post description","section" => "tglatest_post3_options","settings" => "post_description_color3",)));
				
			
				function tgnav_sanitize_fonts3( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "tg_latestpost_font3", array("sanitize_callback" => "tgnav_sanitize_fonts3","default" => "auto"));
				$wp_customize->add_control( "tg_latestpost_font3", array("type" => "select","label" => __( "Font family", "themesgenerator" ),"section" => "tglatest_post3_options","choices" => $font_choices,"settings" => "tg_latestpost_font3"));	
				
				
				$wp_customize->selective_refresh->add_partial("tglatest_post_paragraph_margin3", array( "selector" => "#latest_postz_name3") );
			}			
			function tg_sitelayout_head_styles_latestpost23() { $content_padding3 = get_theme_mod("tglatest_post_padding3"); $content_padding_leftright3 = get_theme_mod("tglatest_post_padding_leftright3"); $content_thumbnail_width3 = get_theme_mod("tglatest_thumbnail_width3"); $content_thumbnail_height3 = get_theme_mod("tglatest_thumbnail_height3"); $content_paragraph_margin3 = get_theme_mod("tglatest_post_paragraph_margin3"); $post_title_color3 = get_theme_mod("post_title_color3"); $post_description_color3 = get_theme_mod("post_description_color3"); $tglatest_title_size3 = get_theme_mod("tglatest_title_size3"); $tglatest_description_size3 = get_theme_mod("tglatest_description_size3"); if ( $content_padding3 != "5" ) : ?> <style type="text/css"> .latestpostz-3 { padding-top: <?php echo $content_padding3;?>px!important; padding-bottom: <?php echo $content_padding3; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright3 != "20" ) : ?> <style type="text/css"> .latestpostz-3 { padding-left: <?php echo $content_padding_leftright3; ?>px!important; padding-right: <?php echo $content_padding_leftright3; ?>px!important; } </style> <?php endif; if (( $content_thumbnail_width3 != "150" )&&( $content_thumbnail_width3 != "" )) : ?> <style type="text/css"> .latestpostz-3 img { width: <?php echo $content_thumbnail_width3; ?>px!important; } .latestpostz-3 .latest-post-content { margin-left: calc(<?php echo $content_thumbnail_width3; ?>px + 25px)!important; } </style> <?php endif; if (( $content_thumbnail_height3 != "110" )&&( $content_thumbnail_height3 != "" )) : ?> <style type="text/css"> .latestpostz-3 img { height: <?php echo $content_thumbnail_height3; ?>px!important; } </style> <?php endif; if (( $content_paragraph_margin3 != "10" )&&( $content_paragraph_margin3 != "" )) : ?> <style type="text/css"> .latestpostz-3 p{ margin: <?php echo $content_paragraph_margin3; ?>px!important; } </style> <?php endif; if (( $post_title_color3 != "424242" )&&( $post_title_color3 != "" )) : ?> <style type="text/css"> .latestpostz-3 .latest-post-title{ color: <?php echo $post_title_color3; ?>!important; } </style> <?php endif; if (( $post_description_color3 != "4c4c4c" )&&( $post_description_color3 != "" )) : ?> <style type="text/css"> .latestpostz-3 .latest-post-content p{ color: <?php echo $post_description_color3; ?>!important; } </style> <?php endif; if (( $tglatest_title_size3 != "26" )&&( $tglatest_title_size3 != "" )) : ?> <style type="text/css"> .latestpostz-3 .latest-post-content .latest-post-title{ font-size: <?php echo $tglatest_title_size3; ?>px!important; } </style> <?php endif; if (( $tglatest_description_size3 != "15" )&&( $tglatest_description_size3 != "" )) : ?> <style type="text/css"> .latestpostz-3 .latest-post-content p{ font-size: <?php echo $tglatest_description_size3; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles_latestpost23" );	
			function tgnav_scripts3() { $tg_latestpost_font3 = esc_html(get_theme_mod("tg_latestpost_font3")); if( $tg_latestpost_font3 ) { $not_google_fonts3 = array("auto", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts3 as $url) { if (strpos($tg_latestpost_font3, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts3", "//fonts.googleapis.com/css?family=". $tg_latestpost_font3 ); } else { wp_enqueue_style( "themesgenerator-source-body3", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts3" );
			
			function tg_sitelayout_latest_posts_23() { $tg_latestpost_font3 = esc_html(get_theme_mod("tg_latestpost_font3")); if ( $tg_latestpost_font3 ) {	$font_pieces = explode(":", $tg_latestpost_font3); $custom = ".latestpostz-3 { font-family: {$font_pieces[0]}!important; }"."\n";} if ( $tg_latestpost_font3 ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_23" );
			
			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_lp4" ); 
			function themegenchild_register_theme_customizer_lp4( $wp_customize ) { 
				$wp_customize->add_panel( "tglatest_post4_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents4", "themesgenerator" ), "description" => __( "Set Latest Posts block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tglatest_post4_options", array("title" => __( "Latest Posts Block 4", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the Latest Posts block 4", "tglatest_post4"),) );
				$wp_customize->add_setting( "latest_postz_name4", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tglatest_post4_theme_name",array("label" => __( "Category to show", "themesgenerator" ),"settings" => "latest_postz_name4","priority" => 10,"section" => "tglatest_post4_options","type" => "select","choices" => wcat2())));
				
				$wp_customize->add_setting("tglatest_post_padding4",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding4", array("label" => "Top & bottom padding (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tglatest_post_padding_leftright4", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding_leftright4", array("label" => "Left & right padding (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_paragraph_margin4", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_paragraph_margin4", array("label" => "Description margin (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_count4", array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_count4", array("label" => "Post count", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "99",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_width4", array("sanitize_callback" => "esc_attr", "default" => "150","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_width4", array("label" => "Thumbnail width (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_height4", array("sanitize_callback" => "esc_attr", "default" => "110","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_height4", array("label" => "Thumbnail height (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("tglatest_title_size4", array("sanitize_callback" => "esc_attr", "default" => "26","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_title_size4", array("label" => "Title size (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_description_size4", array("sanitize_callback" => "esc_attr", "default" => "15","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_description_size4", array("label" => "Description size (px)", "section" => "tglatest_post4_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("post_title_color4", array("default" => "#424242","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_title_color4", array("label" => "Post title","section" => "tglatest_post4_options","settings" => "post_title_color4",)));	
	
				$wp_customize->add_setting("post_description_color4", array("default" => "#4c4c4c","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_description_color4", array("label" => "Post description","section" => "tglatest_post4_options","settings" => "post_description_color4",)));
				
			
				function tgnav_sanitize_fonts4( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "tg_latestpost_font4", array("sanitize_callback" => "tgnav_sanitize_fonts4","default" => "auto"));
				$wp_customize->add_control( "tg_latestpost_font4", array("type" => "select","label" => __( "Font family", "themesgenerator" ),"section" => "tglatest_post4_options","choices" => $font_choices,"settings" => "tg_latestpost_font4"));	
				
				
				$wp_customize->selective_refresh->add_partial("tglatest_post_paragraph_margin4", array( "selector" => "#latest_postz_name4") );
			}			
			function tg_sitelayout_head_styles_latestpost24() { $content_padding4 = get_theme_mod("tglatest_post_padding4"); $content_padding_leftright4 = get_theme_mod("tglatest_post_padding_leftright4"); $content_thumbnail_width4 = get_theme_mod("tglatest_thumbnail_width4"); $content_thumbnail_height4 = get_theme_mod("tglatest_thumbnail_height4"); $content_paragraph_margin4 = get_theme_mod("tglatest_post_paragraph_margin4"); $post_title_color4 = get_theme_mod("post_title_color4"); $post_description_color4 = get_theme_mod("post_description_color4"); $tglatest_title_size4 = get_theme_mod("tglatest_title_size4"); $tglatest_description_size4 = get_theme_mod("tglatest_description_size4"); if ( $content_padding4 != "5" ) : ?> <style type="text/css"> .latestpostz-4 { padding-top: <?php echo $content_padding4;?>px!important; padding-bottom: <?php echo $content_padding4; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright4 != "20" ) : ?> <style type="text/css"> .latestpostz-4 { padding-left: <?php echo $content_padding_leftright4; ?>px!important; padding-right: <?php echo $content_padding_leftright4; ?>px!important; } </style> <?php endif; if (( $content_thumbnail_width4 != "150" )&&( $content_thumbnail_width4 != "" )) : ?> <style type="text/css"> .latestpostz-4 img { width: <?php echo $content_thumbnail_width4; ?>px!important; } .latestpostz-4 .latest-post-content { margin-left: calc(<?php echo $content_thumbnail_width4; ?>px + 25px)!important; } </style> <?php endif; if (( $content_thumbnail_height4 != "110" )&&( $content_thumbnail_height4 != "" )) : ?> <style type="text/css"> .latestpostz-4 img { height: <?php echo $content_thumbnail_height4; ?>px!important; } </style> <?php endif; if (( $content_paragraph_margin4 != "10" )&&( $content_paragraph_margin4 != "" )) : ?> <style type="text/css"> .latestpostz-4 p{ margin: <?php echo $content_paragraph_margin4; ?>px!important; } </style> <?php endif; if (( $post_title_color4 != "424242" )&&( $post_title_color4 != "" )) : ?> <style type="text/css"> .latestpostz-4 .latest-post-title{ color: <?php echo $post_title_color4; ?>!important; } </style> <?php endif; if (( $post_description_color4 != "4c4c4c" )&&( $post_description_color4 != "" )) : ?> <style type="text/css"> .latestpostz-4 .latest-post-content p{ color: <?php echo $post_description_color4; ?>!important; } </style> <?php endif; if (( $tglatest_title_size4 != "26" )&&( $tglatest_title_size4 != "" )) : ?> <style type="text/css"> .latestpostz-4 .latest-post-content .latest-post-title{ font-size: <?php echo $tglatest_title_size4; ?>px!important; } </style> <?php endif; if (( $tglatest_description_size4 != "15" )&&( $tglatest_description_size4 != "" )) : ?> <style type="text/css"> .latestpostz-4 .latest-post-content p{ font-size: <?php echo $tglatest_description_size4; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles_latestpost24" );	
			function tgnav_scripts4() { $tg_latestpost_font4 = esc_html(get_theme_mod("tg_latestpost_font4")); if( $tg_latestpost_font4 ) { $not_google_fonts4 = array("auto", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts4 as $url) { if (strpos($tg_latestpost_font4, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts4", "//fonts.googleapis.com/css?family=". $tg_latestpost_font4 ); } else { wp_enqueue_style( "themesgenerator-source-body4", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts4" );
			
			function tg_sitelayout_latest_posts_24() { $tg_latestpost_font4 = esc_html(get_theme_mod("tg_latestpost_font4")); if ( $tg_latestpost_font4 ) {	$font_pieces = explode(":", $tg_latestpost_font4); $custom = ".latestpostz-4 { font-family: {$font_pieces[0]}!important; }"."\n";} if ( $tg_latestpost_font4 ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_24" );
			
			
			 add_action( "customize_register", "themegenchild_register_theme_customizer_lp5" ); 
			function themegenchild_register_theme_customizer_lp5( $wp_customize ) { 
				$wp_customize->add_panel( "tglatest_post5_options", array("priority" => 70, "theme_supports" => "","title" => __( "page_contents5", "themesgenerator" ), "description" => __( "Set Latest Posts block page.", "themesgenerator" ), ) );
				$wp_customize->add_section( "tglatest_post5_options", array("title" => __( "Latest Posts Block 5", "themesgenerator" ),"priority" => 20,"capability"  => "edit_theme_options","description" => __("Set the Latest Posts block 5", "tglatest_post5"),) );
				$wp_customize->add_setting( "latest_postz_name5", array("sanitize_callback" => "esc_attr", "default" => "default","type" => "theme_mod", "capability" => "edit_theme_options",));	
				$wp_customize->add_control( new WP_Customize_Control($wp_customize,"tglatest_post5_theme_name",array("label" => __( "Category to show", "themesgenerator" ),"settings" => "latest_postz_name5","priority" => 10,"section" => "tglatest_post5_options","type" => "select","choices" => wcat2())));
				
				$wp_customize->add_setting("tglatest_post_padding5",	array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding5", array("label" => "Top & bottom padding (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
			
				$wp_customize->add_setting("tglatest_post_padding_leftright5", array("sanitize_callback" => "esc_attr", "default" => "20","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_padding_leftright5", array("label" => "Left & right padding (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_paragraph_margin5", array("sanitize_callback" => "esc_attr", "default" => "10","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_paragraph_margin5", array("label" => "Description margin (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "0", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_post_count5", array("sanitize_callback" => "esc_attr", "default" => "5","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_post_count5", array("label" => "Post count", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "99",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_width5", array("sanitize_callback" => "esc_attr", "default" => "150","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_width5", array("label" => "Thumbnail width (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_thumbnail_height5", array("sanitize_callback" => "esc_attr", "default" => "110","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_thumbnail_height5", array("label" => "Thumbnail height (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("tglatest_title_size5", array("sanitize_callback" => "esc_attr", "default" => "26","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_title_size5", array("label" => "Title size (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				$wp_customize->add_setting("tglatest_description_size5", array("sanitize_callback" => "esc_attr", "default" => "15","sanitize_callback" => "sanitize_float",));
				$wp_customize->add_control("tglatest_description_size5", array("label" => "Description size (px)", "section" => "tglatest_post5_options", "type" => "number", "input_attrs" => array( "min" => "1", "step" => "1", "max" => "10000",),));
				
				
				$wp_customize->add_setting("post_title_color5", array("default" => "#424242","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_title_color5", array("label" => "Post title","section" => "tglatest_post5_options","settings" => "post_title_color5",)));	
	
				$wp_customize->add_setting("post_description_color5", array("default" => "#4c4c4c","sanitize_callback" => "esc_attr"));
				$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, "post_description_color5", array("label" => "Post description","section" => "tglatest_post5_options","settings" => "post_description_color5",)));
				
			
				function tgnav_sanitize_fonts5( $input ) { $valid = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
				 if ( array_key_exists( $input, $valid ) ) { return $input;
				 } else {
				 return "";
				 } } 
				 
				 $font_choices = array(
				 "auto" => "Default",
				 "Arial, Helvetica, sans-serif" => "Arial", "Arial Black, Gadget, sans-serif" => "Arial Black", "Brush Script MT, sans-serif" => "Brush Script MT", "Comic Sans MS, cursive, sans-serif" => "Comic Sans MS", "Courier New, Courier, monospace" => "Courier New", "Georgia, serif" => "Georgia",
				 "Helvetica, serif" => "Helvetica",
				 "Impact, Charcoal, sans-serif" => "Impact", "Lucida Sans Unicode, Lucida Grande, sans-serif" => "Lucida Sans Unicode", "Tahoma, Geneva, sans-serif" => "Tahoma", "Times New Roman, Times, serif" => "Times New Roman", "Trebuchet MS, Helvetica, sans-serif" => "Trebuchet MS", "Verdana, Geneva, sans-serif" => "Verdana", "Arimo:400,700,400italic,700italic" => "Arimo", "Arvo:400,700,400italic,700italic" => "Arvo", "Bitter:400,700,400italic" => "Bitter", "Cabin:400,700,400italic" => "Cabin",
				 "Droid Sans:400,700" => "Droid Sans",
				 "Droid Serif:400,700,400italic,700italic" => "Droid Serif", "Fjalla One:400" => "Fjalla One",
				 "Francois One:400" => "Francois One",
				 "Josefin Sans:400,300,600,700" => "Josefin Sans", "Lato:400,700,400italic,700italic" => "Lato", "Libre Baskerville:400,400italic,700" => "Libre Baskerville", "Lora:400,700,400italic,700italic" => "Lora", "Merriweather:400,300italic,300,400italic,700,700italic" => "Merriweather", "Montserrat:400,700" => "Montserrat",
				 "Open Sans:400italic,700italic,400,700" => "Open Sans", "Open Sans Condensed:700,300italic,300" => "Open Sans Condensed", "Oswald:400,700" => "Oswald",
				 "Oxygen:400,300,700" => "Oxygen",
				 "Playfair Display:400,700,400italic" => "Playfair Display", "PT Sans:400,700,400italic,700italic" => "PT Sans", "PT Sans Narrow:400,700" => "PT Sans Narrow", "PT Serif:400,700" => "PT Serif",
				 "Raleway:400,700" => "Raleway",
				 "Roboto:400,400italic,700,700italic" => "Roboto", "Roboto Condensed:400italic,700italic,400,700" => "Roboto Condensed", "Roboto Slab:400,700" => "Roboto Slab", "Rokkitt:400" => "Rokkitt",
				 "Source Sans Pro:400,700,400italic,700italic" => "Source Sans Pro", "Ubuntu:400,700,400italic,700italic" => "Ubuntu", "Yanone Kaffeesatz:400,700" => "Yanone Kaffeesatz", );
			
			
				$wp_customize->add_setting( "tg_latestpost_font5", array("sanitize_callback" => "tgnav_sanitize_fonts5","default" => "auto"));
				$wp_customize->add_control( "tg_latestpost_font5", array("type" => "select","label" => __( "Font family", "themesgenerator" ),"section" => "tglatest_post5_options","choices" => $font_choices,"settings" => "tg_latestpost_font5"));	
				
				
				$wp_customize->selective_refresh->add_partial("tglatest_post_paragraph_margin5", array( "selector" => "#latest_postz_name5") );
			}			
			function tg_sitelayout_head_styles_latestpost25() { $content_padding5 = get_theme_mod("tglatest_post_padding5"); $content_padding_leftright5 = get_theme_mod("tglatest_post_padding_leftright5"); $content_thumbnail_width5 = get_theme_mod("tglatest_thumbnail_width5"); $content_thumbnail_height5 = get_theme_mod("tglatest_thumbnail_height5"); $content_paragraph_margin5 = get_theme_mod("tglatest_post_paragraph_margin5"); $post_title_color5 = get_theme_mod("post_title_color5"); $post_description_color5 = get_theme_mod("post_description_color5"); $tglatest_title_size5 = get_theme_mod("tglatest_title_size5"); $tglatest_description_size5 = get_theme_mod("tglatest_description_size5"); if ( $content_padding5 != "5" ) : ?> <style type="text/css"> .latestpostz-5 { padding-top: <?php echo $content_padding5;?>px!important; padding-bottom: <?php echo $content_padding5; ?>px!important; } </style> <?php endif; if ( $content_padding_leftright5 != "20" ) : ?> <style type="text/css"> .latestpostz-5 { padding-left: <?php echo $content_padding_leftright5; ?>px!important; padding-right: <?php echo $content_padding_leftright5; ?>px!important; } </style> <?php endif; if (( $content_thumbnail_width5 != "150" )&&( $content_thumbnail_width5 != "" )) : ?> <style type="text/css"> .latestpostz-5 img { width: <?php echo $content_thumbnail_width5; ?>px!important; } .latestpostz-5 .latest-post-content { margin-left: calc(<?php echo $content_thumbnail_width5; ?>px + 25px)!important; } </style> <?php endif; if (( $content_thumbnail_height5 != "110" )&&( $content_thumbnail_height5 != "" )) : ?> <style type="text/css"> .latestpostz-5 img { height: <?php echo $content_thumbnail_height5; ?>px!important; } </style> <?php endif; if (( $content_paragraph_margin5 != "10" )&&( $content_paragraph_margin5 != "" )) : ?> <style type="text/css"> .latestpostz-5 p{ margin: <?php echo $content_paragraph_margin5; ?>px!important; } </style> <?php endif; if (( $post_title_color5 != "424242" )&&( $post_title_color5 != "" )) : ?> <style type="text/css"> .latestpostz-5 .latest-post-title{ color: <?php echo $post_title_color5; ?>!important; } </style> <?php endif; if (( $post_description_color5 != "4c4c4c" )&&( $post_description_color5 != "" )) : ?> <style type="text/css"> .latestpostz-5 .latest-post-content p{ color: <?php echo $post_description_color5; ?>!important; } </style> <?php endif; if (( $tglatest_title_size5 != "26" )&&( $tglatest_title_size5 != "" )) : ?> <style type="text/css"> .latestpostz-5 .latest-post-content .latest-post-title{ font-size: <?php echo $tglatest_title_size5; ?>px!important; } </style> <?php endif; if (( $tglatest_description_size5 != "15" )&&( $tglatest_description_size5 != "" )) : ?> <style type="text/css"> .latestpostz-5 .latest-post-content p{ font-size: <?php echo $tglatest_description_size5; ?>px!important; } </style> <?php endif;} add_action( "wp_head", "tg_sitelayout_head_styles_latestpost25" );	
			function tgnav_scripts5() { $tg_latestpost_font5 = esc_html(get_theme_mod("tg_latestpost_font5")); if( $tg_latestpost_font5 ) { $not_google_fonts5 = array("auto", "Arial", "Brush Script MT", "Comic Sans MS", "Courier New", "Georgia", "Helvetica", "Impact", "Lucida Sans Unicode", "Times New Roman", "Trebuchet MS", "Verdana"); foreach ($not_google_fonts5 as $url) { if (strpos($tg_latestpost_font5, $url) !== FALSE) { return true;}}	wp_enqueue_style( "themesgenerator-body-fonts5", "//fonts.googleapis.com/css?family=". $tg_latestpost_font5 ); } else { wp_enqueue_style( "themesgenerator-source-body5", "//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600");}}add_action( "wp_enqueue_scripts", "tgnav_scripts5" );
			
			function tg_sitelayout_latest_posts_25() { $tg_latestpost_font5 = esc_html(get_theme_mod("tg_latestpost_font5")); if ( $tg_latestpost_font5 ) {	$font_pieces = explode(":", $tg_latestpost_font5); $custom = ".latestpostz-5 { font-family: {$font_pieces[0]}!important; }"."\n";} if ( $tg_latestpost_font5 ) : ?> <style type="text/css"> <?php echo $custom;?> </style> <?php endif; } add_action( "wp_head", "tg_sitelayout_latest_posts_25" );
			
			
			
register_nav_menus( array( 'menu1'    => __( 'menu1 menu', 'themesgenerator' ), ) );
add_action( "customize_register", "themegenchild_register_theme_customizer3" ); function themegenchild_register_theme_customizer3( $wp_customize ) { $wp_customize->add_panel( "featured_backgrounds", array("priority" => 70, "theme_supports" => "","title" => __( "Backgrounds", "themesgenerator" ), "description" => __( "Set background image.", "themesgenerator" ), ) );
$wp_customize->add_section( "customtgback-1" , array("title" => __("Change Image 1","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-1", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um155015-bf3.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-1", array( "label"    => __( "Image 1", "themesgenerator" ), "section"  => "customtgback-1", "settings" => "tgback-1" ) ));
$wp_customize->selective_refresh->add_partial("tgback-1", array("selector" => "#tgback-1",));

$wp_customize->add_section( "customtgback-2" , array("title" => __("Change Image 2","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-2", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um160123-817.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-2", array( "label"    => __( "Image 2", "themesgenerator" ), "section"  => "customtgback-2", "settings" => "tgback-2" ) ));
$wp_customize->selective_refresh->add_partial("tgback-2", array("selector" => "#tgback-2",));

$wp_customize->add_section( "customtgback-3" , array("title" => __("Change Image 3","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-3", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um155901-490.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-3", array( "label"    => __( "Image 3", "themesgenerator" ), "section"  => "customtgback-3", "settings" => "tgback-3" ) ));
$wp_customize->selective_refresh->add_partial("tgback-3", array("selector" => "#tgback-3",));

$wp_customize->add_section( "customtgback-4" , array("title" => __("Change Image 4","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-4", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um155015-bf3.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-4", array( "label"    => __( "Image 4", "themesgenerator" ), "section"  => "customtgback-4", "settings" => "tgback-4" ) ));
$wp_customize->selective_refresh->add_partial("tgback-4", array("selector" => "#tgback-4",));

$wp_customize->add_section( "customtgback-5" , array("title" => __("Change Image 5","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-5", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um155901-490.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-5", array( "label"    => __( "Image 5", "themesgenerator" ), "section"  => "customtgback-5", "settings" => "tgback-5" ) ));
$wp_customize->selective_refresh->add_partial("tgback-5", array("selector" => "#tgback-5",));

$wp_customize->add_section( "customtgback-6" , array("title" => __("Change Image 6","themesgenerator"),	"panel"    => "featured_backgrounds","priority" => 20) );
$wp_customize->add_setting( "tgback-6", array( "sanitize_callback" => "esc_attr", "default" => "".get_template_directory_uri()."/images/Bildschirmfoto2020-03-14um160123-817.png"));
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, "customtgback-6", array( "label"    => __( "Image 6", "themesgenerator" ), "section"  => "customtgback-6", "settings" => "tgback-6" ) ));
$wp_customize->selective_refresh->add_partial("tgback-6", array("selector" => "#tgback-6",));
}
/********** custom menu 1 **********/?><?php
/**************************/
/*Menu customizer */
/************************/
add_action( "customize_register", "themesgenchild_register_theme_customizer_sitemenumymenu1"); 
function themesgenchild_register_theme_customizer_sitemenumymenu1( $wp_customize ) {
	$nametoshow=str_replace("mymenu","","mymenu1");
	$wp_customize->add_section( 'tg_menumymenu1styles', array(
		'title' => __( "Menu $nametoshow Styles", 'themesgenerator' ),
		'priority' => 100,
	) );	
	
	/*menumymenu1_text_color*/
	$wp_customize->add_setting( 'menumymenu1_text_color', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menumymenu1_text_color', array(
		'label' => 'Text color',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'menumymenu1_text_color',
	) ) );
	
	/*menumymenu1_text_background*/
	require_once( dirname( __FILE__ ) . '/inc/alpha-color-picker.php' );
	$wp_customize->add_setting(
		'menumymenu1_text_background',
		array(
			'default'     => '',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',"sanitize_callback" => "esc_attr"
		)
	);
	$wp_customize->add_control(
		new Customize_Alpha_Color_Control(
			$wp_customize,
			'menumymenu1_text_background',
			array(
				'label'         => 'Text background',
				'section'       => 'tg_menumymenu1styles',
				'settings'      => 'menumymenu1_text_background',
				'show_opacity'  => true, // Optional.
				'palette'	=> array(
					'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
					'rgba(50,50,50,0.8)',
					'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
					'#00CC99' // Mix of color types = no problem
				)
			)
		)
	);
	

	
	/*submenumymenu1_text_color*/
	$wp_customize->add_setting( 'submenumymenu1_text_color', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'submenumymenu1_text_color', array(
		'label' => 'Submenu text color',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'submenumymenu1_text_color',
	) ) );	
	
	
	/*submenumymenu1_text_background*/
	require_once( dirname( __FILE__ ) . '/inc/alpha-color-picker.php' );
	$wp_customize->add_setting(
		'submenumymenu1_text_background',
		array(
			'default'     => '',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',"sanitize_callback" => "esc_attr"
		)
	);
	$wp_customize->add_control(
		new Customize_Alpha_Color_Control(
			$wp_customize,
			'submenumymenu1_text_background',
			array(
				'label'         => 'Submenu text background',
				'section'       => 'tg_menumymenu1styles',
				'settings'      => 'submenumymenu1_text_background',
				'show_opacity'  => true, // Optional.
				'palette'	=> array(
					'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
					'rgba(50,50,50,0.8)',
					'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
					'#00CC99' // Mix of color types = no problem
				)
			)
		)
	);


	
	
	/*menumymenu1_text_color_hover*/
	$wp_customize->add_setting( 'menumymenu1_text_color_hover', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menumymenu1_text_color_hover', array(
		'label' => 'Text color hover',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'menumymenu1_text_color_hover',
	) ) );
	

	/*menumymenu1_text_background_hover*/
	$wp_customize->add_setting( 'menumymenu1_text_background_hover', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'menumymenu1_text_background_hover', array(
		'label' => 'Text background hover',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'menumymenu1_text_background_hover',
	) ) );	
	
	
	/*menumymenu1_navbar_background*/
	require_once( dirname( __FILE__ ) . '/inc/alpha-color-picker.php' );
	$wp_customize->add_setting(
		'menumymenu1_navbar_background',
		array(
			'default'     => '',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',"sanitize_callback" => "esc_attr"
		)
	);
	$wp_customize->add_control(
		new Customize_Alpha_Color_Control(
			$wp_customize,
			'menumymenu1_navbar_background',
			array(
				'label'         => 'Navbar background',
				'section'       => 'tg_menumymenu1styles',
				'settings'      => 'menumymenu1_navbar_background',
				'show_opacity'  => true, // Optional.
				'palette'	=> array(
					'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
					'rgba(50,50,50,0.8)',
					'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
					'#00CC99' // Mix of color types = no problem
				)
			)
		)
	);	
	

	
	/*menumymenu1_mobile_background*/
	require_once( dirname( __FILE__ ) . '/inc/alpha-color-picker.php' );
	$wp_customize->add_setting(
		'menumymenu1_mobile_background',
		array(
			'default'     => '',
			'type'        => 'theme_mod',
			'capability'  => 'edit_theme_options',
			'transport'   => 'refresh',"sanitize_callback" => "esc_attr"
		)
	);
	$wp_customize->add_control(
		new Customize_Alpha_Color_Control(
			$wp_customize,
			'menumymenu1_mobile_background',
			array(
				'label'         => 'Mobile menu background',
				'section'       => 'tg_menumymenu1styles',
				'settings'      => 'menumymenu1_mobile_background',
				'show_opacity'  => true, // Optional.
				'palette'	=> array(
					'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
					'rgba(50,50,50,0.8)',
					'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
					'#00CC99' // Mix of color types = no problem
				)
			)
		)
	);	
	
	
	
	
	/*mobile_icon_colormymenu1*/
	$wp_customize->add_setting( 'mobile_icon_colormymenu1', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_icon_colormymenu1', array(
		'label' => 'Mobile icon',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'mobile_icon_colormymenu1',
	) ) );
	
	
	
	/*mobile_separator_colormymenu1*/
	$wp_customize->add_setting( 'mobile_separator_colormymenu1', array(
		'default' => '',"sanitize_callback" => "esc_attr"
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mobile_separator_colormymenu1', array(
		'label' => 'Mobile separator',
		'section' => 'tg_menumymenu1styles',
		'settings' => 'mobile_separator_colormymenu1',
	) ) );	
	
	
	
	/*menumymenu1_navbar_letter_spacing*/
	$wp_customize->add_setting(
		'menumymenu1_navbar_letter_spacing',
		array(
			'default' => '0',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_letter_spacing',
		array(
			'label' => 'Letter spacing (px)',
			'section' => 'tg_menumymenu1styles',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '0.1', 'max' => '10000',
			  ),
		)
	);	
	
	
	/*menumymenu1_navbar_leftright_padding*/
	$wp_customize->add_setting(
		'menumymenu1_navbar_leftright_padding',
		array(
			'default' => '15',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_leftright_padding',
		array(
			'label' => 'Item side padding (px)',
			'section' => 'tg_menumymenu1styles',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);		



	/*menumymenu1_navbar_top_padding*/
	$wp_customize->add_setting(
		'menumymenu1_navbar_top_padding',
		array(
			'default' => '10',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_top_padding',
		array(
			'label' => 'Navbar top margin (px)',
			'section' => 'tg_menumymenu1styles',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
	
	
	/*menumymenu1_navbar_font_size*/
	$wp_customize->add_setting(
		'menumymenu1_navbar_font_size',
		array(
			'default' => '18',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_font_size',
		array(
			'label' => 'Font size (px)',
			'section' => 'tg_menumymenu1styles',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	





	/*menumymenu1_navbar_text_shadow*/
	$wp_customize->add_setting(
		'menumymenu1_navbar_text_shadow',
		array(
			'default' => '#323232 0px 0px 5px',
			'sanitize_callback' => 'esc_attr',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_text_shadow',
		array(
			'label' => 'Text shadow',
			'section' => 'tg_menumymenu1styles',
			'type' => 'text',
		)
	);


	
	
	
/*menumymenu1_navbar_max_width*/	
/*		
	$wp_customize->add_setting(
		'menumymenu1_navbar_max_width',
		array(
			'default' => '950',
			'sanitize_callback' => 'sanitize_float',
		)
	);
	$wp_customize->add_control(
		'menumymenu1_navbar_max_width',
		array(
			'label' => 'Navbar max width (px)',
			'section' => 'tg_menumymenu1styles',
			'type' => 'number',
			'input_attrs' => array(
				'min' => '0', 'step' => '1', 'max' => '10000',
			  ),
		)
	);	
*/	
	
	
	
	/*random_boolean*/
/*
	$wp_customize->add_setting( 'random_boolean', array(
	'default'        => false,
	'capability'     => 'edit_theme_options'
	 ) );
	$wp_customize->add_control('random_boolean',
	array(
		'section'   => 'tg_menumymenu1styles',
		'label'     => 'Sidebar in blog & WooCommerce',
		'type'      => 'checkbox'
		 )
	 ); 
*/
	 
}

function tg_sitemenumymenu1_head_styles() {
	$menumymenu1_text_color = get_theme_mod( 'menumymenu1_text_color' ); 	
	if (( $menumymenu1_text_color != 'inherit' )&&( $menumymenu1_text_color != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar-menu-link {
				color: <?php echo $menumymenu1_text_color; ?>!important;
			}
		</style>
	<?php
	endif;
	
	
	
	$submenumymenu1_text_color = get_theme_mod( 'submenumymenu1_text_color' ); 	
	if (( $submenumymenu1_text_color != 'inherit' )&&( $submenumymenu1_text_color != '' )):
	?>
		<style type="text/css">
			@media screen and (min-width: 992px){
				.navbar-menu .mymenu1 .sub-menu li a {
					color: <?php echo $submenumymenu1_text_color; ?>!important;
				}
			}
		</style>
	<?php
	endif;	
	
	
	$menumymenu1_text_background_hover = get_theme_mod( 'menumymenu1_text_background_hover' ); 	
	if (( $menumymenu1_text_background_hover != 'inherit' )&&( $menumymenu1_text_background_hover != '' )) :
	?>
		<style type="text/css">
			.navbar-menu .mymenu1 li:hover > a {
				background-color: <?php echo $menumymenu1_text_background_hover; ?>!important;
			}
		</style>
	<?php
	endif;		
	
	
	
	$menumymenu1_text_color_hover = get_theme_mod( 'menumymenu1_text_color_hover' ); 	
	if (( $menumymenu1_text_color_hover != 'inherit' )&&( $menumymenu1_text_color_hover != '' )) :
	?>
		<style type="text/css">
			.navbar-menu .mymenu1 li:hover > a {
				color: <?php echo $menumymenu1_text_color_hover; ?>!important;
			}
		</style>
	<?php
	endif;	
	
	
	
	$menumymenu1_text_background = get_theme_mod( 'menumymenu1_text_background' ); 	
	if (( $menumymenu1_text_background != 'rgba(209,0,55,0.7)' )&&( $menumymenu1_text_background != '' )) :
	?>
		<style type="text/css">
		@media screen and (min-width: 993px) {
			.navbar-menu .mymenu1 > li > a {
				background-color: <?php echo $menumymenu1_text_background; ?>!important;
			}
		}
		</style>
	<?php
	endif;
	

	$submenumymenu1_text_background = get_theme_mod( 'submenumymenu1_text_background' ); 	
	if (( $submenumymenu1_text_background != 'rgba(230, 230, 230,0.7)' )&&( $submenumymenu1_text_background != '' )) :
	?>
		<style type="text/css">
		@media screen and (min-width: 993px) {
			.navbar-menu .mymenu1 .sub-menu li {
				background-color: <?php echo $submenumymenu1_text_background; ?>!important;
			}
		}
		</style>
	<?php
	endif;	
	
	
	
	
	$menumymenu1_mobile_background = get_theme_mod( 'menumymenu1_mobile_background' ); 	
	if (( $menumymenu1_mobile_background != 'rgba(146,149,168,0.7)' )&&( $menumymenu1_mobile_background != '' )) :
	?>
		<style type="text/css">
			@media screen and (max-width: 993px){
				.containermymenu1 .navbar-menu {
					background-color: <?php echo $menumymenu1_mobile_background; ?>!important;
				}
			}
		</style>
	<?php
	endif;		
	

	
	
	
	
	
	
	
	
	
	$mobile_icon_colormymenu1 = get_theme_mod( 'mobile_icon_colormymenu1' ); 	
	if (( $mobile_icon_colormymenu1 != 'inherit' )&&( $mobile_icon_colormymenu1 != '' )) :
	?>
		<style type="text/css">
			.containermymenu1 .navbar-burger-line {
				background: <?php echo $mobile_icon_colormymenu1; ?>!important;
			}
		</style>
	<?php
	endif;
	
	
	
	$mobile_separator_colormymenu1 = get_theme_mod( 'mobile_separator_colormymenu1' ); 	
	if (( $mobile_separator_colormymenu1 != 'inherit' )&&( $mobile_separator_colormymenu1 != '' )) :
	?>
		<style type="text/css">
			@media screen and (max-width: 993px) {
				.itemsmymenu1 .navbar-menu li a {
					border-bottom: 1px solid  <?php echo $mobile_separator_colormymenu1; ?>!important;
				}
			}
		</style>
	<?php
	endif;
	
	
	
	
	
	
	
	
	
	$menumymenu1_navbar_background = get_theme_mod( 'menumymenu1_navbar_background' ); 	
	if (( $menumymenu1_navbar_background != 'rgba(209,0,55,0.7)' )&&( $menumymenu1_navbar_background != '' )) :
	?>
		<style type="text/css">
			.navbar .containermymenu1, .navbarcenter  .containermymenu1, .navbarleft2 .containermymenu1{
				background-color: <?php echo $menumymenu1_navbar_background; ?>!important;
			}
		</style>
	<?php
	endif;	
	

	
	
	$menumymenu1_navbar_letter_spacing = get_theme_mod( 'menumymenu1_navbar_letter_spacing' ); 	
	if (( $menumymenu1_navbar_letter_spacing != '15' )&&( $menumymenu1_navbar_letter_spacing != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar-menu-link {
				letter-spacing: <?php echo $menumymenu1_navbar_letter_spacing; ?>px!important;
			}
		</style>
	<?php
	endif;	
	
	
	$menumymenu1_navbar_leftright_padding = get_theme_mod( 'menumymenu1_navbar_leftright_padding' ); 	
	if (( $menumymenu1_navbar_leftright_padding != '15' )&&( $menumymenu1_navbar_leftright_padding != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar-menu-link {
				padding-left: <?php echo $menumymenu1_navbar_leftright_padding; ?>px!important;
				padding-right: <?php echo $menumymenu1_navbar_leftright_padding; ?>px!important;
			}
		</style>
	<?php
	endif;
	
	
	$menumymenu1_navbar_top_padding = get_theme_mod( 'menumymenu1_navbar_top_padding' ); 	
	if (( $menumymenu1_navbar_top_padding != '10' )&&( $menumymenu1_navbar_top_padding != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar {
				margin-top: <?php echo $menumymenu1_navbar_top_padding; ?>px!important;
			}
		</style>
	<?php
	endif;	
	
	
	
	
	
	
	
	
	$menumymenu1_navbar_font_size = get_theme_mod( 'menumymenu1_navbar_font_size' ); 	
	if (( $menumymenu1_navbar_font_size != '18' )&&( $menumymenu1_navbar_font_size != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar-menu-link {
				font-size: <?php echo $menumymenu1_navbar_font_size; ?>px!important;
			}
		</style>
	<?php
	endif;
	
	
	
	/*
	$menumymenu1_navbar_max_width = get_theme_mod( 'menumymenu1_navbar_max_width' ); 	
	if (( $menumymenu1_navbar_max_width != '950' )&&( $menumymenu1_navbar_max_width != '' )) :
	?>
		<style type="text/css">
			.navbar-container{
				max-width: <?php echo $menumymenu1_navbar_max_width; ?>px!important;
			}
		</style>
	<?php
	endif;	
	*/
	
	
	
	


	$menumymenu1_navbar_text_shadow = get_theme_mod( 'menumymenu1_navbar_text_shadow' ); 	
	if (( $menumymenu1_navbar_text_shadow != '#323232 0px 0px 5px' )&&( $menumymenu1_navbar_text_shadow != '' )) :
	?>
		<style type="text/css">
			.mymenu1 .navbar-menu-link {
				text-shadow: <?php echo $menumymenu1_navbar_text_shadow; ?>!important;
			}
		</style>
	<?php
	endif;
	


	$random_boolean = get_theme_mod( 'random_boolean', 'true' ); 
	/*Sidebar function*/ 
	
	function init_add_sidebar_classes_to_body3mymenu1($classes = ""){		$classes[] = "has-sidebar";    return $classes;}	
	if ( $random_boolean === true ) {
		add_filter("body_class", "init_add_sidebar_classes_to_body3mymenu1");		
	}
	if ( $random_boolean === false ) {
		remove_filter("body_class", "init_add_sidebar_classes_to_body3mymenu1");
	}
	

	/*Google font*/ 
	$body_font = esc_html(get_theme_mod('tg_navbar_fontmymenu1'));
	if ( $body_font ) {
		$font_pieces = explode(":", $body_font);
		$custom = ".mymenu1 .navbar-menu-link { font-family: {$font_pieces[0]}!important; }"."\n";
	}
	if ( $body_font ) :
	?>
		<style type="text/css">
			<?php echo $custom;
			//echo "imprimo mymenu1";
			?>
		</style>
	<?php
	endif;

	
	
	
	
	
	/*Navbar font weight*/
	$navbar_fontweight = esc_html(get_theme_mod('tg_navbar_fontweightmymenu1'));
	if ( $navbar_fontweight ) {
			?>
				<style type="text/css">
					.navbar-items-c .mymenu1 {
						font-weight: <?php echo $navbar_fontweight;?>!important;
					}
				</style>
			<?php
	}	
	
	


	/*Navbar align*/
	$navbar_align = esc_html(get_theme_mod('tg_navbar_alignmymenu1'));
	if ( $navbar_align ) {
		if ( $navbar_align == "right" ) {
			?>
				<style type="text/css">
					.itemsmymenu1.navbar-items-c {
						float: right!important;
					}
				</style>
			<?php
		}
		if ( $navbar_align == "left" ) {
			?>
				<style type="text/css">
					.itemsmymenu1.navbar-items-c {
						float: left!important;
					}
				</style>
			<?php
		}
		if ( $navbar_align == "center" ) {
			?>
				<style type="text/css">		
				.itemsmymenu1.navbar-items-c {
					display: inline-block;
				}
				@media screen and (max-width: 993px) {													
					.itemsmymenu1.navbar-items-c {
						display: none;						
					}
				}				
				@media screen and (min-width: 993px) {
					.itemsmymenu1.navbar-items-c {
						float: none!important;						
					}
					.containermymenu1 {
						text-align: center!important;						
					}
				}
				</style>
			<?php
		}
	}



//navmob icon align


	/*Navbar align*/
	$navmobbar_align = esc_html(get_theme_mod('tg_navmobbar_alignmymenu1'));
	if ( $navmobbar_align ) {
		if ( $navmobbar_align == "right" ) {
			?>
				<style type="text/css">
					.mobilemymenu1 {
						float: right!important;
					}
				</style>
			<?php
		}
		if ( $navmobbar_align == "left" ) {
			?>
				<style type="text/css">
					.mobilemymenu1 {
						float: left!important;
					}
				</style>
			<?php
		}
		if ( $navmobbar_align == "center" ) {
			?>
				<style type="text/css">		
					.mobilemymenu1 {
						float: none!important;
						margin: 0 auto;
					}
				</style>
			<?php
		}
	}


	
	/*Navbar vertical orientation*/
	$navmobbar_vertical = esc_html(get_theme_mod('tg_navmobbar_orientationmymenu1'));
	if ( $navmobbar_vertical ) {
		if ( $navmobbar_vertical == "yes" ) {
			?>
				<style type="text/css">
					@media screen and (min-width: 993px){
						.navbar{
							margin-top:0px;
						}
						.containermymenu1 .navbar-menu li:hover {
							background-color: unset!important;	
						}	
						.containermymenu1 li {
							padding: unset!important;	
						}
						.containermymenu1 .navbar-menu .sub-menu li {
							background: none;
							line-height: 1;
						}
						.containermymenu1 .navbar-menu ul li {
							width: 100%;
						}	
						.containermymenu1 .navbar-menu ul ul {
							top: unset;
							width: 100%;
						}
						.containermymenu1 .navbar-items-c{
							display: block!important;		
						}
						.containermymenu1 .navbar-burger{
							display: none!important;		
						}
						.containermymenu1 .navbar-menu{
							z-index: 9;
							position: relative;
						}
						.containermymenu1 .navbar-menu-link{
							display: block;
						}
						.containermymenu1 .navbar-menu ul {
							display: block!important;
							position: relative;
						}	
						.containermymenu1  .navbar-menu ul ul li a:before {
							margin-left: -6px;
							margin-right: 2px;
							content: "\00a0 \00a0 -";
						}
						.containermymenu1 .navbar-menu ul ul ul{
							left: unset;	
						}     		
					}
				</style>
			<?php
		}
		if ( $navmobbar_vertical == "no" ) {
			?>
				<style type="text/css">
					/*Horizontal menu*/
				</style>
			<?php
		}
	}	

	
}	
add_action( 'wp_head', 'tg_sitemenumymenu1_head_styles' );














add_action( "customize_register", "themegenchild_register_theme_customizer7mymenu1" ); 
function themegenchild_register_theme_customizer7mymenu1( $wp_customize ) {
$wp_customize->add_section( "tgnav_google_fonts_section" , array("title" => __("Navbar Font","themesgenerator"),	"priority" => 20) );
		function tgnav_sanitize_fontsmymenu1( $input ) {
			$valid = array(
			'auto' => 'Default',
			'Arial, Helvetica, sans-serif' => 'Arial',
			'Arial Black, Gadget, sans-serif' => 'Arial Black',
			'Brush Script MT, sans-serif' => 'Brush Script MT',
			'Comic Sans MS, cursive, sans-serif' => 'Comic Sans MS',
			'Courier New, Courier, monospace' => 'Courier New',
			'Georgia, serif' => 'Georgia',
			'Helvetica, serif' => 'Helvetica',
			'Impact, Charcoal, sans-serif' => 'Impact',
			'Lucida Sans Unicode, Lucida Grande, sans-serif' => 'Lucida Sans Unicode',
			'Tahoma, Geneva, sans-serif' => 'Tahoma',
			'Times New Roman, Times, serif' => 'Times New Roman',
			'Trebuchet MS, Helvetica, sans-serif' => 'Trebuchet MS',
			'Verdana, Geneva, sans-serif' => 'Verdana',			
			'Arimo:400,700,400italic,700italic' => 'Arimo',
			'Arvo:400,700,400italic,700italic' => 'Arvo',
			'Bitter:400,700,400italic' => 'Bitter',			
			'Cabin:400,700,400italic' => 'Cabin',
			'Droid Sans:400,700' => 'Droid Sans',
			'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',			
			'Fjalla One:400' => 'Fjalla One',
			'Francois One:400' => 'Francois One',			
			'Josefin Sans:400,300,600,700' => 'Josefin Sans',			
			'Lato:400,700,400italic,700italic' => 'Lato',
			'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
			'Lora:400,700,400italic,700italic' => 'Lora',
			'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',			
			'Montserrat:400,700' => 'Montserrat',
			'Open Sans:400italic,700italic,400,700' => 'Open Sans',
			'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
			'Oswald:400,700' => 'Oswald',
			'Oxygen:400,300,700' => 'Oxygen',
			'Playfair Display:400,700,400italic' => 'Playfair Display',
			'PT Sans:400,700,400italic,700italic' => 'PT Sans',
			'PT Sans Narrow:400,700' => 'PT Sans Narrow',			
			'PT Serif:400,700' => 'PT Serif',			
			'Raleway:400,700' => 'Raleway',
			'Roboto:400,400italic,700,700italic' => 'Roboto',
			'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
			'Roboto Slab:400,700' => 'Roboto Slab',
			'Rokkitt:400' => 'Rokkitt',			
			'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
			'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
			'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
		}
		
		$font_choices = array(
			'auto' => 'Default',
			'Arial, Helvetica, sans-serif' => 'Arial',
			'Arial Black, Gadget, sans-serif' => 'Arial Black',
			'Brush Script MT, sans-serif' => 'Brush Script MT',
			'Comic Sans MS, cursive, sans-serif' => 'Comic Sans MS',
			'Courier New, Courier, monospace' => 'Courier New',
			'Georgia, serif' => 'Georgia',
			'Helvetica, serif' => 'Helvetica',
			'Impact, Charcoal, sans-serif' => 'Impact',
			'Lucida Sans Unicode, Lucida Grande, sans-serif' => 'Lucida Sans Unicode',
			'Tahoma, Geneva, sans-serif' => 'Tahoma',
			'Times New Roman, Times, serif' => 'Times New Roman',
			'Trebuchet MS, Helvetica, sans-serif' => 'Trebuchet MS',
			'Verdana, Geneva, sans-serif' => 'Verdana',			
			'Arimo:400,700,400italic,700italic' => 'Arimo',
			'Arvo:400,700,400italic,700italic' => 'Arvo',
			'Bitter:400,700,400italic' => 'Bitter',			
			'Cabin:400,700,400italic' => 'Cabin',
			'Droid Sans:400,700' => 'Droid Sans',
			'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',			
			'Fjalla One:400' => 'Fjalla One',
			'Francois One:400' => 'Francois One',			
			'Josefin Sans:400,300,600,700' => 'Josefin Sans',			
			'Lato:400,700,400italic,700italic' => 'Lato',
			'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
			'Lora:400,700,400italic,700italic' => 'Lora',
			'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',			
			'Montserrat:400,700' => 'Montserrat',
			'Open Sans:400italic,700italic,400,700' => 'Open Sans',
			'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
			'Oswald:400,700' => 'Oswald',
			'Oxygen:400,300,700' => 'Oxygen',
			'Playfair Display:400,700,400italic' => 'Playfair Display',
			'PT Sans:400,700,400italic,700italic' => 'PT Sans',
			'PT Sans Narrow:400,700' => 'PT Sans Narrow',			
			'PT Serif:400,700' => 'PT Serif',			
			'Raleway:400,700' => 'Raleway',
			'Roboto:400,400italic,700,700italic' => 'Roboto',
			'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
			'Roboto Slab:400,700' => 'Roboto Slab',
			'Rokkitt:400' => 'Rokkitt',			
			'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
			'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
			'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',			
		);

		$wp_customize->add_setting( 'tg_navbar_fontmymenu1', array(
				'sanitize_callback' => 'tgnav_sanitize_fontsmymenu1',
				'default' => 'auto'
			)
		);
		$wp_customize->add_control( 'tg_navbar_fontmymenu1', array(
				'type' => 'select',
				"label"    => __( "Font family", "themesgenerator" ),
				/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
				'section' => 'tg_menumymenu1styles',
				'choices' => $font_choices,
				"settings" => "tg_navbar_fontmymenu1"
			)
		);
$wp_customize->selective_refresh->add_partial("tg_navbar_fontmymenu1", array("selector" => "#menumymenu1-navbar-block",));
}






add_action( "customize_register", "themegenchild_register_theme_customizer9mymenu1" ); 
function themegenchild_register_theme_customizer9mymenu1( $wp_customize ) {
$wp_customize->add_section( "tgnav_fontweight" , array("title" => __("Font weight","themesgenerator"),	"priority" => 20) );
		function tgnav_sanitize_fontweightmymenu1( $input ) {
			$valid = array(
			'100' => 'Thin',
			'200' => 'Extra-Light',
			'300' => 'Light',
			'400' => 'Normal',
			'500' => 'Medium',
			'600' => 'Semi-Bold',
			'700' => 'Bold',
			'800' => 'Extra-Bold',
			'900' => 'Ultra-Bold',			
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
		}	
		$bold_choices = array(
			'100' => 'Thin',
			'200' => 'Extra-Light',
			'300' => 'Light',
			'400' => 'Normal',
			'500' => 'Medium',
			'600' => 'Semi-Bold',
			'700' => 'Bold',
			'800' => 'Extra-Bold',
			'900' => 'Ultra-Bold',				
		);
		$wp_customize->add_setting( 'tg_navbar_fontweightmymenu1', array(
				'sanitize_callback' => 'tgnav_sanitize_fontweightmymenu1',
				'default' => '400'
			)
		);
		$wp_customize->add_control( 'tg_navbar_fontweightmymenu1', array(
				'type' => 'select',
				"label"    => __( "Font weight", "themesgenerator" ),
				/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
				'section' => 'tg_menumymenu1styles',
				'choices' => $bold_choices,
				"settings" => "tg_navbar_fontweightmymenu1"
			)
		);
$wp_customize->selective_refresh->add_partial("tg_navbar_fontweightmymenu1", array("selector" => "#menumymenu1-navbar-block",));
}


add_action( "customize_register", "themegenchild_register_theme_customizer8mymenu1" ); 
function themegenchild_register_theme_customizer8mymenu1( $wp_customize ) {
$wp_customize->add_section( "tgnav_alignment" , array("title" => __("Navbar align","themesgenerator"),	"priority" => 20) );
		function tgnav_sanitize_alignmymenu1( $input ) {
			$valid = array(
			'right' => 'Right',
			'left' => 'Left',
			'center' => 'Center',
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
		}	
		$font_choices = array(
			'right' => 'Right',
			'left' => 'Left',
			'center' => 'Center',			
		);
		$wp_customize->add_setting( 'tg_navbar_alignmymenu1', array(
				'sanitize_callback' => 'tgnav_sanitize_alignmymenu1',
				'default' => 'right'
			)
		);
		$wp_customize->add_control( 'tg_navbar_alignmymenu1', array(
				'type' => 'select',
				"label"    => __( "Navbar align", "themesgenerator" ),
				/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
				'section' => 'tg_menumymenu1styles',
				'choices' => $font_choices,
				"settings" => "tg_navbar_alignmymenu1"
			)
		);
$wp_customize->selective_refresh->add_partial("tg_navbar_alignmymenu1", array("selector" => "#menumymenu1-navbar-block",));
}





add_action( "customize_register", "themegenchild_register_theme_customizerMobmymenu1" ); 
function themegenchild_register_theme_customizerMobmymenu1( $wp_customize ) {
$wp_customize->add_section( "tgnavmob_alignment" , array("title" => __("Mobile icon align","themesgenerator"),	"priority" => 20) );
		function tgnavmob_sanitize_alignmymenu1( $input ) {
			$valid = array(
			'right' => 'Right',
			'left' => 'Left',
			'center' => 'Center',
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
		}	
		$font_choices = array(
			'right' => 'Right',
			'left' => 'Left',
			'center' => 'Center',			
		);
		$wp_customize->add_setting( 'tg_navmobbar_alignmymenu1', array(
				'sanitize_callback' => 'tgnavmob_sanitize_alignmymenu1',
				'default' => 'right'
			)
		);
		$wp_customize->add_control( 'tg_navmobbar_alignmymenu1', array(
				'type' => 'select',
				"label"    => __( "Mobile icon align", "themesgenerator" ),
				/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
				'section' => 'tg_menumymenu1styles',
				'choices' => $font_choices,
				"settings" => "tg_navmobbar_alignmymenu1"
			)
		);
$wp_customize->selective_refresh->add_partial("tg_navmobbar_alignmymenu1", array("selector" => "#menumymenu1-navmobbar-block",));
}






add_action( "customize_register", "themegenchild_register_theme_customizerVerticalmymenu1" ); 
function themegenchild_register_theme_customizerVerticalmymenu1( $wp_customize ) {
$wp_customize->add_section( "tgnavmob_orientationment" , array("title" => __("Vertical menu orientation","themesgenerator"),	"priority" => 20) );
		function tgnavmob_sanitize_orientationmymenu1( $input ) {
			$valid = array(
			'yes' => 'Yes',
			'no' => 'No',
			);
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
			}
		}	
		$font_choices = array(
			'yes' => 'Yes',
			'no' => 'No',			
		);
		$wp_customize->add_setting( 'tg_navmobbar_orientationmymenu1', array(
				'sanitize_callback' => 'tgnavmob_sanitize_orientationmymenu1',
				'default' => 'no'
			)
		);
		$wp_customize->add_control( 'tg_navmobbar_orientationmymenu1', array(
				'type' => 'select',
				"label"    => __( "Vertical orientation", "themesgenerator" ),
				/*'description' => __( 'Select your desired font for the body.', 'themesgenerator' ),*/
				'section' => 'tg_menumymenu1styles',
				'choices' => $font_choices,
				"settings" => "tg_navmobbar_orientationmymenu1"
			)
		);
$wp_customize->selective_refresh->add_partial("tg_navmobbar_orientationmymenu1", array("selector" => "#menumymenu1-navmobbar-block",));
}



/**
 *Menu customizer (fonts)
 * Enqueue scripts and styles.
 */
function tgnav_mymenu1scripts() {
	$body_font = esc_html(get_theme_mod('tg_navbar_fontmymenu1'));
	if( $body_font ) {
			/*Avoids 400 error - resource not found en consola when we choose a NOT google font*/
			$not_google_fonts = array('auto', 'Arial', 'Brush Script MT', 'Comic Sans MS', 'Courier New', 'Georgia', 'Helvetica', 'Impact', 'Lucida Sans Unicode', 'Times New Roman', 'Trebuchet MS', 'Verdana');
			foreach ($not_google_fonts as $url) {
				if (strpos($body_font, $url) !== FALSE) {
					//echo "Match found"; 					
					return true;
				}
			}
			//echo "Not found!";					
			wp_enqueue_style( 'themesgenerator-body-fontsmymenu1', '//fonts.googleapis.com/css?family='. $body_font );
	} else {
		wp_enqueue_style( 'themesgenerator-source-bodymymenu1', '//fonts.googleapis.com/css?family=Source+Sans+Pro:400,300,400italic,700,600');
	}
}
add_action( 'wp_enqueue_scripts', 'tgnav_mymenu1scripts' );
function footer_script(){ if( is_home() || is_front_page() ) { ?>
<script>jQuery(document).ready(function(){var e=atob('cGxlYXNlLCB1cGdyYWRlIHRvIGEgcHJlbWl1bSBhY2NvdW50IHRvIHJlbW92ZSBURyBjcmVkaXRz');if (!jQuery('.home .site-info-tgen').length){alert(e); return;}if (jQuery('.home .site-info-tgen').length){/*Avoids undefined*/if (jQuery('.home .site-info-tgen').html().indexOf('themesgenerator.com') > -1){/*ok*/}else{alert(e); return;}}if (!jQuery('.home .site-info-tgen').is(':visible')){alert(e); return;}if (!jQuery('.home div.site-info-tgen > a').is(':visible')){alert(e); return;}});</script>
			<?php }}
add_action('wp_footer', 'footer_script'); ?>